//------------------------------
//TASKS AND OBJECTIVES

//AIO Attack Location
//AIO Attack Object - teleport true
//AIO Attack Player
//AIO Defend Location - teleport true
//AIO Defense Patrol - teleport true
//AIO Deploy Equipment - teleport true
//AIO Deploy Vehicle
//AIO Destroy Object - teleport true
//AIO Escort Player
//AIO Laze Object
//AIO MAttack Location
//AIO MDestroy Object - teleport true
//AIO Missile Object - teleport true
//AIO Mortar Object - teleport true
//AIO Place Camera
//AIO Repair Object
//AIO Tank Patrol
//AIO Touch Object - teleport true

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Attack Location +++

function AIOAttackLocation::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;
      
	//now, if this bot is linked to a human who has issued this command, up the weight
	if (%this.issuedByClientId == %client.controlByHuman)
	{
		//make sure we have the potential to reach the minWeight
		if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
		{
			if ($AIWeightHumanIssuedCommand < %minWeight)
				return 0;
			else
				%weight = $AIWeightHumanIssuedCommand;
		}
		else
		{
			// calculate the default...
			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
			if (%weight < $AIWeightHumanIssuedCommand)
				%weight = $AIWeightHumanIssuedCommand;
		}
	}
	else
	{
		//make sure we have the potential to reach the minWeight
		if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
			return 0;

		// calculate the default...
		%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
	}

	return %weight;
}

function AIOAttackLocation::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIAttackLocation);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIOAttackLocation::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Attack Location ---

function AIAttackLocation::initFromObjective(%task, %objective, %client)
{
	//initialize the task vars from the objective
   %task.baseWeight = %client.objectiveWeight;
   %task.location = %objective.location;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
	%task.chat = %objective.chat;

	//initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;
   %task.engageTarget = -1;
}

function AIAttackLocation::assume(%task, %client)
{
   %task.setWeightFreq(30);
   %task.setMonitorFreq(30);
	%client.needEquipment = AINeedEquipment(%task.equipment, %client);

	//even if we don't *need* equipemnt, see if we should buy some... 
	if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
	{
		//see if we could benefit from inventory
		%needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
		%result = AIFindClosestInventory(%client, %needArmor);
		%closestInv = getWord(%result, 0);
		%closestDist = getWord(%result, 1);
		if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
		{
			%result = AIFindClosestEnemyToLoc(%client, %task.location, 50, $AIClientLOSTimeout);
	      %closestEnemy = getWord(%result, 0);

			if (%closestEnemy <= 0)
				%client.needEquipment = true;
		}
	}

	//mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();

	%task.snipeLocation = "";
	%task.hideLocation = "";
	%task.moveToPosition = true;
	%task.moveToSnipe = false;
	%task.nextSnipeTime = 0;
}

function AIAttackLocation::retire(%task, %client)
{
}

function AIAttackLocation::weight(%task, %client)
{
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

	//if we're a sniper, we're going to cheat, and see if there are clients near the attack location
   %losTimeout = $AIClientMinLOSTime + ($AIClientLOSTimeout * %client.getSkillLevel());
	%distToLoc = VectorDist(%client.player.getWorldBoxCenter(), %task.location);
	if (%client.player.getInventory(SniperRifle) > 0 && %client.player.getInventory(EnergyPack) > 0 && %distToLoc > 60)
		%result = AIFindClosestEnemyToLoc(%client, %task.location, 50, $AIClientLOSTimeout, true);

	//otherwise, do the search normally.  (cheat ignores LOS)...
	else
		%result = AIFindClosestEnemyToLoc(%client, %task.location, 50, %losTimeout, false);

   %closestEnemy = getWord(%result, 0);
   %closestdist = getWord(%result, 1);
   %task.setWeight(%task.baseWeight);
   
   //see if we found someone
   if (%closestEnemy > 0)
      %task.engageTarget = %closestEnemy;
   else
      %task.engageTarget = -1;
}

function AIAttackLocation::monitor(%task, %client)
{
   //first, buy the equipment
   if (%client.needEquipment)
   {
      %task.setMonitorFreq(5);
      if (%task.equipment !$= "")
         %equipmentList = %task.equipment;
      else
	 %equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
      if (%result $= "InProgress")
      {
         //force a nervous reaction every 15 sec - Lagg...
         if (getSimTime() - %task.buyInvTime > 15000)
         {
            %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
            %task.buyInvTime = getSimTime();
         }
         return;
      }
      else if (%result $= "Finished")
      {
         %task.setMonitorFreq(30);
	 %client.needEquipment = false;
      }
      else if (%result $= "Failed")
      {
	 //if this task is the objective task, choose a new objective
	 if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
	 return;
      }
   }
	//if we made it past the inventory buying, reset the inv time
	%task.buyInvTime = getSimTime();

	//chat
	if (%task.sendMsg)
	{
		if (%task.sendMsgTime == 0)
			%task.sendMsgTime = getSimTime();
		else if (getSimTime() - %task.sendMsgTime > 7000)
		{
			%task.sendMsg = false;
		   if (%client.isAIControlled())
			{
				if (%task.chat !$= "")
				{
					%chatMsg = getWord(%task.chat, 0);
					%chatTemplate = getWord(%task.chat, 1);
					if (%chatTemplate !$= "")
						AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
					else
						AIMessageThread(%task.chat, %client, -1);
				}
				else
					AIMessageThreadTemplate("AttackBase", "ChatSelfAttack", %client, -1);
			}
		}
	}

   //how far are we from the location we're defending
   %myPos = %client.player.getWorldBoxCenter();
   %distance = %client.getPathDistance(%task.location);
	if (%distance < 0)
		%distance = 32767;

	if (%client.player.getInventory(SniperRifle) > 0 && %client.player.getInventory(EnergyPack) > 0)
	{
		//first, find an LOS location
		if (%task.snipeLocation $= "")
		{
			%task.snipeLocation = %client.getLOSLocation(%task.location, 150, 250);
			%task.hideLocation = %client.getHideLocation(%task.location, VectorDist(%task.location, %task.snipeLocation), %task.snipeLocation, 1); 
			%client.stepMove(%task.hideLocation, 4.0);
			%task.moveToPosition = true;
		}
		else
		{
			//see if we can acquire a target
			%energy = %client.player.getEnergyPercent();
			%distToSnipe = VectorDist(%task.snipelocation, %client.player.getWorldBoxCenter());
			%distToHide = VectorDist(%task.hidelocation, %client.player.getWorldBoxCenter());

			//until we're in position, we can move using the AIModeExpress, after that, we only want to walk...
			if (%task.moveToPosition)
			{
				if (%distToHide < 4.0)
				{
					//dissolve the human control link
					if (%task == %client.objectiveTask)
					{
						if (aiHumanHasControl(%task.issuedByClient, %client))
						{
							aiReleaseHumanControl(%client.controlByHuman, %client);

							//should re-evaluate the current objective weight
							%inventoryStr = AIFindClosestInventories(%client);
							%client.objectiveWeight = %client.objective.weight(%client, %client.objectiveLevel, 0, %inventoryStr);
						}
					}

					%task.moveToPosition = false;
				}
			}

			else if (%task.moveToSnipe)
			{
				if (%energy > 0.75 && %client.getStepStatus() $= "Finished")
				{
					%client.stepMove(%task.snipeLocation, 4.0, $AIModeWalk);
					%client.setEngageTarget(%task.engageTarget);
				}
				else if (%energy < 0.4)
				{
					%client.setEngageTarget(-1);
					%client.stepMove(%task.hideLocation, 4.0);
					%task.nextSnipeTime = getSimTime() + 1000 + (getRandom() * 1000);
					%task.moveToSnipe = false;
				}
			}

			else if (%energy > 0.5 && %task.engageTarget > 0 && getSimTime() > %task.nextSnipeTime)
			{ 
			   %client.stepRangeObject(%task.engageTarget.player.getWorldBoxCenter(), "BasicSniperShot", 150, 250, %task.snipelocation);
				%client.aimAt(%task.engageTarget.player.getWorldBoxCenter(), 8000);
				%task.moveToSnipe = true;
			}
		}
	}
	else
	{
	   //else see if we have a target to begin attacking
	   if (%client.getEngageTarget() <= 0 && %task.engageTarget > 0)
	      %client.stepEngage(%task.engageTarget);

	   //else move to the location we're defending
	   else if (%client.getEngageTarget() <= 0)
		{
	      %client.stepMove(%task.location, 8.0);
			if (VectorDist(%client.player.position, %task.location) < 10)
			{
				//dissolve the human control link
				if (%task == %client.objectiveTask)
				{
					if (aiHumanHasControl(%task.issuedByClient, %client))
					{
						aiReleaseHumanControl(%client.controlByHuman, %client);

						//should re-evaluate the current objective weight
						%inventoryStr = AIFindClosestInventories(%client);
						%client.objectiveWeight = %client.objective.weight(%client, %client.objectiveLevel, 0, %inventoryStr);
					}
				}
			}
		}
	}

   //see if we're supposed to be engaging anyone...
   if (!AIClientIsAlive(%client.getEngageTarget()) && AIClientIsAlive(%client.shouldEngage))
      %client.setEngageTarget(%client.shouldEngage);
}

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Attack Object +++
//totally rewritten so but will RAPE the object. used only for generators in Omann Ru siege - Lagg... 11-1-2003

function AIOAttackObject::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   // if were playing CnH, check who owns this
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team == %client.team)
      return 0;      
   
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;
      
   //no need to attack if the object is already destroyed
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamageState() $= "Destroyed")
      return 0;
   else
   {
      //if this bot is linked to a human who has issued this command, up the weight
      if (%this.issuedByClientId == %client.controlByHuman)
      {
         //make sure we have the potential to reach the minWeight
	 if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
	 {
	    if ($AIWeightHumanIssuedCommand < %minWeight)
	       return 0;
	    else
	       %weight = $AIWeightHumanIssuedCommand;
         }
	 else
	 {
	    // calculate the default...
	    %weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
	    if (%weight < $AIWeightHumanIssuedCommand)
	       %weight = $AIWeightHumanIssuedCommand;
	 }
      }
      else
      {
         //make sure we have the potential to reach the minWeight
	 if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
	    return 0;

         //if the enemy turrets are down take out this target
         %tur1 = nameToId("Team2TurretBaseLarge1");
         %tur2 = nameToId("Team2TurretBaseLarge2");
         %gen1 = nameToId("Team2GeneratorLarge1");
         %gen2 = nameToId("Team2GeneratorLarge2");
         if (%this.targetObjectId == %gen1 || %this.targetObjectId == %gen2)
         {
            if (%tur1.isDisabled() && %tur2.isDisabled())
            {
               //this should break any defense around def bunker gens
               %this.weightLevel1 = "4100";
               %this.weightLevel2 = "3400";
               %this.weightLevel3 = "3150";
               %this.weightLevel4 = "1000";
            }
            else
            {
               %this.weightLevel1 = "3400";
	       %this.weightLevel2 = "3150";
	       %this.weightLevel3 = "1000";
	       %this.weightLevel4 = "0";
            }
         }

	 // calculate the default...
	 %weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
      }

      //lets give him some personallity on this one :) - Lagg...
      if ((findTargetInView(%client, 150)) == %this.targetObjectId)
         %weight += 400;


      return %weight;
   }
}

function AIOAttackObject::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIAttackObject);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIOAttackObject::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//---------------------------------------------------------------------------------------------- AI Attack Object ---

function AIAttackObject::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   %task.equipment = %objective.equipment;
   %task.buyEquipmentSet = %objective.buyEquipmentSet;
   %task.desiredEquipment = %objective.desiredEquipment;
   %task.issuedByClient = %objective.issuedByClientId;
   %task.location = %objective.location;

   //initialize other task vars
   %task.sendMsg = true;
   %task.sendMsgTime = 0;
   %task.useTeleport = false;

   if (%task.equipment $= "")
   {
      //pick a random equipment set...
      %randNum = getRandom();
      if (%randNum < 0.2)
      {
         %task.desiredEquipment = "SensorJammerPack";
         %task.buyEquipmentSet = "HeavyEnergySet";
      }
      else if (%randNum < 0.4)
      {
         %task.desiredEquipment = "SensorJammerPack";
         %task.buyEquipmentSet = "MediumEnergyELF";
      } 
      else if (%randNum < 0.6)
      {
         %task.desiredEquipment = "CloakingPack";
         %task.buyEquipmentSet = "LightCloakSet";
      }
      else if (%randNum < 0.8)
      {
         %task.desiredEquipment = "ShieldPack";
         %task.buyEquipmentSet = "HeavyShieldOff";
      }
      else
      {
         %task.desiredEquipment = "AmmoPack";
         %task.buyEquipmentSet = "mediumMissileSet";
      }
   }
   //error("AIAttackObject::initFromObjective - " @ getTaggedString(%client.name));
}

function AIAttackObject::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(5);
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);
   %hasPlasma = (%client.player.getInventory("Plasma") > 0) && (%client.player.getInventory("PlasmaAmmo") > 0);
   if (%hasPlasma)
      %client.needEquipment = false;

   //even if we don't *need* equipemnt, see if we should buy some... 
   if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
   {
      //see if we could benefit from inventory
      %needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
      %result = AIFindClosestInventory(%client, %needArmor);
      %closestInv = getWord(%result, 0);
      %closestDist = getWord(%result, 1);
      if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
      {
         //find where we are
         %clientPos = %client.player.getWorldBoxCenter();
         %objPos = %task.targetObject.getWorldBoxCenter();
         %distToObject = %client.getPathDistance(%objPos);
			
	 if (%distToObject < 0 || %closestDist + 50 < %distToObject)
	    %client.needEquipment = true;
      }
   }

   //mark the current time for the buy inventory state machine
   %task.buyInvTime = getSimTime();

   //--------------------------------------------------- assume telporter - start -
   //if the MPB Teleporter is online - Lagg... 9-30-2003

   //first check for deployed MPB
   %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
   %closestMPB = getWord(%result, 0);
   %closestMPBDist = getWord(%result, 1);
      
   //next find the teleporter
   %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
   %closestTel = getWord(%result, 0);
   %closestTelDist = getWord(%result, 1);
      
   //now check for what would be closer - Lagg... 10-1-2003
   if (%closestMPB > 0 && %closestTel > 0)
   {
      %disToTarg = %client.getPathDistance(%task.targetObject.getTransform());
      %mpbDisToTarg = vectorDist(%closestMPB.getTransform(), %task.targetObject.getTransform());
         
      if (%closestTelDist < %closestMPBDist && %closestMPBDist < %disToTarg && %mpbDisToTarg < %disToTarg)
         %task.useTeleport = true;//new - Lagg... 10-1-2003
      else
         %task.useTeleport = false;             
   }
   //--------------------------------------------------- assume telporter - end -

   //error("AiAttackObject - client = " @ getTaggedString(%client.name));//more debugging
}

function AIAttackObject::retire(%task, %client)
{
   %client.setTargetObject(-1);
}

function AIAttackObject::weight(%task, %client)
{
   //update the task weight
   if (%task == %client.objectiveTask)
      %task.baseWeight = %client.objectiveWeight;

   //see if we can find someone to shoot at...
   if (%client.getEngageTarget() <= 0)
   {
      %losTimeout = $AIClientMinLOSTime + ($AIClientLOSTimeout * %client.getSkillLevel());
      %myLocation = %client.player.getWorldBoxCenter();
      %result = AIFindClosestEnemy(%client, 40, %losTimeout);
      %task.engageTarget = getWord(%result, 0);
   }
   
   %task.setWeight(%task.baseWeight);
}

function AIAttackObject::monitor(%task, %client)
{
   //--------------------------------------------------- monitor telporter - start -
   //are we using teleporter
   if (%task.useTeleport)
   {
      %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
      %closestMPB = getWord(%result, 0);
      %closestMPBDist = getWord(%result, 1);
      %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
      %closestTel = getWord(%result, 0);
      %closestTelDist = getWord(%result, 1);
      if (%closestMPB > 0 && %closestTel > 0)
      {
         //we are done teleporting
         if (%closestMPBDist < %closestTelDist)
         {
            //reset the clients inventory status
            if (%client.needEquipment)
            {
               %result = AIFindClosestInventory(%client, 0);
	       %closestInv = getWord(%result, 0);
               %client.invToUse = %closestInv;
            }
            %task.useTeleport = false;
            return;
         }

         if (%closestTelDist < 2)
            %client.pressJump();
         else
         {
            %client.stepMove(%closestTel.getWorldBoxCenter(), 0.25, $AIModeWalk);
            return;
         }
      }
      else
         %task.useTeleport = false;
   }
   //--------------------------------------------------- monitor telporter - end -

   //first, buy the equipment - if we really really need some :) - Lagg... - 4-6-2003
   %hasPlasma = (%client.player.getInventory("Plasma") > 0) && (%client.player.getInventory("PlasmaAmmo") > 0);
   if (%client.needEquipment && !%hasPlasma)
   {
      %task.setMonitorFreq(5);
      if (%task.equipment !$= "")
         %equipmentList = %task.equipment;
      else
         %equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
      if (%result $= "InProgress")
      {
         //force a nervous reaction every 15 sec - Lagg...
         if (getSimTime() - %task.buyInvTime > 15000)
         {
            %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
            %task.buyInvTime = getSimTime();
         }
         return;
      }
      else if (%result $= "Finished")
      {
         %task.setMonitorFreq(15);
	 %client.needEquipment = false;
      }
      else if (%result $= "Failed")
      {
         //if this task is the objective task, choose a new objective
	 if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
         return;
      }
   }

   //if we made it past the inventory buying, reset the inv time
   %task.buyInvTime = getSimTime();
   
   //chat
   if (%task.sendMsg)
   {
      if (%task.sendMsgTime == 0)
         %task.sendMsgTime = getSimTime();
      else if (getSimTime() - %task.sendMsgTime > 7000)
      {
         %task.sendMsg = false;
         if (%client.isAIControlled())
         {
	    if (%task.chat !$= "")
	    {
	       %chatMsg = getWord(%task.chat, 0);
	       %chatTemplate = getWord(%task.chat, 1);
	       if (%chatTemplate !$= "")
	          AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
	       else
		  AIMessageThread(%task.chat, %client, -1);
            }
	    else if (%task.targetObject > 0)
	    {
	       %type = %task.targetObject.getDataBlock().getName();
	       if (%type $= "GeneratorLarge")
	          AIMessageThreadTemplate("AttackBase", "ChatSelfAttackGenerator", %client, -1);
	       else if (%type $= "SensorLargePulse")
		  AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
	       else if (%type $= "SensorMediumPulse")
		  AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
	       else if (%type $= "TurretBaseLarge")
		  AIMessageThreadTemplate("AttackBase", "ChatSelfAttackTurrets", %client, -1);
	       else if (%type $= "StationVehicle")
		  AIMessageThreadTemplate("AttackBase", "ChatSelfAttackVehicle", %client, -1);
            }
         }
      }
   }

   //set the target object if targetObject not destroyed
   %outOfStuff = (AIAttackOutofAmmo(%client));
   if (isObject(%task.targetObject) && %task.targetObject.getDamageState() !$= "Destroyed" && !%outOfStuff)
   {
      %client.stepMove(%task.location, 0.25, $AIModeExpress);//move to target no matter what
      %targetLOS = "false";
      %mask = $TypeMasks::TerrainObjectType | $TypeMasks::InteriorObjectType;
      %targetLOS = !containerRayCast(%client.player.getWorldBoxCenter(), %task.targetObject.getWorldBoxCenter(), %mask, 0);
      
      //fire at target object if in sight
      if (%targetLOS)
      {
         %task.setWeight($AIWeightReturnFire);
         %client.setEngageTarget(-1);
         %client.setTargetObject(%task.targetObject, 80, "Mortar");
      }
      else
      {
         %client.setTargetObject(-1);
         %task.setWeight(%task.baseWeight);

         //see if we need to engage a new target
         %engageTarget = %client.getEngageTarget();
         if (!AIClientIsAlive(%engageTarget) && %task.engageTarget > 0)
            %client.setEngageTarget(%task.engageTarget);

         //else see if we should abandon the engagement
         else if (AIClientIsAlive(%engageTarget))
         {
            %myPos = %client.player.getWorldBoxCenter();
            %testPos = %engageTarget.player.getWorldBoxCenter();
            %distance = %client.getPathDistance(%testPos);
            if (%distance < 0 || %distance > 20)
               %client.setEngageTarget(-1);

            //see if we're supposed to be engaging anyone...
            if (!AIClientIsAlive(%client.getEngageTarget()) && AIClientIsAlive(%client.shouldEngage))
               %client.setEngageTarget(%client.shouldEngage);
         }
      } 
   }
   else
   {
      %client.setTargetObject(-1);
            
      //if this task is the objective task, choose a new objective
      if (%task == %client.objectiveTask)
      {
         AIUnassignClient(%client);
         Game.AIChooseGameObjective(%client);
      }
   }
}

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Attack Player +++

function AIOAttackPlayer::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

	//if we're attacking the flag carrier, make sure a flag carrier exists
	if (%this.mode $= "FlagCarrier")
	{
		if (%this.targetObjectId.carrier $= "")
			return 0;
		else
			%this.targetClientId = %this.targetObjectId.carrier.client;
	}
      
	//now, if this bot is linked to a human who has issued this command, up the weight
	if (%this.issuedByClientId == %client.controlByHuman)
	{
		//make sure we have the potential to reach the minWeight
		if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
		{
			if ($AIWeightHumanIssuedCommand < %minWeight)
				return 0;
			else
				%weight = $AIWeightHumanIssuedCommand;
		}
		else
		{
			// calculate the default...
			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
			if (%weight < $AIWeightHumanIssuedCommand)
				%weight = $AIWeightHumanIssuedCommand;
		}
	}
	else
	{
		//make sure we have the potential to reach the minWeight
		if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
			return 0;

		// calculate the default...
		%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
	}

	return %weight;
}

function AIOAttackPlayer::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIAttackPlayer);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIOAttackPlayer::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//------------------------------------------------------------------------------------------------- AI Attack Player ---

function AIAttackPlayer::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetClient = %objective.targetClientId;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
        %task.chat = %objective.chat;

	//initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;
}

function AIAttackPlayer::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(15);
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);
	if (! %client.needEquipment)
	   %client.stepEngage(%task.targetClient);

	//even if we don't *need* equipemnt, see if we should buy some... 
	if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
	{
		//see if we could benefit from inventory
		%needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
		%result = AIFindClosestInventory(%client, %needArmor);
		%closestInv = getWord(%result, 0);
		%closestDist = getWord(%result, 1);
		if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
		{
			%distToTarg = %client.getPathDistance(%task.targetClient.player.getWorldBoxCenter());
			if (%distToTarg < 0 || %distToTarg > 100)
				%client.needEquipment = true;
		}
	}

	//mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();
}

function AIAttackPlayer::retire(%task, %client)
{
	//dissolve the human control link
	if (%task == %client.objectiveTask)
		aiReleaseHumanControl(%client.controlByHuman, %client);
}

function AIAttackPlayer::weight(%task, %client)
{
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   %task.setWeight(%task.baseWeight);
}

function AIAttackPlayer::monitor(%task, %client)
{
   //chat, first
   if (%task.sendMsg)
   {
      if (%task.sendMsgTime == 0)
         %task.sendMsgTime = getSimTime();
      else if (getSimTime() - %task.sendMsgTime > 7000)
      {
         %task.sendMsg = false;
         if (%client.isAIControlled())
	 {
	    if (%task.chat !$= "")
	    {
	       %chatMsg = getWord(%task.chat, 0);
	       %chatTemplate = getWord(%task.chat, 1);
	       if (%chatTemplate !$= "")
	          AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
	       else
		  AIMessageThread(%task.chat, %client, true);
	    }
	    else
               AIMessageThread("ChatSelfAttack", %client, -1);
	 }
      }
   }

   //second, buy the equipment
   if (%client.needEquipment)
   {
	   %task.setMonitorFreq(5);
		if (%task.equipment !$= "")
			%equipmentList = %task.equipment;
		else
			%equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
		if (%result $= "InProgress")
                {
                   //force a nervous reaction every 10 sec - Lagg...
                   if (getSimTime() - %task.buyInvTime > 10000)
                   {
                      %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
                      %task.buyInvTime = getSimTime();
                   }
                   return;
                }
		else if (%result $= "Finished")
		{
		   %task.setMonitorFreq(15);
			%client.needEquipment = false;
		   %client.stepEngage(%task.targetClient);
		}
		else if (%result $= "Failed")
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	      {
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
	      }
			return;
		}
   }
	//if we made it past the inventory buying, reset the inv time
	%task.buyInvTime = getSimTime();

	//cheap hack for now...   make the bot always know where you are...
	%client.clientDetected(%task.targetClient);

	//make sure we're still attacking...
   if (%client.getStepName() !$= "AIStepEngage")
	   %client.stepEngage(%task.targetClient);

	//make sure we're still attacking the right target
	%client.setEngageTarget(%task.targetClient);

   if (%client.getStepStatus() !$= "InProgress" && %task == %client.objectiveTask)
	{
      AIUnassignClient(%client);
      Game.AIChooseGameObjective(%client);
	}
}

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Defend Location +++

function AIODefendLocation::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   // if were playing CnH, check who owns this
   if (%this.targetObjectId > 0)
	{
   	if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team != %client.team)
	      return 0;
	}
   
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

	//do a quick check to disqualify this objective if it can't meet the minimum weight
	if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
	{
		if (%this.targetObjectId > 0 && %this.issuedByClientId == %client.controlByHuman)
		{
			if ($AIWeightHumanIssuedCommand < %minWeight)
				return 0;
		}
		else
			return 0;
	}

	%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);

   //if the object has been destroyed, reduce the weight
	if (%this.targetObjectId > 0)
	{

		//see if we were forced on the objective
		if (%this.issuedByClientId == %client.controlByHuman && %weight < $AIWeightHumanIssuedCommand)
			%weight = $AIWeightHumanIssuedCommand;

		//else see if the object has been destroyed - slight modification here - Lagg... 11-7-2003
	   //else if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamageState() $= "Destroyed")
           else if (!isObject(%this.targetObjectId) || %this.targetObjectId.isDisabled())
			%weight -= 320;
	}

        //special checks for camping in enemy base
        if (%this.mode $= "Camping1")
        {
           if (nameToId("Team2GeneratorLarge1").isEnabled() && nameToId("Team2GeneratorLarge2").isEnabled())
           {
              %this.weightLevel1 = "0";
	      %this.weightLevel2 = "0";
	      %this.weightLevel3 = "0";
	      %this.weightLevel4 = "0";
           }
           else
           {
              %this.weightLevel1 = "3150";
              %this.weightLevel2 = "0";
              %this.weightLevel3 = "0";
              %this.weightLevel4 = "0";
           }
        }
        else if (%this.mode $= "Camping2")
        {
           if (nameToId("MainBaseGen1").isEnabled())
           {
              %this.weightLevel1 = "0";
	      %this.weightLevel2 = "0";
	      %this.weightLevel3 = "0";
	      %this.weightLevel4 = "0";
           }
           else
           {
              %this.weightLevel1 = "3000";
              %this.weightLevel2 = "0";
              %this.weightLevel3 = "0";
              %this.weightLevel4 = "0";
           }
        }
        else if (%this.mode $= "Camping3")
        {
           if (nameToId("MainBaseGen2").isEnabled())
           {
              %this.weightLevel1 = "0";
	      %this.weightLevel2 = "0";
	      %this.weightLevel3 = "0";
	      %this.weightLevel4 = "0";
           }
           else
           {
              %this.weightLevel1 = "3000";
              %this.weightLevel2 = "0";
              %this.weightLevel3 = "0";
              %this.weightLevel4 = "0";
           }
        }
        else if (%this.mode $= "Camping4")
        {
           if (nameToId("Team2GeneratorLarge4").isEnabled())
           {
              %this.weightLevel1 = "0";
	      %this.weightLevel2 = "0";
	      %this.weightLevel3 = "0";
	      %this.weightLevel4 = "0";
           }
           else
           {
              %this.weightLevel1 = "3050";
              %this.weightLevel2 = "0";
              %this.weightLevel3 = "0";
              %this.weightLevel4 = "0";
           }
        }

	return %weight;
}

function AIODefendLocation::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIDefendLocation);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIODefendLocation::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Defend Location ---

function AIDefendLocation::initFromObjective(%task, %objective, %client)
{
	//initialize the task vars from the objective
   %task.baseWeight = %client.objectiveWeight;
	%task.targetObject = %objective.targetObjectId;
	if (%objective.Location !$= "")
	   %task.location = %objective.location;
	else
	   %task.location = %objective.targetObjectId.getWorldBoxCenter();

   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
	%task.chat = %objective.chat;
        %task.mode = %objective.mode;

	//initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;
   
   %task.engageTarget = -1;
}

function AIDefendLocation::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(15);
   %client.inPerimeter = false;
	%client.needEquipment = AINeedEquipment(%task.equipment, %client);

	//even if we don't *need* equipemnt, see if we should buy some... 
	if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
	{
		//see if we could benefit from inventory
		%needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
		%result = AIFindClosestInventory(%client, %needArmor);
		%closestInv = getWord(%result, 0);
		%closestDist = getWord(%result, 1);
		if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
		{
			%result = AIFindClosestEnemy(%client, 200, $AIClientLOSTimeout);
	      %closestEnemy = getWord(%result, 0);
		   %closestEnemydist = getWord(%result, 1);

			if (%closestEnemy <= 0 || (%closestEnemyDist > %closestDist * 1.5))
				%client.needEquipment = true;
		}
	}

	//mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();

	//set a flag to determine if the objective should be re-aquired when the object is destroyed
	%task.reassignOnDestroyed = false;
   //--------------------------------------------------- assume telporter - start -
   //if the MPB Teleporter is online - Lagg... 9-30-2003

   //first check for deployed MPB
   %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
   %closestMPB = getWord(%result, 0);
   %closestMPBDist = getWord(%result, 1);
      
   //next find the teleporter
   %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
   %closestTel = getWord(%result, 0);
   %closestTelDist = getWord(%result, 1);
      
   //now check for what would be closer - Lagg... 10-1-2003
   if (%closestMPB > 0 && %closestTel > 0)
   {
      %disToTarg = %client.getPathDistance(%task.location);
      %mpbDisToTarg = vectorDist(%closestMPB.getTransform(), %task.location);
         
      if (%closestTelDist < %closestMPBDist && %closestMPBDist < %disToTarg && %mpbDisToTarg < %disToTarg)
         %task.useTeleport = true;//new - Lagg... 10-1-2003
      else
         %task.useTeleport = false;             
   }
   //--------------------------------------------------- assume telporter - end -
   if (%task.mode $= "camping")
      error("AIDefendLocation::assume -FF gens are down- " @ getTaggedString(%client.name));
}

function AIDefendLocation::retire(%task, %client)
{
	%task.engageVehicle = -1;
	%client.setTargetObject(-1);
}

function AIDefendLocation::weight(%task, %client)
{
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

	%player = %client.player;
	if (!isObject(%player))
		return;

   %hasMissile = (%player.getInventory("MissileLauncher") > 0) && (%player.getInventory("MissileLauncherAmmo") > 0);

	//if we're defending with a missile launcher, our first priority is to take out vehicles...
	//see if we're already attacking a vehicle...
	if (%task.engageVehicle > 0 && isObject(%task.engageVehicle) && %hasMissile)
	{
		//set the weight
	   %task.setWeight(%task.baseWeight);
		return;
	}

	//search for a new vehicle to attack
	%task.engageVehicle = -1;
   %losTimeout = $AIClientMinLOSTime + ($AIClientLOSTimeout * %client.getSkillLevel());
	%result = AIFindClosestEnemyPilot(%client, 300, %losTimeout);
	%pilot = getWord(%result, 0);
	%pilotDist = getWord(%result, 1);

	//if we've got missiles, and a vehicle to attack...
	if (%hasMissile && AIClientIsAlive(%pilot))
	{
		%task.engageVehicle = %pilot.vehicleMounted;
		%client.needEquipment = false;
	}

	//otherwise look for a regular enemy to fight...
	else
	{
	   %result = AIFindClosestEnemyToLoc(%client, %task.location, 100, %losTimeout);
	   %closestEnemy = getWord(%result, 0);
	   %closestdist = getWord(%result, 1);
	   
	   //see if we found someone
	   if (%closestEnemy > 0)
	      %task.engageTarget = %closestEnemy;
	   else
		{
	      %task.engageTarget = -1;

			//see if someone is near me...
			%result = AIFindClosestEnemy(%client, 100, %losTimeout);
		   %closestEnemy = getWord(%result, 0);
		   %closestdist = getWord(%result, 1);
			if (%closestEnemy <= 0 || %closestDist > 70)
				%client.setEngageTarget(-1);
		}
	}

	//set the weight
   %task.setWeight(%task.baseWeight);
}

function AIDefendLocation::monitor(%task, %client)
{
   //first, buy the equipment
   if (%client.needEquipment)
   {
	   %task.setMonitorFreq(5);
		if (%task.equipment !$= "")
			%equipmentList = %task.equipment;
		else
			%equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
		if (%result $= "InProgress")
                {
                   //force a nervous reaction every 15 sec - Lagg...
                   if (getSimTime() - %task.buyInvTime > 15000)
                   {
                      %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
                      %task.buyInvTime = getSimTime();
                   }
                   return;
                }
		else if (%result $= "Finished")
		{
		   %task.setMonitorFreq(15);
			%client.needEquipment = false;
		}
		else if (%result $= "Failed")
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	      {
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
	      }
			return;
		}
   }
	//if we made it past the inventory buying, reset the inv time
	%task.buyInvTime = getSimTime();

	//chat
	if (%task.sendMsg)
	{
		if (%task.sendMsgTime == 0)
			%task.sendMsgTime = getSimTime();
		else if (getSimTime() - %task.sendMsgTime > 7000)
		{
			%task.sendMsg = false;
		   if (%client.isAIControlled())
			{
				if (%task.chat !$= "")
				{
					%chatMsg = getWord(%task.chat, 0);
					%chatTemplate = getWord(%task.chat, 1);
					if (%chatTemplate !$= "")
						AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
					else
						AIMessageThread(%task.chat, %client, -1);
				}
				else if (%task.targetObject > 0)
				{
					%type = %task.targetObject.getDataBlock().getName();
					if (%type $= "Flag")
						AIMessageThreadTemplate("DefendBase", "ChatSelfDefendFlag", %client, -1);
					else if (%type $= "GeneratorLarge")
						AIMessageThreadTemplate("DefendBase", "ChatSelfDefendGenerator", %client, -1);
					else if (%type $= "StationVehicle")
						AIMessageThreadTemplate("DefendBase", "ChatSelfDefendVehicle", %client, -1);
					else if (%type $= "SensorLargePulse")
						AIMessageThreadTemplate("DefendBase", "ChatSelfDefendSensors", %client, -1);
					else if (%type $= "SensorMediumPulse")
						AIMessageThreadTemplate("DefendBase", "ChatSelfDefendSensors", %client, -1);
					else if (%type $= "TurretBaseLarge")
						AIMessageThreadTemplate("DefendBase", "ChatSelfDefendTurrets", %client, -1);
				}
			}
		}
	}

   //--------------------------------------------------- monitor telporter - start -
   //are we using teleporter
   if (%task.useTeleport)
   {
      %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
      %closestMPB = getWord(%result, 0);
      %closestMPBDist = getWord(%result, 1);
      %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
      %closestTel = getWord(%result, 0);
      %closestTelDist = getWord(%result, 1);
      if (%closestMPB > 0 && %closestTel > 0)
      {
         //we are done teleporting
         if (%closestMPBDist < %closestTelDist)
         {
            //reset the clients inventory status
            if (%client.needEquipment)
            {
               %result = AIFindClosestInventory(%client, 0);
	       %closestInv = getWord(%result, 0);
               %client.invToUse = %closestInv;
               error("resetting client's inventory to use");
            }
            %task.useTeleport = false;
            return;
         }

         if (%closestTelDist < 2)
            %client.pressJump();
         else
         {
            %client.stepMove(%closestTel.getWorldBoxCenter(), 0.25);
            return;
         }
      }
      else
         %task.useTeleport = false;
   }
   //--------------------------------------------------- monitor telporter - end -       

	//if the defend location task has an object, set the "reset" flag
	if (%task == %client.objectiveTask && isObject(%task.targetObject))
	{
		//if (%task.targetObject.getDamageState() !$= "Destroyed")//modified - Lagg... 11-9-2003
                if (%task.targetObject.isDisabled())
			%task.reassignOnDestroyed = true;
		else
		{
			if (%task.reassignOnDestroyed)
			{
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
				return;
			}
		}
	}

	//first, check for a vehicle to engage
	if (%task.engageVehicle > 0 && isObject(%task.engageVehicle))
	{
		%client.stop();
		%client.clearStep();
		%client.setEngageTarget(-1);
		%client.setTargetObject(%task.engageVehicle, 300, "Missile");
	}
	else
	{
		//clear the target vehicle...
		%client.setTargetObject(-1);

	   //see if we're engaging a player
	   if (%client.getEngageTarget() > 0)
	   {
	      //too far, or killed the enemy - return home
	      if (%client.getStepStatus() !$= "InProgress" || %distance > 75)
	      {
	         %client.setEngageTarget(-1);
	         %client.stepMove(%task.location, 8.0);
	      } 
	   }
	   
	   //else see if we have a target to begin attacking
	   else if (%task.engageTarget > 0)
	      %client.stepEngage(%task.engageTarget);
	      
	   //else move to a random location around where we are defending
	   else if (%client.getStepName() !$= "AIStepIdlePatrol")
		{
			%dist = VectorDist(%client.player.getWorldBoxCenter(), %task.location);
			if (%dist < 10)
			{
				//dissolve the human control link and re-evaluate the weight
				if (%task == %client.objectiveTask)
				{
					if (aiHumanHasControl(%task.issuedByClient, %client))
					{
						aiReleaseHumanControl(%client.controlByHuman, %client);

						//should re-evaluate the current objective weight
						%inventoryStr = AIFindClosestInventories(%client);
						%client.objectiveWeight = %client.objective.weight(%client, %client.objectiveLevel, 0, %inventoryStr);
					}
				}

		      %client.stepIdle(%task.location);
			}
			else
		      %client.stepMove(%task.location, 8.0);
		}
	}

   //see if we're supposed to be engaging anyone...
   if (!AIClientIsAlive(%client.getEngageTarget()) && AIClientIsAlive(%client.shouldEngage))
      %client.setEngageTarget(%client.shouldEngage);
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Defense Patrol +++
//this is a new objective in beta. Requires a simgroup including 'markers' to set as locations to defend.

function AIODefensePatrol::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   // if were playing CnH, check who owns this
   if (%this.targetObjectId > 0)
	{
   	if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team != %client.team)
	      return 0;
	}
   
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

	//do a quick check to disqualify this objective if it can't meet the minimum weight
	if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
	{
		if (%this.targetObjectId > 0 && %this.issuedByClientId == %client.controlByHuman)
		{
			if ($AIWeightHumanIssuedCommand < %minWeight)
				return 0;
		}
		else
			return 0;
	}

	%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);

   //if the object has been destroyed, reduce the weight
	if (%this.targetObjectId > 0)
	{

		//see if we were forced on the objective
		if (%this.issuedByClientId == %client.controlByHuman && %weight < $AIWeightHumanIssuedCommand)
			%weight = $AIWeightHumanIssuedCommand;

		//else see if the object has been destroyed - slight modification here - Lagg... 11-7-2003
	   //else if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamageState() $= "Destroyed")
           else if (!isObject(%this.targetObjectId) || %this.targetObjectId.isDisabled())
			%weight -= 320;
	}

	return %weight;
}

function AIODefensePatrol::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIDefensePatrol);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIODefensePatrol::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Defense Patrol ---

function AIDefensePatrol::initFromObjective(%task, %objective, %client)
{
   //initialize the task vars from the objective
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   if (%objective.Location !$= "")
      %task.location = %objective.location;
   else
      %task.location = %objective.targetObjectId.getWorldBoxCenter();

   %task.equipment = %objective.equipment;
   %task.desiredEquipment = %objective.desiredEquipment;
   %task.buyEquipmentSet = %objective.buyEquipmentSet;
   %task.issuedByClient = %objective.issuedByClientId;
   %task.chat = %objective.chat;

   //initialize other task vars
   %task.sendMsg = true;
   %task.sendMsgTime = 0;
   
   %task.engageTarget = -1;

   %task.timeCheck = true;
}

function AIDefensePatrol::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(15);
   %client.inPerimeter = false;
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);

   //even if we don't *need* equipemnt, see if we should buy some... 
   if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
   {
      //see if we could benefit from inventory
      %needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
      %result = AIFindClosestInventory(%client, %needArmor);
      %closestInv = getWord(%result, 0);
      %closestDist = getWord(%result, 1);
      if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
      {
         %result = AIFindClosestEnemy(%client, 200, $AIClientLOSTimeout);
	 %closestEnemy = getWord(%result, 0);
	 %closestEnemydist = getWord(%result, 1);

	 if (%closestEnemy <= 0 || (%closestEnemyDist > %closestDist * 1.5))
            %client.needEquipment = true;
      }
   }

   //mark the current time for the buy inventory state machine
   %task.buyInvTime = getSimTime();

   //set a flag to determine if the objective should be re-aquired when the object is destroyed
   %task.reassignOnDestroyed = false;

   //--------------------------------------------------- assume telporter - start -
   //if the MPB Teleporter is online - Lagg... 9-30-2003

   //first check for deployed MPB
   %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
   %closestMPB = getWord(%result, 0);
   %closestMPBDist = getWord(%result, 1);
      
   //next find the teleporter
   %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
   %closestTel = getWord(%result, 0);
   %closestTelDist = getWord(%result, 1);
      
   //now check for what would be closer - Lagg... 10-1-2003
   if (%closestMPB > 0 && %closestTel > 0)
   {
      %disToTarg = %client.getPathDistance(%task.location);
      %mpbDisToTarg = vectorDist(%closestMPB.getTransform(), %task.location);
         
      if (%closestTelDist < %closestMPBDist && %closestMPBDist < %disToTarg && %mpbDisToTarg < %disToTarg)
         %task.useTeleport = true;//new - Lagg... 10-1-2003
      else
         %task.useTeleport = false;             
   }
   //--------------------------------------------------- assume telporter - end -

   //error("AIDefensePatrol::assume - client = " @ getTaggedString(%client.name));
}

function AIDefensePatrol::retire(%task, %client)
{
   %task.engageVehicle = -1;
   %client.setTargetObject(-1);
}

function AIDefensePatrol::weight(%task, %client)
{
   //update the task weight
   if (%task == %client.objectiveTask)
      %task.baseWeight = %client.objectiveWeight;//this will reaccess on destroyed if targetobjectid > 0

   %player = %client.player;
   if (!isObject(%player))
      return;

   %hasMissile = (%player.getInventory("MissileLauncher") > 0) && (%player.getInventory("MissileLauncherAmmo") > 0);

   //if we're defending with a missile launcher, our first priority is to take out vehicles...
   //see if we're already attacking a vehicle...
   if (%task.engageVehicle > 0 && isObject(%task.engageVehicle) && %hasMissile)
   {
      //set the weight
      %task.setWeight(%task.baseWeight);
		return;
   }

   //search for a new vehicle to attack
   %task.engageVehicle = -1;
   %losTimeout = $AIClientMinLOSTime + ($AIClientLOSTimeout * %client.getSkillLevel());
   %result = AIFindClosestEnemyPilot(%client, 300, %losTimeout);
   %pilot = getWord(%result, 0);
   %pilotDist = getWord(%result, 1);

   //if we've got missiles, and a vehicle to attack...
   if (%hasMissile && AIClientIsAlive(%pilot))
   {
      %task.engageVehicle = %pilot.vehicleMounted;
      %client.needEquipment = false;
   }

   //otherwise look for a regular enemy to fight...
   else
   {
      %result = AIFindClosestEnemyToLoc(%client, %task.location, 100, %losTimeout);
      %closestEnemy = getWord(%result, 0);
      %closestdist = getWord(%result, 1);
	   
      //see if we found someone
      if (%closestEnemy > 0)
         %task.engageTarget = %closestEnemy;
      else
      {
         %task.engageTarget = -1;

	 //see if someone is near me...
	 %result = AIFindClosestEnemy(%client, 100, %losTimeout);
		   %closestEnemy = getWord(%result, 0);
		   %closestdist = getWord(%result, 1);
			if (%closestEnemy <= 0 || %closestDist > 70)
				%client.setEngageTarget(-1);
      }
   }

   //set the weight
   %task.setWeight(%task.baseWeight);
}

function AIDefensePatrol::monitor(%task, %client)
{
   //error("AIDefensePatrol::monitor - client = " @ getTaggedString(%client.name));
   //first, buy the equipment
   if (%client.needEquipment)
   {
      %task.setMonitorFreq(5);
      if (%task.equipment !$= "")
         %equipmentList = %task.equipment;
      else
         %equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
      if (%result $= "InProgress")
      {
         //force a nervous reaction every 15 sec - Lagg...
         if (getSimTime() - %task.buyInvTime > 15000)
         {
            %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
            %task.buyInvTime = getSimTime();
         }
         return;
      }
      else if (%result $= "Finished")
      {
         %task.setMonitorFreq(15);
	 %client.needEquipment = false;
      }
      else if (%result $= "Failed")
      {
         //if this task is the objective task, choose a new objective
	 if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
	 return;
      }
   }
   //if we made it past the inventory buying, reset the inv time
   %task.buyInvTime = getSimTime();

   //chat
   if (%task.sendMsg)
   {
      if (%task.sendMsgTime == 0)
         %task.sendMsgTime = getSimTime();
      else if (getSimTime() - %task.sendMsgTime > 7000)
      {
         %task.sendMsg = false;
         if (%client.isAIControlled())
	 {
	    if (%task.chat !$= "")
	    {
	       %chatMsg = getWord(%task.chat, 0);
	       %chatTemplate = getWord(%task.chat, 1);
	       if (%chatTemplate !$= "")
                  AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
	       else
		  AIMessageThread(%task.chat, %client, -1);
	    }
	    else if (%task.targetObject > 0)
	    {
	       %type = %task.targetObject.getDataBlock().getName();
	       if (%type $= "Flag")
	          AIMessageThreadTemplate("DefendBase", "ChatSelfDefendFlag", %client, -1);
	       else if (%type $= "GeneratorLarge")
		  AIMessageThreadTemplate("DefendBase", "ChatSelfDefendBase", %client, -1);
	       else if (%type $= "StationVehicle")
		  AIMessageThreadTemplate("DefendBase", "ChatSelfDefendVehicle", %client, -1);
	       else if (%type $= "SensorLargePulse")
		  AIMessageThreadTemplate("DefendBase", "ChatSelfDefendSensors", %client, -1);
	       else if (%type $= "SensorMediumPulse")
		  AIMessageThreadTemplate("DefendBase", "ChatSelfDefendSensors", %client, -1);
	       else if (%type $= "TurretBaseLarge")
		  AIMessageThreadTemplate("DefendBase", "ChatSelfDefendTurrets", %client, -1);
	    }
         }
      }
   }

   //--------------------------------------------------- monitor telporter - start -
   //are we using teleporter
   if (%task.useTeleport)
   {
      %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
      %closestMPB = getWord(%result, 0);
      %closestMPBDist = getWord(%result, 1);
      %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
      %closestTel = getWord(%result, 0);
      %closestTelDist = getWord(%result, 1);
      if (%closestMPB > 0 && %closestTel > 0)
      {
         //we are done teleporting
         if (%closestMPBDist < %closestTelDist)
         {
            //reset the clients inventory status
            if (%client.needEquipment)
            {
               %result = AIFindClosestInventory(%client, 0);
	       %closestInv = getWord(%result, 0);
               %client.invToUse = %closestInv;
               error("resetting client's inventory to use");
            }
            %task.useTeleport = false;
            return;
         }

         if (%closestTelDist < 2)
            %client.pressJump();
         else
         {
            %client.stepMove(%closestTel.getWorldBoxCenter(), 0.25);
            return;
         }
      }
      else
         %task.useTeleport = false;
   }
   //--------------------------------------------------- monitor telporter - end -       

   //if the defend location task has an object, set the "reset" flag
   if (%task == %client.objectiveTask && isObject(%task.targetObject))
   {
      //if (%task.targetObject.getDamageState() !$= "Destroyed")
      if (%task.targetObject.isDisabled())
         %task.reassignOnDestroyed = true;
      else
      {
         if (%task.reassignOnDestroyed)
         {
            AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	    return;
         }
      }
   }

   //first, check for a vehicle to engage
   if (%task.engageVehicle > 0 && isObject(%task.engageVehicle))
   {
      %client.stop();
      %client.clearStep();
      %client.setEngageTarget(-1);
      %client.setTargetObject(%task.engageVehicle, 300, "Missile");
   }
   else
   {
      //clear the target vehicle...
      %client.setTargetObject(-1);

      //see if we're engaging a player
      if (%client.getEngageTarget() > 0)
      {
         //too far, or killed the enemy - return home
	 if (%client.getStepStatus() !$= "InProgress" || %distance > 100)
	 {
	    %client.setEngageTarget(-1);
	    %client.stepMove(%task.location, 4.0);
	 } 
      }
	   
      //else see if we have a target to begin attacking
      else if (%task.engageTarget > 0)
         %client.stepEngage(%task.engageTarget);
	      
      //else move to a random location around where we are defending
      else
      {
         %dist = VectorDist(%client.player.getWorldBoxCenter(), %task.location);
	 if (%dist < 6)
	 {
            //random time update task location - Lagg...
            if (%task.timeCheck)
            {
               %task.watTime = getSimTime();
               %task.ranTime = getRandom(0, 20) * 1000;//random time to stepidle at defense points
               %task.timeCheck = false;
            }
            if (getSimTime() > (%task.watTime + %task.ranTime))
            {
               %patrolSpots = nameToId(T2PatrolPath1);
               %count = %patrolSpots.getCount();
               %ranSpot = mFloor(getRandom(0, %count - 1));
               %task.location = %patrolSpots.getObject(%ranSpot).position;
               %task.timeCheck = true;
            }
            //dissolve the human control link and re-evaluate the weight
	    if (%task == %client.objectiveTask)
	    {
	       if (aiHumanHasControl(%task.issuedByClient, %client))
	       {
	          aiReleaseHumanControl(%client.controlByHuman, %client);

		  //should re-evaluate the current objective weight
		  %inventoryStr = AIFindClosestInventories(%client);
		  %client.objectiveWeight = %client.objective.weight(%client, %client.objectiveLevel, 0, %inventoryStr);
               }
            }
	    %client.stepIdle(%task.location);
	 }
	 else
            %client.stepMove(%task.location, 4.0, $AIModeWalk);
      }
   }

   //see if we're supposed to be engaging anyone...
   if (!AIClientIsAlive(%client.getEngageTarget()) && AIClientIsAlive(%client.shouldEngage))
      %client.setEngageTarget(%client.shouldEngage);
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Deploy Equipment +++
//modified here so bot will continue deploying if has equip and not get bumped
//can be set at a realistic weight now, like 3400               - Lagg... 4-12-2003
//If the function ShapeBaseImageData::testInvalidDeployConditions() changes at all, those changes need to be reflected here

function AIODeployEquipment::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

   //make sure the deploy objective is valid
   if (%this.isInvalid)
      return 0;

   //special check for camping in enemy base
   if (%this.mode $= "camping" && nameToId("Team2GeneratorLarge1").isEnabled() &&
     nameToId("Team2GeneratorLarge2").isEnabled())
      return 0; 

   //first, make sure we haven't deployed too many...
   if (%this.equipment $= "TurretOutdoorDeployable" || %this.equipment $= "TurretIndoorDeployable")
      %maxAllowed = countTurretsAllowed(%this.equipment);
   else
      %maxAllowed = $TeamDeployableMax[%this.equipment];

   if ($TeamDeployedCount[%client.team, %this.equipment] >= %maxAllowed)
      return 0;

   //now make sure there are no other items in the way...
   InitContainerRadiusSearch(%this.location, $MinDeployableDistance, $TypeMasks::VehicleObjectType |
  	                                             $TypeMasks::MoveableObjectType |
  	                                             $TypeMasks::StaticShapeObjectType |
  	                                             $TypeMasks::TSStaticShapeObjectType | 
  	                                             $TypeMasks::ForceFieldObjectType |
  	                                             $TypeMasks::ItemObjectType | 
  	                                             $TypeMasks::PlayerObjectType | 
  	                                             $TypeMasks::TurretObjectType);
      %objSearch = containerSearchNext();

      //make sure we're not invalidating the deploy location with the client's own player object
      if (%objSearch == %client.player)
         %objSearch = containerSearchNext();

      //did we find an object which would block deploying the equipment?
      if (isObject(%objSearch))
         return 0;

   //now run individual checks based on the equipment type...
   if (%this.equipment $= "TurretIndoorDeployable")
   {
      //check if there's another turret close to the deploy location
      InitContainerRadiusSearch(%this.location, $TurretIndoorSpaceRadius, $TypeMasks::StaticShapeObjectType);
      %found = containerSearchNext();
      if (isObject(%found))
      {
         %foundName = %found.getDataBlock().getName();
 	 if ((%foundName $= TurretDeployedFloorIndoor) || (%foundName $= "TurretDeployedWallIndoor") ||
           (%foundName $= "TurretDeployedCeilingIndoor") || (%foundName $= "TurretDeployedOutdoor"))
 	    return 0;
      }
 
      //now see if there are too many turrets in the area...
      %highestDensity = 0;
      InitContainerRadiusSearch(%this.location, $TurretIndoorSphereRadius, $TypeMasks::StaticShapeObjectType);
      %found = containerSearchNext();
      while (isObject(%found))
      {
         %foundName = %found.getDataBlock().getName();
 	 if ((%foundName $= "TurretDeployedFloorIndoor") || (%foundName $= "TurretDeployedWallIndoor") ||
           (%foundName $= "TurretDeployedCeilingIndoor") || (%foundName $= "TurretDeployedOutdoor"))
 	 {
 	    //found one
 	    %numTurretsNearby++;//+++++++++++++++++++++++++++++++++++++++++ ahh review this - Lagg... +++
            %nearbyDensity = testNearbyDensity(%found, $TurretIndoorSphereRadius);
 	    if (%nearbyDensity > %highestDensity)
 	       %highestDensity = %nearbyDensity;
         }
 	 %found = containerSearchNext();
      }
 
      if (%numTurretsNearby > %highestDensity)
         %highestDensity = %numTurretsNearby;
 
      //now see if the area is already saturated
      if (%highestDensity > $TurretIndoorMaxPerSphere)
         return 0;
   }
   //--------------------left off here - Lagg...+++++++++++++++++++++++++
 
 	else if (%this.equipment $= "TurretOutdoorDeployable")
 	{
 		//check if there's another turret close to the deploy location
 	   InitContainerRadiusSearch(%this.location, $TurretOutdoorSpaceRadius, $TypeMasks::StaticShapeObjectType);
 	   %found = containerSearchNext();
 	   if (isObject(%found))
 		{
 			%foundName = %found.getDataBlock().getName();     
 			if ((%foundName $= "TurretDeployedFloorIndoor") || (%foundName $= "TurretDeployedWallIndoor") || (%foundName $= "TurretDeployedCeilingIndoor") || (%foundName $= "TurretDeployedOutdoor"))
 				return 0;
 		}
 
 		//now see if there are too many turrets in the area...
 	   %highestDensity = 0;
 	   InitContainerRadiusSearch(%this.location, $TurretOutdoorSphereRadius, $TypeMasks::StaticShapeObjectType);
 	   %found = containerSearchNext();
 	   while (isObject(%found))
 	   {
 	      %foundName = %found.getDataBlock().getName();
 	      if ((%foundName $= "TurretDeployedFloorIndoor") || (%foundName $= "TurretDeployedWallIndoor") || (%foundName $= "TurretDeployedCeilingIndoor") || (%foundName $= "TurretDeployedOutdoor"))
 	      {
 				//found one
 				%numTurretsNearby++;
 
 				%nearbyDensity = testNearbyDensity(%found, $TurretOutdoorSphereRadius);
 				if (%nearbyDensity > %highestDensity)
 					%highestDensity = %nearbyDensity;     
 	      }
 	     %found = containerSearchNext();
 	   }
 
 		if (%numTurretsNearby > %highestDensity)
 			%highestDensity = %numTurretsNearby;
 
 		//now see if the area is already saturated
 		if (%highestDensity > $TurretOutdoorMaxPerSphere)
 			return 0;
 	}

	//check equipment requirement
	%needEquipment = AINeedEquipment(%this.equipment, %client);
	
   //if don't need equipment, see if we've past the "point of no return", and should continue regardless
 	if (! %needEquipment)
 	{
 		%needArmor = AIMustUseRegularInvStation(%this.equipment, %client);
 		%result = AIFindClosestInventory(%client, %needArmor);
 		%closestInv = getWord(%result, 0);
 		%closestDist = getWord(%result, 1);
 
 		//if we're too far from the inv to go back, or we're too close to the deploy location, force continue
 		//if (%closestDist > 50 && VectorDist(%client.player.getWorldBoxCenter(), %task.location) < 50)
                if (%closestDist > 20)
 		{
 			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
 			if (%weight < $AIWeightContinueDeploying)
 				%weight = $AIWeightContinueDeploying;
 			return %weight;
 		}
 	}

	//if this bot is linked to a human who has issued this command, up the weight
	if (%this.issuedByClientId == %client.controlByHuman)
	{
		//make sure we have the potential to reach the minWeight
		if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
		{
			if ($AIWeightHumanIssuedCommand < %minWeight)
				return 0;
			else
				%weight = $AIWeightHumanIssuedCommand;
		}
		else
		{
			// calculate the default...
			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
			if (%weight < $AIWeightHumanIssuedCommand)
				%weight = $AIWeightHumanIssuedCommand;
		}
	}
	else
	{
		//make sure we have the potential to reach the minWeight
		if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
			return 0;

		// calculate the default...
		%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
	}

	return %weight;
}

function AIODeployEquipment::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIDeployEquipment);
   %task = %client.objectiveTask;
   %task.initFromObjective(%this, %client);
}

function AIODeployEquipment::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//---------------------------------------------------------------------------------------------- AI Deploy Equipment ---

function AIDeployEquipment::initFromObjective(%task, %objective, %client)
{
	//initialize the task vars from the objective
   %task.baseWeight = %client.objectiveWeight;
   %task.location = %objective.location;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
	%task.chat = %objective.chat;

	//initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;
        %task.useTeleport = false;

	//use the Y-axis of the rotation as the desired direction of deployement,
	//and calculate a walk to point 3 m behind the deploy point. 
	%task.deployDirection = MatrixMulVector("0 0 0 " @ getWords(%objective.getTransform(), 3, 6), "0 1 0");
	%task.deployDirection = VectorNormalize(%task.deployDirection);
}

function AIDeployEquipment::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(15);
	
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);
   
   //mark the current time for the buy inventory state machine
   %task.buyInvTime = getSimTime();

   %task.passes = 0;
   %task.deployAttempts = 0;
   %task.checkObstructed = false;
   %task.waitMove = 0;

   //--------------------------------------------------- assume telporter - start -
   //if the MPB Teleporter is online - Lagg... 9-30-2003

   //first check for deployed MPB
   %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
   %closestMPB = getWord(%result, 0);
   %closestMPBDist = getWord(%result, 1);
      
   //next find the teleporter
   %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
   %closestTel = getWord(%result, 0);
   %closestTelDist = getWord(%result, 1);
      
   //now check for what would be closer - Lagg... 10-1-2003
   if (%closestMPB > 0 && %closestTel > 0)
   {
      %disToTarg = %client.getPathDistance(%task.location);
      %mpbDisToTarg = vectorDist(%closestMPB.getTransform(), %task.location);
         
      if (%closestTelDist < %closestMPBDist && %closestMPBDist < %disToTarg && %mpbDisToTarg < %disToTarg)
         %task.useTeleport = true;//new - Lagg... 10-1-2003
      else
         %task.useTeleport = false;             
   }
   //--------------------------------------------------- assume telporter - end -
}

function AIDeployEquipment::retire(%task, %client)
{
}

function AIDeployEquipment::weight(%task, %client)
{
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   %task.setWeight(%task.baseWeight);
}

function findTurretDeployPoint(%client, %location, %attempt)
{
   %player = %client.player;
	if (!isObject(%player))
		return "0 0 0";

	%feetPos = posFromTransform(%player.getTransform());
	%temp = VectorSub(%location, %feetPos);
   %temp2 = getWord(%temp, 0) @ " " @ getWord(%temp, 1) @ " 0";
	%facingVector = VectorNormalize(%temp2);
	%aimPoint = VectorAdd(%feetPos, %facingVector);
	//assume that there will be 10 attempts
	%height = getWord(%location, 2) + 1.0 - (0.2 * %attempt);
   %aimAt = getWord(%aimPoint, 0) @ " " @ getWord(%aimPoint, 1) @ " " @ %height;
   return %aimAt;
}

//modified range to deploy to make easier for outdoor inventory deployments - Lagg... - 4-12-2003
function AIDeployEquipment::monitor(%task, %client)
{
   //first, buy the equipment
   if (%client.needEquipment)
   {
	   %task.setMonitorFreq(5);
		if (%task.equipment !$= "")
			%equipmentList = %task.equipment;
		else
			%equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
		if (%result $= "InProgress")
                {
                   //force a nervous reaction every 15 sec - Lagg...
                   if (getSimTime() - %task.buyInvTime > 15000)
                   {
                      %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
                      %task.buyInvTime = getSimTime();
                   }
                   return;
                }
		else if (%result $= "Finished")
		{	
		   %task.setMonitorFreq(30);
         %client.needEquipment = false;
         //if we made it past the inventory buying, reset the inv time
	      %task.buyInvTime = getSimTime();
      }
      else if (%result $= "Failed")
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	      {
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
	      }
			return;
		}
   }

   //--------------------------------------------------- monitor telporter - start -
   //are we using teleporter
   if (%task.useTeleport)
   {
      %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
      %closestMPB = getWord(%result, 0);
      %closestMPBDist = getWord(%result, 1);
      %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
      %closestTel = getWord(%result, 0);
      %closestTelDist = getWord(%result, 1);
      if (%closestMPB > 0 && %closestTel > 0)
      {
         //we are done teleporting
         if (%closestMPBDist < %closestTelDist)
         {
            //reset the clients inventory status
            if (%client.needEquipment)
            {
               %result = AIFindClosestInventory(%client, 0);
	       %closestInv = getWord(%result, 0);
               %client.invToUse = %closestInv;
               error("resetting client's inventory to use");
            }
            %task.useTeleport = false;
            return;
         }

         if (%closestTelDist < 2)
            %client.pressJump();
         else
         {
            %client.stepMove(%closestTel.getWorldBoxCenter(), 0.25);
            return;
         }
      }
      else
         %task.useTeleport = false;
   }
   //--------------------------------------------------- monitor telporter - end -

   //make sure we still have equipment
		%client.needEquipment = AINeedEquipment(%task.equipment, %client);
      if (%client.needEquipment)
      {
         //if this task is the objective task, choose a new objective
         if (%task == %client.objectiveTask)
			{
            AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
				return;
			}
      }

   //make sure this was not deployed already
   InitContainerRadiusSearch(%task.location, $MinDeployableDistance, $TypeMasks::StaticShapeObjectType);
   %found = containerSearchNext();
   if (isObject(%found))
   {
      if (%found.team == %client.team)
      {
         if (%task == %client.objectiveTask)
	 {
            AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	    return;
	 }
      }
   }

	//chat
	if (%task.sendMsg)
	{
		if (%task.sendMsgTime == 0)
			%task.sendMsgTime = getSimTime();
		else if (getSimTime() - %task.sendMsgTime > 7000)
		{
			%task.sendMsg = false;
		   if (%client.isAIControlled())
			{
				if (%task.chat !$= "")
				{
					%chatMsg = getWord(%task.chat, 0);
					%chatTemplate = getWord(%task.chat, 1);
					if (%chatTemplate !$= "")
						AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
					else
						AIMessageThread(%task.chat, %client, -1);
				}
			}
		}
	}

   //see if we're supposed to be engaging anyone...
   if (AIClientIsAlive(%client.shouldEngage))
   {
	   %hasLOS = %client.hasLOSToClient(%client.shouldEngage);
	   %losTime = %client.getClientLOSTime(%client.shouldEngage);
	   if (%hasLOS || %losTime < 1000)
         %client.setEngageTarget(%client.shouldEngage);
      else
         %client.setEngageTarget(-1);
   }
   else
      %client.setEngageTarget(-1);

	//calculate the deployFromLocation
	%factor = -1 * (4 - (%task.passes * 0.5));//changed to 4m behind to improve proformance --- Lagg... 3-15-2003
   %task.deployFromLocation = VectorAdd(%task.location,VectorScale(%task.deployDirection, %factor));

	//see if we're within range of the deploy location
   %clLoc = %client.player.position;
   %distance = VectorDist(%clLoc, %task.deployFromLocation);
	%dist2D = VectorDist(%client.player.position, getWords(%task.deployFromLocation, 0, 1) SPC getWord(%client.player.position, 2));

	//set the aim when we get near the target...  this will be overwritten when we're actually trying to deploy
	if (%distance < 10 && %dist2D < 10)
      %client.aimAt(%task.location, 1000);

   if ((%client.pathDistRemaining(20) > %distance + 0.25) || %dist2D > 0.5)
	{
		%task.deployAttempts = 0;
		%task.checkObstructed = false;
		%task.waitMove = 0;
      %client.stepMove(%task.deployFromLocation, 0.25);
	   %task.setMonitorFreq(15);
		return;
	}
   
	if (%task.deployAttempts < 10 && %task.passes < 5 && !AIClientIsAlive(%client.getEngageTarget()))
	{
		//dissolve the human control link
		if (%task == %client.objectiveTask)
			aiReleaseHumanControl(%client.controlByHuman, %client);

	   %task.setMonitorFreq(3);
      %client.stop();
		if (%task.deployAttempts == 0)
			%deployPoint = %task.location;
		else
	      %deployPoint = findTurretDeployPoint(%client, %task.location, %task.deployAttempts);
      if(%deployPoint !$= "")
      {
         // we have possible point
         %task.deployAttempts++;
         %client.aimAt(%deployPoint, 2000);

			//try to deploy the backpack
			%client.deployPack = true;
         %client.lastDeployedObject = -1;
         %client.player.use(Backpack);
         
         // check if pack deployed
         if (isObject(%client.lastDeployedObject))
			{
				//see if there's a "repairObject" objective for the newly deployed thingy...
				if (%task == %client.objectiveTask)
				{
					%deployedObject = %client.lastDeployedObject;

					//search the current objective group and search for a "repair Object" task...
					%objective = %client.objective;

					//delete any previously associated "AIORepairObject" objective
					if (isObject(%objective.repairObjective))
					{
						AIClearObjective(%objective.repairObjective);
						%objective.repairObjective.delete();
						%objective.repairObjective = "";
					}

					//add the repair objective
	            %objective.repairObjective = new AIObjective(AIORepairObject)
		                              {
											      dataBlock = "AIObjectiveMarker";
		                                 weightLevel1 = %objective.weightLevel1 - 50;
		                                 weightLevel2 = 0;
		                                 description = "Repair the " @ %deployedObject.getDataBlock().getName();
													targetObjectId = %deployedObject;
													issuedByClientId = %client;
		                                 offense = false;
													defense = true;
		                                 equipment = "RepairPack";
		                              };
					%objective.repairObjective.deployed = true;
					%objective.repairObjective.setTransform(%objective.getTransform());
					%objective.repairObjective.group = %objective.group;
                                        MissionCleanup.add(%objective.repairObjective);

   //if is siege game we have to do this right - Lagg... 11-3-2003
   if (Game.class $= "SiegeGame")
   {
      //the objectives in $ObjectiveQ[1] are all offense objectives, $ObjectiveQ[2] has the defensive ones..
      if (%client.team == game.offenseTeam)
         $ObjectiveQ[1].add(%objective.repairObjective);
      else
         $ObjectiveQ[2].add(%objective.repairObjective);
   }
   else
      $ObjectiveQ[%client.team].add(%objective.repairObjective);


                              //changed to fix Siege gameType wrong Q error - Lagg... 11-5-2003
			      //MissionCleanup.add(%objective.repairObjective);
	            //$ObjectiveQ[%client.team].add(%objective.repairObjective);

					//finally, unassign the client so he'll go do something else...
			      AIUnassignClient(%client);
					Game.AIChooseGameObjective(%client);
				}

				//finished
				return;
			}
      }
	}
	else if (!%task.checkObstructed)
	{
		%task.checkObstructed = true;

	   //see if anything is in our way
	   InitContainerRadiusSearch(%task.location, 4, $TypeMasks::MoveableObjectType | $TypeMasks::VehicleObjectType |
																					                      $TypeMasks::PlayerObjectType);
	   %objSrch = containerSearchNext();
		if (%objSrch == %client.player)
		   %objSrch = containerSearchNext();
	   if (%objSrch)
			AIMessageThread("ChatMove", %client, -1);
	}
	else if (%task.waitMove < 5 && %task.passes < 5)
	{
		%task.waitMove++;

		//try another pass at deploying 
		if (%task.waitMove == 5)
		{
			%task.waitMove = 0;
			%task.passes++;
			%task.deployAttempts = 0;

			//see if we're *right* underneath the deploy point
			%deployDist2D = VectorDist(getWords(%client.player.position, 0, 1) @ "0", getWords(%task.location, 0, 1) @ "0");
			if (%deployDist2D < 0.25)
			{
				%client.pressjump();
				%client.deployPack = true;
	         %client.player.use(Backpack);

	         // check if pack deployed
	         if(%client.player.getMountedImage($BackpackSlot) == 0)
				{
					//don't add a "repairObject" objective for ceiling turrets
					if (%task == %client.objectiveTask)
					{
						AIUnassignClient(%client);
						Game.AIChooseGameObjective(%client);
					}
				}
			}
		}
	}
	else
	{
		//find a new assignment - and remove this one from the Queue
      if (%task == %client.objectiveTask)
		{
			error(%client SPC "from team" SPC %client.team SPC "is invalidating objective:" SPC %client.objective SPC "UNABLE TO DEPLOY EQUIPMENT");
                        error("client = " @ getTaggedString(%client.name));
			%client.objective.isInvalid = true;
	      AIUnassignClient(%client);
			Game.AIChooseGameObjective(%client);
		}
	}
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Deploy Vehicle +++
//This objective buys a MPB and deploys it at a selected desired location, follows a path of markers
//set in a simgroup named "T2MPBPath1" for team 2 or "T1MPBPath1" for team 1, also can have 2 paths
//choosen at random by just making another simgroup called "T2MPBPath2" or "T1MPBPath2" for each team - Lagg... 10-4-2003 

function AIODeployVehicle::weight(%this, %client, %level, %minWeight, %inventoryStr)
{ 
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

   //do a quick check to disqualify this objective if it can't meet the minimum weight
   if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
   {
      if (%this.targetObjectId > 0 && %this.issuedByClientId == %client.controlByHuman)
      {
         if ($AIWeightHumanIssuedCommand < %minWeight)
	    return 0;
      }
      else
         return 0;
   }

   //check for Vehicle station near buy of forget it - Lagg...
   %clVs = AIFindClosestVStation(%client);
   if (%clVs > 0)
   {
      %closestVs = getWord(%clVs, 0);
      %closestVsDist = getWord(%clVs, 1);
      if (%closestVsDist > 250)
         return 0;
   }
   else
      return 0;

   //check how many vehicles of this type are in the field
   %blockName = "MobileBaseVehicle";
   if (!vehicleCheck(%blockName, %client.team))
      return 0;

   %weight = AIODefault::weight(%this, %client, %level, %inventoryStr);

   return %weight;
}

function AIODeployVehicle::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIDeployVehicle);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIODeployVehicle::unassignClient(%this, %client)
{ 
   if(%client.pilotVehicle)
   {
      AIDisembarkVehicle(%client);
   }  
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Deploy Vehicle ---

function AIDeployVehicle::initFromObjective(%task, %objective, %client)
{
   //initialize the task vars from the objective
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   if (%objective.Location !$= "")
      %task.location = %objective.location;
   else
      %task.location = %objective.targetObjectId.getWorldBoxCenter();

   %task.equipment = %objective.equipment;
   %task.buyEquipmentSet = %objective.buyEquipmentSet;
   %task.desiredEquipment = %objective.desiredEquipment;
   %task.issuedByClient = %objective.issuedByClientId;
   %task.chat = %objective.chat;

   //initialize other task vars
   %task.sendMsg = true;
   %task.sendMsgTime = 0;
   %task.path = "";
   %task.offense = %objective.offense;//if task is offensive create def the MPB objective - some day - Lagg... *
   %task.unassignTime = 0;
}

function AIDeployVehicle::assume(%task, %client)
{
   %task.setWeightFreq(30);
   %task.setMonitorFreq(50);
   
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);

   //even if we don't *need* equipemnt, see if we should buy some... 
   if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
   {
      //see if we could benefit from inventory
      %needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
      %result = AIFindClosestInventory(%client, %needArmor);
      %closestInv = getWord(%result, 0);
      %closestDist = getWord(%result, 1);
      if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
      {
         %result = AIFindClosestEnemy(%client, 100, $AIClientLOSTimeout);
	 %closestEnemy = getWord(%result, 0);
	 %closestEnemydist = getWord(%result, 1);

	 if (%closestEnemy <= 0 || (%closestEnemyDist > %closestDist * 1.5))
	    %client.needEquipment = true;
      }
   }

   //mark the current time for the buy inventory state machine
   %task.buyInvTime = getSimTime();

   //reset the vehicle station wait time
   %client.vsWaitTime = "";

   //set the destination paths for each team and game type

   %team = %client.team;
   %random = mFloor(getRandom(1, 2));
   if (Game.class $= "SiegeGame")
   {
      if (%team == Game.offenseTeam)
      {         
         if (nameToId("Team2GeneratorLarge1").isEnabled() && nameToId("Team2GeneratorLarge2").isEnabled()) 
            %task.group = nameToId(T1MPBPath1);
         else if (isObject(nameToId(T1MPBPath2)))
            %task.group = nameToId(T1MPBPath2);
         else
            %task.group = nameToId(T1MPBPath1);
      }      
      else
      {
         if (%random == 1)
            %task.group = nameToId(T2MPBPath1);
         else if (isObject(nameToId(T2MPBPath2)))
            %task.group = nameToId(T2MPBPath2);
         else
            %task.group = nameToId(T2MPBPath1);
      }
   }
   else
   {
      if (%team == 1)
      {         
         if (%random == 1)
            %task.group = nameToId(T1MPBPath1);
         else if (isObject(nameToId(T1MPBPath2)))
            %task.group = nameToId(T1MPBPath2);
         else
            %task.group = nameToId(T1MPBPath1);
      }      
      else
      {
         if (%random == 1)
            %task.group = nameToId(T2MPBPath1);
         else if (isObject(nameToId(T2MPBPath2)))
            %task.group = nameToId(T2MPBPath2);
         else
            %task.group = nameToId(T2MPBPath1);
      }      
   }      
      
   %task.locationIndex = -1;
   %client.needVehicle = true;
}

function AIDeployVehicle::retire(%task, %client)
{
   if (aiClientIsAlive(%client))
   {
      %client.clearStep();
      if(%client.player.isMounted())
      {
         AIDisembarkVehicle(%client);
      }
   }
}

function AIDeployVehicle::weight(%task, %client)
{
   //let the monitor decide when to quit :)
   %task.setWeight(%task.baseWeight);
}

function AIDeployVehicle::monitor(%task, %client)
{   
   //first, buy equipment
   if (%client.needEquipment)
   {
      %task.setMonitorFreq(5);
      if (%task.equipment !$= "")
         %equipmentList = %task.equipment;
      else
         %equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
      if (%result $= "InProgress")
      {
         //force a nervous reaction every 30 sec - Lagg...
         if (getSimTime() - %task.buyInvTime > 30000)
         {
            %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
            %task.buyInvTime = getSimTime();
         }
         return;
      }
      else if (%result $= "Finished")
      {
         %task.setMonitorFreq(30);
	 %client.needEquipment = false;
      }
      else if (%result $= "Failed")
      {
         //if this task is the objective task, choose a new objective
	 if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
	 return;
      }
   }
   //if we made it past the inventory buying, reset the inv time
   %task.buyInvTime = getSimTime();

   //chat
   if (%task.sendMsg)
   {
      if (%task.sendMsgTime == 0)
         %task.sendMsgTime = getSimTime();
      else if (getSimTime() - %task.sendMsgTime > 7000)
      {
         %task.sendMsg = false;
         if (%client.isAIControlled())
	 {
	    if (%task.chat !$= "")
	    {
	       %chatMsg = getWord(%task.chat, 0);
	       %chatTemplate = getWord(%task.chat, 1);
	       if (%chatTemplate !$= "")
		  AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
	       else
		  AIMessageThread(%task.chat, %client, -1);
	    }
         }
      }
   }

   if (%client.needVehicle)
   {
      %clVs = AIFindClosestVStation(%client);
      if (%clVs > 0)
      {
         %closestVs = getWord(%clVs, 0);
         %closestVsDist = getWord(%clVs, 1);
      }
      if (%closestVs > 0 && %closestVsDist < 250 && !isObject(%client.player.mVehicle))
      {
         //If we're in light or medium armor, buy the vehicle - Lagg...
         if (%client.player.getArmorSize() !$= "Heavy")
         {        
            %task.baseWeight = $AIWeightVehicleMountedEscort + 1000;//set high - lagg...
            %task.setMonitorFreq(9);
            %buyResult = aiBuyVehicle(MobileBaseVehicle, %client);
         }
         else
         {
            //if ai in heavy armor buy equipment
            if (%task == %client.objectiveTask)
	    {
               %task.baseWeight = %client.objectiveWeight;
               %task.equipment = "Medium";
	       %task.buyEquipmentSet = "MediumRepairSet";
               %client.needEquipment = true;
               return;
	    }
         }
           
         if (%buyResult $= "InProgress")
         {
            //clear offensive tags
            %client.lastDamageClient = -1;
            %client.lastDamageTurret = -1;
            %client.shouldEngage = -1;
            %client.setEngageTarget(-1);
            %client.setTargetObject(-1);
            %client.engageRemeq = -1;
            %client.pickUpItem = -1;
	    return;
         }
         else if (%buyResult $= "Finished")
         {
            //mount the vehicle and go - Lagg...
	    %task.setMonitorFreq(50);
            %client.stop();
            %client.pilotVehicle = true;//needed to allow ai to get in pilot seat
                           
            //throw away any packs that won't fit
	    if (%client.player.getInventory(InventoryDeployable) > 0)
	       %client.player.throwPack();
	    else if (%client.player.getInventory(TurretIndoorDeployable) > 0)
	       %client.player.throwPack();
	    else if (%client.player.getInventory(TurretOutdoorDeployable) > 0)
	       %client.player.throwPack();
         }
         else if (%buyResult $= "Failed")
         {
            //if this task is the objective task, choose a new objective
	    if (%task == %client.objectiveTask)
	    {
               AIUnassignClient(%client);            
	       Game.AIChooseGameObjective(%client);
               return;
	    }
         }
      }
   }   

   //if we managed to get in vehicle then go
   if (%client.player.isMounted() && isObject(%client.player.mVehicle))
   {
      %vehicle = %client.vehicleMounted;
      if (%vehicle.getDataBlock().getName() !$= "mobileBaseVehicle")
      {
         error("opps we got in wrong vehicle");
         if (%task == %client.objectiveTask)
	 {
            if (%client.player.isMounted())
            {
               AIDisembarkVehicle(%client);//Hop off...
               %client.needVehicle = true;
               return;
            }
            //else
            //{
               //AIUnassignClient(%client);
	       //Game.AIChooseGameObjective(%client);
               //return;
            //}
	 }
      }

      //if we managed to get in vehicle then go
      if(%task.locationIndex < 0)
         %task.locationIndex++;

      //set the locations
      %location = %task.group.getObject(%task.locationIndex);
  
      //%client.setPilotPitchRange(-0.2, 0.05, 0.05);//use later +++
      %client.setPilotDestination(%location.position, 20);//slow
      
      //%vehicle = %Client.vehicleMounted;

      //else see if we're close enough to the current destination to choose the next
      %pos = %client.vehicleMounted.position;
      %pos2D = getWord(%pos, 0) SPC getWord(%pos, 1) SPC "0";
      %dest = %location.position;
      %dest2D = getWord(%dest, 0) SPC getWord(%dest, 1) SPC "0";

      if (VectorDist(%dest2D, %pos2D) < 35)
      {
         if (%task.group.getCount()-1 > %task.locationIndex)
            %task.locationIndex++;
	 else
         {                  
            //we are finished, choose a new objective
	    if (%task == %client.objectiveTask)
	    {               
               if (%client.vehicleMounted )
               {
                   %task.setMonitorFreq(9);
                   AIDisembarkVehicle(%client); //Hop off...
                   %client.stepMove(%location.position, 0.25); //Resume walking to our objective
                   %task.unassignTime = getSimTime();
                   return;
               }
	    }
         }
      }          
   }
   else if (!%client.player.isMounted())
   {
      //if we at end of path and we hopped out
      if (%task.group.getCount()-1 <= %task.locationIndex)
      {
         //give the MPB a chance to deploy
         if (getSimTime() - %task.unassignTime > 8000)
         {
            AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
            return;
         }
         return;
      }
            
      //did we fall off our bike? if so get back on!
      if (isObject(%client.player.mVehicle) && %client.player.mVehicle.getDamageState() !$= "Destroyed")
      {
         //throw away any packs that won't fit
	 if (%client.player.getInventory(InventoryDeployable) > 0)
	    %client.player.throwPack();
	 else if (%client.player.getInventory(TurretIndoorDeployable) > 0)
	    %client.player.throwPack();
	 else if (%client.player.getInventory(TurretOutdoorDeployable) > 0)
	    %client.player.throwPack();

         %client.pilotVehicle = true;//needed to let ai mount pilot seat
         %client.stepMove(%client.player.mVehicle.position, 0.25, $AIModeMountVehicle);
      }

      //did someone shoot our legs out? if so we are done!
      else if (isObject(%client.player.mVehicle) && %client.player.mVehicle.getDamageState() $= "Destroyed")
      {
         if (%task == %client.objectiveTask)
	 {
            AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
            return;
	 }				
      }
   }
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Destroy Object +++
//place objective marker in spot you want bot to stand and destroy for sentry turrets and hard to
//reach spots. basically same as attackobject, use this on generators/solar panels in siege game - Lagg... 3-26-2003

function AIODestroyObject::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   // if were playing CnH, check who owns this
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team == %client.team)
      return 0;      
   
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;
      
   //no need to attack if the object is already destroyed
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamageState() $= "Destroyed")
      return 0;
   else
	{
		//if this bot is linked to a human who has issued this command, up the weight
		if (%this.issuedByClientId == %client.controlByHuman)
		{
			//make sure we have the potential to reach the minWeight
			if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
			{
				if ($AIWeightHumanIssuedCommand < %minWeight)
					return 0;
				else
					%weight = $AIWeightHumanIssuedCommand;
			}
			else
			{
				// calculate the default...
				%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
				if (%weight < $AIWeightHumanIssuedCommand)
					%weight = $AIWeightHumanIssuedCommand;
			}
		}
		else
		{
			//make sure we have the potential to reach the minWeight
			if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
				return 0;

			// calculate the default...
			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
		}

                //lets give him some personallity on this one :) - Lagg...
                if ((findTargetInView(%client, 150)) == %this.targetObjectId)
                   %weight += 200;


		return %weight;
	}
}

function AIODestroyObject::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIdestroyObject);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIODestroyObject::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//------------------------------------------------------------------------------------------------ AI Destroy Object ---

function AIDestroyObject::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
        %task.location = %objective.location;

	//initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;
        %task.useTeleport = false;

              //pick a random equipment set...
	      %randNum = getRandom();
	      if (%randNum < 0.2)
              {
                    %task.desiredEquipment = "SensorJammerPack";
                    %task.buyEquipmentSet = "HeavyEnergySet";
              }
	      else if (%randNum < 0.4)
              {
                    %task.desiredEquipment = "SensorJammerPack";
                    %task.buyEquipmentSet = "MediumEnergyELF";
              } 
	      else if (%randNum < 0.6)
              {
                    %task.desiredEquipment = "CloakingPack";
                    %task.buyEquipmentSet = "LightCloakSet";
              }
              else if (%randNum < 0.8)
              {
                    %task.desiredEquipment = "ShieldPack";
                    %task.buyEquipmentSet = "HeavyShieldOff";
              }
              else
              {
                    %task.desiredEquipment = "AmmoPack";
                    %task.buyEquipmentSet = "mediumMissileSet";
              }
}

function AIDestroyObject::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(5);
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);
   %hasPlasma = (%client.player.getInventory("Plasma") > 0) && (%client.player.getInventory("PlasmaAmmo") > 0);
   if (%hasPlasma)
      %client.needEquipment = false;

   //even if we don't *need* equipemnt, see if we should buy some... 
   if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
   {
      //see if we could benefit from inventory
      %needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
      %result = AIFindClosestInventory(%client, %needArmor);
      %closestInv = getWord(%result, 0);
      %closestDist = getWord(%result, 1);
      if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
      {
         //find where we are
         %clientPos = %client.player.getWorldBoxCenter();
         %objPos = %task.targetObject.getWorldBoxCenter();
         %distToObject = %client.getPathDistance(%objPos);
			
	 if (%distToObject < 0 || %closestDist < %distToObject)
	    %client.needEquipment = true;
      }
   }

   //mark the current time for the buy inventory state machine
   %task.buyInvTime = getSimTime();

   //--------------------------------------------------- assume telporter - start -
   //if the MPB Teleporter is online - Lagg... 9-30-2003

   //first check for deployed MPB
   %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
   %closestMPB = getWord(%result, 0);
   %closestMPBDist = getWord(%result, 1);
      
   //next find the teleporter
   %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
   %closestTel = getWord(%result, 0);
   %closestTelDist = getWord(%result, 1);
      
   //now check for what would be closer - Lagg... 10-1-2003
   if (%closestMPB > 0 && %closestTel > 0)
   {
      %disToTarg = %client.getPathDistance(%task.targetObject.getTransform());
      %mpbDisToTarg = vectorDist(%closestMPB.getTransform(), %task.targetObject.getTransform());
         
      if (%closestTelDist < %closestMPBDist && %closestMPBDist < %disToTarg && %mpbDisToTarg < %disToTarg)
         %task.useTeleport = true;//new - Lagg... 10-1-2003
      else
         %task.useTeleport = false;             
   }
   //--------------------------------------------------- assume telporter - end -
}

function AIDestroyObject::retire(%task, %client)
{
   %client.setTargetObject(-1);
}

function AIDestroyObject::weight(%task, %client)
{
   //update the task weight
   if (%task == %client.objectiveTask)
      %task.baseWeight = %client.objectiveWeight;

   //let the monitor decide when to stop attacking
   %task.setWeight(%task.baseWeight);
}

function AIDestroyObject::monitor(%task, %client)
{
   //--------------------------------------------------- monitor telporter - start -
   //are we using teleporter
   if (%task.useTeleport)
   {
      %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
      %closestMPB = getWord(%result, 0);
      %closestMPBDist = getWord(%result, 1);
      %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
      %closestTel = getWord(%result, 0);
      %closestTelDist = getWord(%result, 1);
      if (%closestMPB > 0 && %closestTel > 0)
      {
         //we are done teleporting
         if (%closestMPBDist < %closestTelDist)
         {
            //reset the clients inventory status
            if (%client.needEquipment)
            {
               %result = AIFindClosestInventory(%client, 0);
	       %closestInv = getWord(%result, 0);
               %client.invToUse = %closestInv;
            }
            %task.useTeleport = false;
            return;
         }

         if (%closestTelDist < 2)
            %client.pressJump();
         else
         {
            %client.stepMove(%closestTel.getWorldBoxCenter(), 0.25);
            return;
         }
      }
      else
         %task.useTeleport = false;
   }
   //--------------------------------------------------- monitor telporter - end -

   //first, buy the equipment - if we really really need some :) - Lagg... - 4-6-2003
   %hasPlasma = (%client.player.getInventory("Plasma") > 0) && (%client.player.getInventory("PlasmaAmmo") > 0);
   if (%client.needEquipment && !%hasPlasma)
   {
	   %task.setMonitorFreq(5);
		if (%task.equipment !$= "")
			%equipmentList = %task.equipment;
		else
			%equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
		if (%result $= "InProgress")
                {
                   //force a nervous reaction every 15 sec - Lagg...
                   if (getSimTime() - %task.buyInvTime > 15000)
                   {
                      %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
                      %task.buyInvTime = getSimTime();
                   }
                   return;
                }
		else if (%result $= "Finished")
		{
		   %task.setMonitorFreq(15);
			%client.needEquipment = false;
		}
		else if (%result $= "Failed")
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	      {
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
	      }
			return;
		}
   }
	//if we made it past the inventory buying, reset the inv time
	%task.buyInvTime = getSimTime();
   
	//chat
	if (%task.sendMsg)
	{
		if (%task.sendMsgTime == 0)
			%task.sendMsgTime = getSimTime();
		else if (getSimTime() - %task.sendMsgTime > 7000)
		{
			%task.sendMsg = false;
		   if (%client.isAIControlled())
			{
				if (%task.chat !$= "")
				{
					%chatMsg = getWord(%task.chat, 0);
					%chatTemplate = getWord(%task.chat, 1);
					if (%chatTemplate !$= "")
						AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
					else
						AIMessageThread(%task.chat, %client, -1);
				}
				else if (%task.targetObject > 0)
				{
					%type = %task.targetObject.getDataBlock().getName();
					if (%type $= "GeneratorLarge")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackGenerator", %client, -1);
					else if (%type $= "SensorLargePulse")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
					else if (%type $= "SensorMediumPulse")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
					else if (%type $= "TurretBaseLarge")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackTurrets", %client, -1);
					else if (%type $= "StationVehicle")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackVehicle", %client, -1);
				}
			}
		}
	}

   //set the target object
   %outOfStuff = (AIAttackOutofAmmo(%client));
   if (isObject(%task.targetObject) && %task.targetObject.getDamageState() !$= "Destroyed" && !%outOfStuff)
   {
      %client.stepMove(%task.location);
      %targetLOS = "false";
      %mask = $TypeMasks::TerrainObjectType | $TypeMasks::InteriorObjectType;
      %targetLOS = !containerRayCast(%client.player.getWorldBoxCenter(), %task.targetObject.getWorldBoxCenter(), %mask, 0);
      if (%targetLOS)
         %client.setTargetObject(%task.targetObject, 40, "Destroy");
      else
      {
          %client.setTargetObject(-1);
          //%client.stepMove(%task.location);
      } 
   }
   else
   {
      %client.setTargetObject(-1);
      //%client.stop();
      
      //if this task is the objective task, choose a new objective
      if (%task == %client.objectiveTask)
      {
         AIUnassignClient(%client);
         Game.AIChooseGameObjective(%client);
      }
   }
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Escort Player +++
//modified escorter armor type allowed, rewritten all aivehicle escort stuff, included vehicleobjecttypes
//as potential targets if lazed by escortie.                                              - Lagg... - 4-12-2003

function AIOEscortPlayer::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client) || ! AIClientIsAlive(%this.targetClientId))
      return 0;

   //can't escort yourself
   if (%client == %this.targetClientId)
      return 0;

   //if vehicle mounted escort check for empty seats - Lagg... - 5-17-2003
   %targMounted = %this.targetClientId.player.ismounted();
   if (%targMounted > 0)
   {
      //%this.forceClientId = %client;//this should stop em getting bumped
      %vehicle = %this.targetClientId.vehicleMounted;
      %node = findAIEmptySeat(%vehicle, %client.player);

      if (%node < 0 && %client.vehicleMounted != %this.targetClientId.vehicleMounted)
         return 0;
   }

   //make sure the class is appropriate unless we are in a vehicle :) - Lagg...
   if (%this.forceClientId <= 0 && %this.issuedByClientId != %client.controlByHuman)
   {
      %targArmor = %this.targetClientId.player.getArmorSize();
      %myArmor = %client.player.getArmorSize();
      %targMounted = %this.targetClientId.player.ismounted();
                      
      if ((%targArmor $= "Light" && %myArmor !$= "Light" && !%targMounted)
        || (%targArmor $= "Medium" && %myArmor $= "Heavy" && !%targMounted))
	      return 0;
   }

   //can't bump a forced client from level 1
   if (%this.forceClientId > 0 && %this.forceClientId != %client && %level == 1)
      return 0;

   //check the range if target player is vehicle mounted - Lagg... - 5-17-2003
   if (%this.targetClientId.player.ismounted() && !%client.player.isMounted())
   {
      //lets check the range on this one
      if (vectorDist(%client.Player.getWorldBoxCenter(), %this.targetClientId.player.getWorldBoxCenter()) > 300)
         return 0;
   }

   //if this bot is linked to a human who has issued this command, up the weight
   if (%this.issuedByClientId == %client.controlByHuman)
   {
      //make sure we have the potential to reach the minWeight
		if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
		{
			if ($AIWeightHumanIssuedEscort < %minWeight)
				return 0;
			else
				%weight = $AIWeightHumanIssuedEscort;
		}
		else
		{
			// calculate the default...
			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
			if (%weight < $AIWeightHumanIssuedEscort)
				%weight = $AIWeightHumanIssuedEscort;
		}
	}
	else
	{
		//make sure we have the potential to reach the minWeight
		if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
			return 0;

		// calculate the default...
		%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
	}

	return %weight;
}

function AIOEscortPlayer::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIEscortPlayer);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIOEscortPlayer::unassignClient(%this, %client)
{
   //kill the escort objective
   if (%client.escort)
   {
      AIClearObjective(%client.escort);
      %client.escort.delete();
      %client.escort = "";
   }
   %client.repairObject = -1;
   %client.setTargetObject(-1);
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Escort Player ---

function AIEscortPlayer::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetClient = %objective.targetClientId;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
        %task.mode = %objective.mode;
	%task.issuedByClient = %objective.issuedByClientId;
	%task.forceClient = %objective.forceClientId;
        %task.chat = %objective.chat;

        //initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;
}

function AIEscortPlayer::assume(%task, %client)
{
   %task.setWeightFreq(20);//was 15
   %task.setMonitorFreq(20);//was 15
	%task.rangedTarget = false;
	if (%task == %client.objectiveTask && %client == %task.forceClient && %task.issuedByClient == %task.targetClient && !%task.targetClient.player.isMounted())
	{
	   %client.needEquipment = false;
           %client.mountVehicle = false;
	}
	else
	{
	   %client.needEquipment = AINeedEquipment(%task.equipment, %client);
		if (! %client.needEquipment)
		   %client.stepEscort(%task.targetClient);

		//even if we don't *need* equipemnt, see if we should buy some... 
		if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
		{
			//see if we could benefit from inventory
			%needArmor = AIMustUseRegularInvStation(%task.equipment, %client);
			%result = AIFindClosestInventory(%client, %needArmor);
			%closestInv = getWord(%result, 0);
			%closestDist = getWord(%result, 1);
			if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
			{
				//find where we are
				%clientPos = %client.player.getWorldBoxCenter();
				%targPos = %task.targetClient.player.getWorldBoxCenter();
				%distToTarg = %client.getPathDistance(%targPos);
				
				if (%closestDist < 50 && (%distToTarg < 0 || %distToTarg > 100))
					%client.needEquipment = true;
			}
		}
	}

	//mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();
}

function AIEscortPlayer::retire(%task, %client)
{
   if (aiClientIsAlive(%client))
   {
      %client.clearStep();
      if(%client.player.isMounted())
      {
         AIDisembarkVehicle(%client);
      }

      //clear the target object
      %client.setTargetObject(-1);

      //tailgunner stop repairing
      if (%client.player.getImageState($BackpackSlot) $= "Activate")
      {
         %client.player.use("RepairPack");
         %client.player.cycleWeapon();
      }

      //make sure we are standing up right
      %client.player.setActionThread("root");
   }
}

function AIEscortPlayer::weight(%task, %client)
{
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   //make sure we still have someone to escort
   if (!AiClientIsAlive(%task.targetClient))
   {
		%task.setWeight(0);
      return;
   }

   //always shoot at the closest person to the client being escorted
   %targetPos = %task.targetClient.player.getWorldBoxCenter();
   %losTimeout = $AIClientMinLOSTime + ($AIClientLOSTimeout * %client.getSkillLevel());
	%result = AIFindClosestEnemyToLoc(%client, %targetPos, 50, %losTimeout);
   %task.engageTarget = getWord(%result, 0);
   if (!AIClientIsAlive(%task.engageTarget))
   {
      if (AIClientIsAlive(%task.targetClient.lastDamageClient, %losTimeout) && getSimTime() - %task.targetClient.lastDamageTime < %losTimeout)
         %task.engageTarget = %task.targetClient.lastDamageClient;
   }
   if (!AIClientIsAlive(%task.engageTarget))
   {
      %myPos = %client.player.getWorldBoxCenter();
		%result = AIFindClosestEnemy(%client, 50, %losTimeout);
      %task.engageTarget = getWord(%result, 0);
   }

   //if both us and the person we're escorting are in a vehicle, set the weight high!
   if (%task.targetClient.player.isMounted() && %client.player.isMounted())
   {
      %vehicle = %client.vehicleMounted;
      if (%vehicle > 0 && isObject(%vehicle) && %vehicle.getDamagePercent() < 0.8)
      {
         %task.setWeight($AIWeightVehicleMountedEscort);
         AIProcessVehicle(%client); //call the vehicle process routine - Lagg...
      }
      else
         %task.setWeight(%task.baseWeight);
   }
   else
      %task.setWeight(%task.baseWeight);

   //find out if our escortee is lazing a target... 
   %task.missileTarget = -1;
   %targetCount = ServerTargetSet.getCount();
   for (%i = 0; %i < %targetCount; %i++)
   {
      %targ = ServerTargetSet.getObject(%i);
      if (%targ.sourceObject == %task.targetClient.player)
      {
         //find out which item is being targetted...
	 %targPoint = %targ.getWorldBoxCenter();
         InitContainerRadiusSearch(%targPoint, 10, $TypeMasks::TurretObjectType | $TypeMasks::StaticShapeObjectType |
           $TypeMasks::VehicleObjectType);
	 %task.missileTarget = containerSearchNext();
	 break;
      }
   }
}

function AIEscortPlayer::monitor(%task, %client)
{
   //make sure we still have someone to escort
   if (!AiClientIsAlive(%task.targetClient))
   {
      if (%task == %client.objectiveTask)
      {
         AIUnassignClient(%client);
	 Game.AIChooseGameObjective(%client);
      }
      return;
   }

   //chat first
   if (%task.sendMsg)
   {
      if (%task.sendMsgTime == 0)
         %task.sendMsgTime = getSimTime();
      else if (getSimTime() - %task.sendMsgTime > 7000)
      {
         %task.sendMsg = false;
         if (%client.isAIControlled())
	 {
	    if (%task.chat !$= "")
	    {
	       %chatMsg = getWord(%task.chat, 0);
	       %chatTemplate = getWord(%task.chat, 1);
	       if (%chatTemplate !$= "")
	          AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
	       else
		  AIMessageThread(%task.chat, %client, -1, true);
	    }
	    else
               AIMessageThreadTemplate("ChatTaskCover", "ChatTaskOnIt", %client, -1);
	 }
      }
   }

   //second, buy the equipment
   if (%client.needEquipment && !%client.player.isMounted())
   {
      %task.setMonitorFreq(5);
      if (%task.equipment !$= "")
         %equipmentList = %task.equipment;
      else
         %equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
      if (%result $= "InProgress")
         return;
      else if (%result $= "Finished")
      {
         %task.setMonitorFreq(20);//was 15
         %client.needEquipment = false;
	 %client.stepEscort(%task.targetClient);
	 %task.buyInvTime = getSimTime();
      }
      else if (%result $= "Failed")
      {
         //if this task is the objective task, choose a new objective
	 if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
	 return;
      }
   }
   
   //see if our target is mounted in a vehicle...
   if (%task.targetClient.player.isMounted())
   {
      %task.setWeightFreq(10);//was 15 - Lagg...
      %task.setMonitorFreq(10);//was 15 - Lagg...

      //find the passenger seat the bot will take
      %vehicle = %task.targetClient.vehicleMounted;
      if (!%client.isMounted)//added - *
         %node = findAIEmptySeat(%vehicle, %client.player);

      //make sure there is an empty seat
      if (%node < 0 && %client.vehicleMounted != %task.targetClient.vehicleMounted)
      {
         if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
         return;
      }
                 
      //find the passenger seat location...
      %slotPosition = %vehicle.getSlotTransform(%node);
      
      //make sure we're in the correct armor - assault tanks cannot have a heavy...
      if (%task.targetClient.vehicleMounted.getDataBlock().getName() $= "AssaultVehicle")
      {
         //if the bot is in a heavy, go get equipment - Lagg...
	 if (%client.player.getArmorSize() $= "Heavy")
	 {
            if (%task == %client.objectiveTask)
            {
               if (! %task.sendMsg && isObject(%vehicle))
               {
                  %task.sendMsg = true;
                  %task.sendMsgTime = getSimTime();
                  %task.chat = "ChatNeedHold";
               }               
               %task.equipment = "Medium FlareGrenade RepairPack";
	       %task.buyEquipmentSet = "MediumRepairSet";
               %client.needEquipment = true;
               return;
	    }
	 }

         //throw away any packs that won't fit
	 if (%client.player.getInventory(InventoryDeployable) > 0)
	    %client.player.throwPack();
	 else if (%client.player.getInventory(TurretIndoorDeployable) > 0)
	    %client.player.throwPack();
	 else if (%client.player.getInventory(TurretOutdoorDeployable) > 0)
	    %client.player.throwPack();
      }

      //make sure we're in the correct armor - bomber turrets cannot have a heavy...
      if (%task.targetClient.vehicleMounted.getDataBlock().getName() $= "BomberFlyer")
      {
         //bd seat
         %nodeBd = %vehicle.getMountNodeObject(1);

         //tg seat
         %nodeTg = %vehicle.getMountNodeObject(2);

         //if we are a tailgunner with a repair pack lets use it :) - Lagg...
         if (%nodeTg == %client.player)
         { 
            if (%client.getStepName() !$= "AIStepEscort")
               %client.stepEscort(%task.targetClient);

            //make sure we're still shooting...
            %client.setEngageTarget(%task.engageTarget);

            //see if we're supposed to be engaging anyone...
            if (!AIClientIsAlive(%client.getEngageTarget()) && AIClientIsAlive(%client.shouldEngage))
               %client.setEngageTarget(%client.shouldEngage);
            
            if (%vehicle.getDamagePercent() > 0 && %client.player.getInventory(RepairPack) > 0 &&                                       %client.getEngageTarget() <= 0)
	    {
               if (isObject(%vehicle) && (%client.player.getImageState($BackpackSlot) !$= "Activate"))               
                  %client.player.use("RepairPack");
               else if (isObject(%vehicle) && isObject(%client.player.getMountedImage($WeaponSlot))
                    && %client.player.getMountedImage($WeaponSlot).getName() $= "RepairGunImage")
               {
                  %client.aimAt(%vehicle.getWorldBoxCenter());
                  %client.repairObject = %vehicle;
                  %client.setTargetObject(%vehicle, 12, "Repair");
               }
               else
               {
                  %client.repairObject = -1;
                  %client.setTargetObject(-1);
                  %client.pressFire(-1);
               }
            }
            else
            {               
               %client.repairObject = -1;
               %client.setTargetObject(-1);
            }
	 } 

         //do we need a tailgunner - Lagg...
         if (! %client.escort && %nodeTg <= 0 && %task.mode !$= "Tailgunner")
         {
            
            //create the escort objective (require flares in this case...)
            if (%task == %client.objectiveTask)
               {
                  if (! %task.sendMsg && isObject(%vehicle))
                  {
                     %task.sendMsg = true;
                     %task.sendMsgTime = getSimTime();
                     %task.chat = "ChatNeedTailgunner";
                  }
               }

            %client.escort = new AIObjective(AIOEscortPlayer)
            {
               dataBlock = "AIObjectiveMarker";
                        weightLevel1 = $AIWeightVehicleMountedEscort;
                        weightLevel2 = 0;
                        description = "Escort " @ getTaggedString(%client.name);
                        targetClientId = %client;
                        issuedByHuman        = true;
                        mode = "Tailgunner";
                        offense = true;
                        chat = "ChatNeedRide";
                        equipment = "FlareGrenade";
	                buyEquipmentSet = "HeavyRepairSet";
            };
            MissionCleanup.add(%client.escort);
            //if is siege game we have to do this right - Lagg... 11-3-2003
            if (Game.class $= "SiegeGame")
            {
               //the objectives in $ObjectiveQ[1] are all offense objectives, $ObjectiveQ[2] has the defensive ones..
               if (%client.team == game.offenseTeam)
                  $ObjectiveQ[1].add(%client.escort);
               else
                  $ObjectiveQ[2].add(%client.escort);
            }
            else
               $ObjectiveQ[%client.team].add(%client.escort);
         }

         //throw away any packs that won't fit
	 if (%client.player.getInventory(InventoryDeployable) > 0 && %node == 1 && %task.mode !$= "Tailgunner")
	    %client.player.throwPack();
	 else if (%client.player.getInventory(TurretIndoorDeployable) > 0 && %node == 1 && %task.mode !$= "Tailgunner")
	    %client.player.throwPack();
	 else if (%client.player.getInventory(TurretOutdoorDeployable) > 0 && %node == 1 && %task.mode !$= "Tailgunner")
	    %client.player.throwPack();
      }
      //we mounted in a havoc
      else
      {
         if (%client.getStepName() !$= "AIStepEscort")
            %client.stepEscort(%task.targetClient);

         //make sure we're still shooting...
         %client.setEngageTarget(%task.engageTarget);

         //see if we're supposed to be engaging anyone...
         if (!AIClientIsAlive(%client.getEngageTarget()) && AIClientIsAlive(%client.shouldEngage))
            %client.setEngageTarget(%client.shouldEngage);
      }
		
      if (%client.player.isMounted())
      {
         %vehicle = %task.targetClient.vehicleMounted;

         //make sure it's the same vehicle :)
         if (%client.vehicleMounted != %vehicle)
            AIDisembarkVehicle(%client);
      }
      else if (!%client.player.isMounted())
      {
         if (%task.targetClient.vehicleMounted.getDataBlock().getName() $= "BomberFlyer")
         {
            if (%nodeBd <= 0 && %client.player.getArmorSize() $= "Heavy" && %task.mode !$= "Tailgunner")
            {
               if (%task == %client.objectiveTask)
               {
                  if (! %task.sendMsg && isObject(%vehicle))
                  {
                     %task.sendMsg = true;
                     %task.sendMsgTime = getSimTime();
                     %task.chat = "ChatNeedHold";                     
                  }
                  %task.equipment = "Medium";
	          %task.buyEquipmentSet = "MediumMissileSet";
                  %client.needEquipment = true;
                  return;
               }
            }
            if (%nodeBd > 0 && %nodeTg <= 0 && %client.player.getInventory(FlareGrenade) <= 0)
            {
               if (%task == %client.objectiveTask)
               {
                  if (! %task.sendMsg && isObject(%vehicle))
                  {
                     %task.sendMsg = true;
                     %task.sendMsgTime = getSimTime();
                     %task.chat = "ChatNeedHold";
                  }
                  %task.mode = "Tailgunner";
                  %task.equipment = "FlareGrenade RepairPack";
	          %task.buyEquipmentSet = "HeavyRepairSet";
                  %client.needEquipment = true;
                  return;
               }
            }
         }
         //mount the vehicle - heavily modified - Lagg... 10-16-2003
         //%client.stepMove(%slotPosition, 0.25, $AIModeMountVehicle);
         
         //first check if it is a bomber
         if (%vehicle.getdataBlock().getName() $= "BomberFlyer")
         {
            if (vectorDist(%client.Player.getWorldBoxCenter(), %task.targetClient.player.getWorldBoxCenter()) < 20)
            {
               %client.player.setActionThread(%vehicle.getDatablock().mountPose[0]);
               %client.stepMove(%slotPosition, 0.25, $AIModeMountVehicle);
               
               if (vectorDist(%client.Player.position, %slotPosition) < 6)
                  %client.player.setActionThread(%vehicle.getDatablock().mountPose[0]);
            }
            else
            {
               %client.player.setActionThread("root");
               %client.stepMove(%task.targetClient.vehicleMounted.getWorldBoxCenter(), 16, $AIModeExpress);
            }                     
         }
         //vehicle is a Tank 
         else if (%vehicle.getdataBlock().getName() $= "AssaultVehicle")
         {
            if (vectorDist(%client.Player.position, %slotPosition) < 10)
                  %client.player.setActionThread(sitting, true, true);
            if (vectorDist(%client.Player.getWorldBoxCenter(), %task.targetClient.player.getWorldBoxCenter()) < 18)
            {
               %client.player.setActionThread(sitting, true, true);
               %client.stepMove(%slotPosition, 0.25, $AIModeMountVehicle);

               if (vectorDist(%client.Player.position, %slotPosition) < 10)
                  %client.player.setActionThread(sitting, true, true);
            }
            else
            {
               %client.player.setActionThread("root");
               %client.stepMove(%task.targetClient.vehicleMounted.getWorldBoxCenter(), 14, $AIModeWalk);
            }
         }
         //else must be a havoc so mount regularly
         else
            %client.stepMove(%slotPosition, 0.25, $AIModeMountVehicle);
      }
   }
   else//------------------------------------------------------------------//target client is not mounted
   {
      //lets end the vehicle conversation stuff - Lagg...
      if (%task == %client.objectiveTask)
      {
         %task.sendMsg = false;
         %task.chat = "";
      }

      //disembark if we're mounted, but our target isn't (anymore)
      if (%client.player.isMounted())
         AIDisembarkVehicle(%client);

      //kill the escort (tailgunner) objective
      if (%client.escort)
      {
         AIClearObjective(%client.escort);
         %client.escort.delete();
         %client.escort = "";
      }
   //} moved down to bottom - *

      //END VEHICLE STUFF----------------------------------------------------- Lagg...
   
      //see if we're supposed to be mortaring/missiling something...
      //%client.player.setActionThread("root", true);
      %hasMortar = (%client.player.getInventory("Mortar") > 0) && (%client.player.getInventory("MortarAmmo") > 0);
      %hasMissile = (%client.player.getInventory("MissileLauncher") > 0) &&
        (%client.player.getInventory("MissileLauncherAmmo") > 0);

      if (!isObject(%task.engageTarget) && isobject(%task.missileTarget) && %task.missileTarget.getDamageState() !$=         "Destroyed" && (%hasMortar || %hasMissile))
      {
         if (%task.rangedTarget)
         {
            %client.stop();
	    %client.clearStep();
	    %client.setEngageTarget(-1);

            %type = %task.missileTarget.getDataBlock().getName();
	    if (%type $= "SensorLargePulse" && %hasMissile)
               %client.setTargetObject(%task.missileTarget, 300, "MissileNoLock");
	    else if (%type $= "SensorMediumPulse" && %hasMissile)
               %client.setTargetObject(%task.missileTarget, 300, "MissileNoLock");
	    else if (%type $= "TurretBaseLarge" && %hasMissile)
               %client.setTargetObject(%task.missileTarget, 300, "MissileNoLock");
            else if (%type $= "MobileBaseVehicle" && %hasMissile)
               %client.setTargetObject(%task.missileTarget, 300, "MissileNoLock");
	    else
               %client.setTargetObject(%task.missileTarget, 300, "Mortar");
         }
         else if (%client.getStepName() !$= "AIStepRangeObject")
         {
            if (%hasMortar || %hasMissile)
	       %client.stepRangeObject(%task.missileTarget, "BasicTargeter", 100, 300);
	    else
	       %client.stepRangeObject(%task.missileTarget, "DefaultRepairBeam", 20, 30);
         }
         else if (%client.getStepStatus() $= "Finished")
         %task.rangedTarget = true;
      }
      else
      {
        if ((%client.repairObject != %task.targetClient.vehicleMounted) || !%client.player.isMounted())
        {
           %task.rangedTarget = false;
           %client.setTargetObject(-1);
           //echo("set targetobject -1");
        }
        if (%client.getStepName() !$= "AIStepEscort")
           %client.stepEscort(%task.targetClient);

        //make sure we're still shooting...
        %client.setEngageTarget(%task.engageTarget);

        //see if we're supposed to be engaging anyone...
        if (!AIClientIsAlive(%client.getEngageTarget()) && AIClientIsAlive(%client.shouldEngage))
           %client.setEngageTarget(%client.shouldEngage);
      }
   }//was moved down from above *
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Laze Object +++
//fixed here so bots will acually use the targetting lazer for the right team :) - Lagg... - 4-12-2003
//modified last laze time and distance to client we laze for.
   
function AIOLazeObject::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

   //lets check the range on this one
   if (vectorDist(%client.Player.getWorldBoxCenter(), %this.getWorldBoxCenter()) < 80)
      return 0;
      
	//see if it's already being lazed
	%numTargets = ServerTargetSet.getCount();
	for (%i = 0; %i < %numTargets; %i++)
	{
		%targ = ServerTargetSet.getObject(%i);
		if (%targ.sourceObject != %client.player)
		{
			%targDist = VectorDist(%targ.getWorldBoxCenter(), %this.targetObjectId.getWorldBoxCenter());
			if (%targDist < 10)
			{
				%this.lastLazedTime = getSimTime();
				%this.lastLazedClient = %targ.sourceObject.client;
				break;
 			}
		}
	}
   if (%this.issuedByClientId > 0 && %this.issuedByClinetId == %client)
   {
       echo("cant laze target for your self IDIOT !");
       return 0;
   }

   //no need to laze if the object is already destroyed
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamageState() $= "Destroyed")
      return 0;
	else if (%this.targetObjectId.isHidden() || %this.targetObjectId.team == %client.team)
      return 0;      
	else if (getSimTime() - %this.lastLazedTime <= 10000 && %this.lastLazedClient == %client)
		return 0;
   else
	{
	   //set the base weight
	   switch (%level)
	   {
	      case 1:
	         %weight = %this.weightLevel1;
	      case 2:
	         %weight = %this.weightLevel2;
	      case 3:
	         %weight = %this.weightLevel3;
	      default:
	         %weight = %this.weightLevel4;
	   }
   
	   //check Affinity
	   if (ClientHasAffinity(%this, %client))
	      %weight += 100;
      
		//for now, do not deviate from the current assignment to laze a target, if you don't
		//already have a targeting laser.
		%needEquipment = AINeedEquipment(%this.equipment, %client);
		if (!%needEquipment)
			%weight += 100;
		else if (!aiHumanHasControl(%client.controlByHuman, %client))
			return 0;

		//see if this client is close to the issuing client
		if (%this.issuedByClientId > 0)
		{
			if (! AIClientIsAlive(%this.issuedByClientId))
				return 0;

		   %distance = %client.getPathDistance(%this.issuedByClientId.player.getWorldBoxCenter());
			if (%distance < 0)
				%distance = 32767;

		   //see if we're over 300 m
		   if (%distance > 300)
		      return 0;

                   //see if we're within 200 m
		   if (%distance < 200)
		      %weight += 30;

		   //see if we're within 90 m
		   if (%distance < 90)
		      %weight += 30;

		   //see if we're within 45 m
		   if (%distance < 45)
		      %weight += 30;
		}

		//now, if this bot is linked to a human who has issued this command, up the weight
		if (%this.issuedByClientId == %client.controlByHuman && %weight < $AIWeightHumanIssuedCommand)
			%weight = $AIWeightHumanIssuedCommand;

		return %weight;
	}
}

function AIOLazeObject::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AILazeObject);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIOLazeObject::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Laze Object ---

function AILazeObject::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
	%task.msgAck = true;
	%task.msgFire = true;
}

function AILazeObject::assume(%task, %client)
{
   %task.setWeightFreq(30);
   %task.setMonitorFreq(30);
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);
   
   //clear the target object, and range it
   %client.setTargetObject(-1);
	if (! %client.needEquipment)
	   %client.stepRangeObject(%task.targetObject, "BasicTargeter", 80, 300, %task.issuedByClient.player.getWorldBoxCenter());

	//set up some task vars
	%task.celebrate = false;
	%task.waitTimerMS = 0;

	//mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();
}

function AILazeObject::retire(%task, %client)
{
   %client.setTargetObject(-1);
}

function AILazeObject::weight(%task, %client)
{
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   //let the monitor decide when to stop lazing
   %task.setWeight(%task.baseWeight);
}

function AILazeObject::monitor(%task, %client)
{
   //first, buy the equipment
   if (%client.needEquipment)
   {
	   %task.setMonitorFreq(5);
		if (%task.equipment !$= "")
			%equipmentList = %task.equipment;
		else
			%equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
		if (%result $= "InProgress")
                {
                   //force a nervous reaction every 30 sec - Lagg...
                   if (getSimTime() - %task.buyInvTime > 30000)
                   {
                      %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
                      %task.buyInvTime = getSimTime();
                   }
                   return;
                }
		else if (%result $= "Finished")
		{
		   %task.setMonitorFreq(30);
			%client.needEquipment = false;
		   %client.stepRangeObject(%task.targetObject, "BasicTargeter", 80, 300);
		}
		else if (%result $= "Failed")
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	      {
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
	      }
			return;
		}
   }
	//if we made it past the inventory buying, reset the inv time
	%task.buyInvTime = getSimTime();
   
   //set the target object
   if (isObject(%task.targetObject) && %task.targetObject.getDamageState() !$= "Destroyed")
   {
      //make sure we still have equipment
		%client.needEquipment = AINeedEquipment(%task.equipment, %client);
      if (%client.needEquipment)
      {
         //if this task is the objective task, choose a new objective
         if (%task == %client.objectiveTask)
			{
            AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
				return;
			}
      }
      
		//look to see if anyone else is also targetting...
		%foundTarget = false;
		%numTargets = ServerTargetSet.getCount();
		for (%i = 0; %i < %numTargets; %i++)
		{
			%targ = ServerTargetSet.getObject(%i);
			if (%targ.sourceObject != %client.player)
			{
				%targDist = VectorDist(%targ.getWorldBoxCenter(), %task.targetObject.getWorldBoxCenter());
				if (%targDist < 60)//was 10 - Lagg...
				{
					%foundTarget = true;
					break;
				}
			}
		}

		if (%foundTarget)
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	         AIUnassignClient(%client);
		}

      else if (%client.getStepStatus() $= "Finished")
		{
			//dissolve the human control link
			if (%task == %client.objectiveTask)
				aiReleaseHumanControl(%client.controlByHuman, %client);

         %client.setTargetObject(%task.targetObject, 300, "Laze");
			%task.celebrate = true;
			%task.waitTimerMS = 0;

			//make sure we only say "fire..." once
			if (%task.msgFire)
			{
				AIMessageThread("ChatTargetFire", %client, -1);
				%task.msgFire = false;
			}
		}
      else
		{
			%client.aimAt(%task.targetObject.getWorldBoxCenter(), 1000);
         %client.setTargetObject(-1);
		}
   }
   else
   {
      %client.setTargetObject(-1);

		if (%task.celebrate)
		{
			if (%task.waitTimerMS == 0)
			{
				//add in a "woohoo"!  :)
				//choose the animation range
				%minCel = 3;
				%maxCel = 8;

				//pick a random sound
				if (getRandom() > 0.25)
					%sound = "gbl.awesome";
				else if (getRandom() > 0.5)
					%sound = "gbl.thanks";
				else if (getRandom() > 0.75)
					%sound = "gbl.nice";
				else
					%sound = "gbl.rock";
			  	%randTime = mFloor(getRandom() * 500) + 1;
			   schedule(%randTime, %client, "AIPlayAnimSound", %client, %task.targetObject.getWorldBoxCenter(), %sound, %minCel, %maxCel, 0);

				//set the timer
            %task.waitTimerMS = getSimTime();
			}

			//else see if the celebration period is over
			else if (getSimTime() - %task.waitTimerMS > 3000)
				%task.celebrate = false;
		}
		else
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
			{
	         AIUnassignClient(%client);
				Game.AIChooseGameObjective(%client);
			}
		}
   }
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO MAttack Location +++
//modified version of AIAttackLocation, could be called AIMortarSpamLocation :) - Lagg...

function AIOMAttackLocation::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;
      
   //now, if this bot is linked to a human who has issued this command, up the weight
   if (%this.issuedByClientId == %client.controlByHuman)
   {
      //make sure we have the potential to reach the minWeight
      if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
      {
         if ($AIWeightHumanIssuedCommand < %minWeight)
	    return 0;
	 else
	    %weight = $AIWeightHumanIssuedCommand;
      }
      else
      {
         // calculate the default...
	 %weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
	 if (%weight < $AIWeightHumanIssuedCommand)
	    %weight = $AIWeightHumanIssuedCommand;
      }
   }
   else
   {
      //make sure we have the potential to reach the minWeight
      if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
         return 0;

      // calculate the default...
      %weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
   }
   return %weight;
}

function AIOMAttackLocation::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIMAttackLocation);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIOMAttackLocation::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI MAttack Location ---

function AIMAttackLocation::initFromObjective(%task, %objective, %client)
{
        //initialize the task vars from the objective
   %task.baseWeight = %client.objectiveWeight;
   %task.location = %objective.location;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
	%task.chat = %objective.chat;

	//initialize other task vars
	%task.sendMsg = false;
	%task.sendMsgTime = 0;
   %task.engageTarget = -1;
}

function AIMAttackLocation::assume(%task, %client)
{
   %task.setWeightFreq(30);
   %task.setMonitorFreq(30);
	%client.needEquipment = AINeedEquipment(%task.equipment, %client);

	//even if we don't *need* equipemnt, see if we should buy some... 
	if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
	{
		//see if we could benefit from inventory
		%needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
		%result = AIFindClosestInventory(%client, %needArmor);
		%closestInv = getWord(%result, 0);
		%closestDist = getWord(%result, 1);
		if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
		{
			%result = AIFindClosestEnemyToLoc(%client, %task.location, 50, $AIClientLOSTimeout);
	      %closestEnemy = getWord(%result, 0);

			if (%closestEnemy <= 0)
				%client.needEquipment = true;
		}
	}

	//mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();

	%task.snipeLocation = "";
	%task.hideLocation = "";
	%task.moveToPosition = true;
	%task.moveToSnipe = false;
	%task.nextSnipeTime = 0;
}

function AIMAttackLocation::retire(%task, %client)
{
}

function AIMAttackLocation::weight(%task, %client)
{
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

	//if we're a sniper, we're going to cheat, and see if there are clients near the attack location
        %losTimeout = $AIClientMinLOSTime + ($AIClientLOSTimeout * %client.getSkillLevel());
	%distToLoc = VectorDist(%client.player.getWorldBoxCenter(), %task.location);
	if (((%client.player.getInventory(SniperRifle) > 0 && %client.player.getInventory(EnergyPack) > 0) ||
            (%client.player.getInventory(Mortar) > 0 && %client.player.getInventory(MortarAmmo) > 0)) && %distToLoc > 100)
		%result = AIFindClosestEnemyToLoc(%client, %task.location, 100, $AIClientLOSTimeout, true);

	//otherwise, do the search normally.  (cheat ignores LOS)...
	else
		%result = AIFindClosestEnemyToLoc(%client, %task.location, 100, %losTimeout, false);

   %closestEnemy = getWord(%result, 0);
   %closestdist = getWord(%result, 1);
   %task.setWeight(%task.baseWeight);
   
   //see if we found someone
   if (%closestEnemy > 0)
      %task.engageTarget = %closestEnemy;
   else
      %task.engageTarget = -1;
}

//---------------------------------------------------------------------
//modified range for bot sniper to attack location - Lagg... 4-12-2003
function AIMAttackLocation::monitor(%task, %client)
{
   //first, buy the equipment
   if (%client.needEquipment)
   {
      %task.setMonitorFreq(5);
      if (%task.equipment !$= "")
         %equipmentList = %task.equipment;
      else
	 %equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
      if (%result $= "InProgress")
      {
         //force a nervous reaction every 15 sec - Lagg...
         if (getSimTime() - %task.buyInvTime > 15000)
         {
            %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
            %task.buyInvTime = getSimTime();
         }
         return;
      }
      else if (%result $= "Finished")
      {
         %task.setMonitorFreq(30);
	 %client.needEquipment = false;
      }
      else if (%result $= "Failed")
      {
         //if this task is the objective task, choose a new objective
	 if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
	 return;
      }
   }
   //if we made it past the inventory buying, reset the inv time
   %task.buyInvTime = getSimTime();

   //chat
   if (%task.sendMsg)
   {
      if (%task.sendMsgTime == 0)
         %task.sendMsgTime = getSimTime();
      else if (getSimTime() - %task.sendMsgTime > 7000)
      {
         %task.sendMsg = false;
         if (%client.isAIControlled())
	 {
	    if (%task.chat !$= "")
	    {
	       %chatMsg = getWord(%task.chat, 0);
	       %chatTemplate = getWord(%task.chat, 1);
	       if (%chatTemplate !$= "")
	          AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
	       else
	          AIMessageThread(%task.chat, %client, -1);
	    }
	    else
	       AIMessageThreadTemplate("AttackBase", "ChatSelfAttack", %client, -1);
	 }
      }
   }

   //make sure we still have equipment
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);
   if (%client.needEquipment)
   {
      //if this task is the objective task, choose a new objective
      if (%task == %client.objectiveTask)
      {
         AIUnassignClient(%client);
	 Game.AIChooseGameObjective(%client);
	 return;
      }
   }

   //how far are we from the location we're defending
   %myPos = %client.player.getWorldBoxCenter();
   %distance = %client.getPathDistance(%task.location);
   %hasSniper = %client.player.getInventory(SniperRifle) > 0 && %client.player.getInventory(EnergyPack) > 0;
   %hasMortar = %client.player.getInventory(Mortar) > 0 && %client.player.getInventory(MortarAmmo) > 0;
   if (%distance < 0)
      %distance = 32767;

   if (%hasSniper || %hasMortar)
   {
      //first, find an LOS location
      if (%task.snipeLocation $= "")
      {
         %task.snipeLocation = %client.getLOSLocation(%task.location, 150, 300);//was 150-200 - Lagg...
	 %task.hideLocation = %client.getHideLocation(%task.location, VectorDist(%task.location, %task.snipeLocation), %task.snipeLocation, 1); 
	 %client.stepMove(%task.hideLocation, 4.0);
         %task.moveToPosition = true;
      }
      else
      {
         //see if we can acquire a target
	 %energy = %client.player.getEnergyPercent();
         %distToSnipe = VectorDist(%task.snipelocation, %client.player.getWorldBoxCenter());
	 %distToHide = VectorDist(%task.hidelocation, %client.player.getWorldBoxCenter());

	 //until we're in position, we can move using the AIModeExpress, after that, we only want to walk...
	 if (%task.moveToPosition)
	 {
	    if (%distToHide < 4.0)
	    {
	       //dissolve the human control link
	       if (%task == %client.objectiveTask)
	       {
	          if (aiHumanHasControl(%task.issuedByClient, %client))
		  {
		     aiReleaseHumanControl(%client.controlByHuman, %client);

		     //should re-evaluate the current objective weight
		     %inventoryStr = AIFindClosestInventories(%client);
		     %client.objectiveWeight = %client.objective.weight(%client, %client.objectiveLevel, 0, %inventoryStr);
		  }
	       }
               %task.moveToPosition = false;
	    }
         }
         else if (%task.moveToSnipe)
	 {
	    if (((%hasSniper && %energy > 0.75) || %hasMortar) && %client.getStepStatus() $= "Finished")
	    {
               %client.stepMove(%task.snipeLocation, 4.0, $AIModeWalk);
	       %client.setEngageTarget(%task.engageTarget);
	    }
	    else if (%hasSniper && %energy < 0.4)
	    {
               %client.setEngageTarget(-1);
	       %client.stepMove(%task.hideLocation, 4.0);
	       //%task.nextSnipeTime = getSimTime() + 4000 + (getRandom() * 4000);
               %task.nextSnipeTime = getSimTime() + 1000 + (getRandom() * 2000);
	       %task.moveToSnipe = false;
	    }
         }
         else if (((%hasSniper && %energy > 0.5) || %hasMortar) && %task.engageTarget > 0 && getSimTime() > %task.nextSnipeTime)
	 {
            %task.sendMsg = true;
            %client.stepRangeObject(%task.engageTarget.player.getWorldBoxCenter(), "BasicSniperShot", 150, 300, %task.snipelocation);
            if (! %hasMortar)
	       %client.aimAt(%task.engageTarget.player.getWorldBoxCenter(), 8000);
	    %task.moveToSnipe = true;
	 }
      }
   }
   //else we don't have sniper or mortar stuff so attack regular like :( - Lagg...
   else
   {
      //else see if we have a target to begin attacking
      if (%client.getEngageTarget() <= 0 && %task.engageTarget > 0)
         %client.stepEngage(%task.engageTarget);

      //else move to the location we're attacking
      else if (%client.getEngageTarget() <= 0)
      {
         %client.stepMove(%task.location, 8.0);
	 if (VectorDist(%client.player.position, %task.location) < 10)
	 {
	    //dissolve the human control link
	    if (%task == %client.objectiveTask)
	    {
	       if (aiHumanHasControl(%task.issuedByClient, %client))
	       {
		  aiReleaseHumanControl(%client.controlByHuman, %client);

		  //should re-evaluate the current objective weight
		  %inventoryStr = AIFindClosestInventories(%client);
		  %client.objectiveWeight = %client.objective.weight(%client, %client.objectiveLevel, 0, %inventoryStr);
	       }
	    }
	 }
      }
   }

   //see if we're supposed to be engaging anyone...
   if (!AIClientIsAlive(%client.getEngageTarget()) && AIClientIsAlive(%client.shouldEngage))
      %client.setEngageTarget(%client.shouldEngage);
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO MDestroy Object +++
//place objective marker in spot you want bot to stand and destroy for sentry turrets and hard to
//reach spots. basically same as destroy object but with mortars :)           - Lagg... 3-26-2003

function AIOMDestroyObject::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   // if were playing CnH, check who owns this
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team == %client.team)
      return 0;      
   
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;
      
   //no need to attack if the object is already destroyed
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamageState() $= "Destroyed")
      return 0;
   else
	{
		//if this bot is linked to a human who has issued this command, up the weight
		if (%this.issuedByClientId == %client.controlByHuman)
		{
			//make sure we have the potential to reach the minWeight
			if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
			{
				if ($AIWeightHumanIssuedCommand < %minWeight)
					return 0;
				else
					%weight = $AIWeightHumanIssuedCommand;
			}
			else
			{
				// calculate the default...
				%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
				if (%weight < $AIWeightHumanIssuedCommand)
					%weight = $AIWeightHumanIssuedCommand;
			}
		}
		else
		{
			//make sure we have the potential to reach the minWeight
			if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
				return 0;

			// calculate the default...
			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
		}

                //lets give him some personallity on this one :) - Lagg...
                if ((findTargetInView(%client, 150)) == %this.targetObjectId)
                   %weight += 200;

		return %weight;
	}
}

function AIOMDestroyObject::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIMDestroyObject);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIOMDestroyObject::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI MDestroy Object ---

function AIMDestroyObject::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
        %task.location = %objective.location;

	//initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;
        %task.useTeleport = false;

        //%task.location = %objective.location;
              //pick a random set based on armor...
	      %randNum = getRandom();
	      if (%randNum < 0.2)
              {
                    %task.desiredEquipment = "SensorJammerPack";
                    %task.buyEquipmentSet = "HeavyEnergySet";
              }
	      else if (%randNum < 0.4)
              {
                    %task.desiredEquipment = "RepairPack";
                    %task.buyEquipmentSet = "HeavyRepairSet";
              } 
	      else if (%randNum < 0.6)
              {
                    %task.desiredEquipment = "EnergyPack";
                    %task.buyEquipmentSet = "HeavyEnergyDefault";
              }
              else if (%randNum < 0.8)
              {
                    %task.desiredEquipment = "ShieldPack";
                    %task.buyEquipmentSet = "HeavyShieldOff";
              }
              else
              {
                    %task.desiredEquipment = "CloakingPack";
                    %task.buyEquipmentSet = "LightCloakSet";
              }
}

function AIMDestroyObject::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(5);
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);
   %hasMortar = (%client.player.getInventory("Mortar") > 0) && (%client.player.getInventory("MortarAmmo") > 0);
   if (%hasMortar)
      %client.needEquipment = false;

	//even if we don't *need* equipemnt, see if we should buy some... 
	if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
	{
		//see if we could benefit from inventory
		%needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
		%result = AIFindClosestInventory(%client, %needArmor);
		%closestInv = getWord(%result, 0);
		%closestDist = getWord(%result, 1);
		if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
		{
			//find where we are
			%clientPos = %client.player.getWorldBoxCenter();
			%objPos = %task.targetObject.getWorldBoxCenter();
			%distToObject = %client.getPathDistance(%objPos);
			
			if (%distToObject < 0 || %closestDist < %distToObject)
				%client.needEquipment = true;
		}
	}

	//mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();

   //--------------------------------------------------- assume telporter - start -
   //if the MPB Teleporter is online - Lagg... 9-30-2003

   //first check for deployed MPB
   %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
   %closestMPB = getWord(%result, 0);
   %closestMPBDist = getWord(%result, 1);
      
   //next find the teleporter
   %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
   %closestTel = getWord(%result, 0);
   %closestTelDist = getWord(%result, 1);
      
   //now check for what would be closer - Lagg... 10-1-2003
   if (%closestMPB > 0 && %closestTel > 0)
   {
      %disToTarg = %client.getPathDistance(%task.location);
      %mpbDisToTarg = vectorDist(%closestMPB.getTransform(), %task.location);
         
      if (%closestTelDist < %closestMPBDist && %closestMPBDist < %disToTarg && %mpbDisToTarg < %disToTarg)
         %task.useTeleport = true;//new - Lagg... 10-1-2003
      else
         %task.useTeleport = false;             
   }
   //--------------------------------------------------- assume telporter - end -
}

function AIMDestroyObject::retire(%task, %client)
{
   %client.setTargetObject(-1);
}

function AIMDestroyObject::weight(%task, %client)
{
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   //let the monitor decide when to stop attacking
   %task.setWeight(%task.baseWeight);
}

function AIMDestroyObject::monitor(%task, %client)
{
   //first, buy the equipment - if we really really need some :) - Lagg... - 4-6-2003
   %hasMortar = (%client.player.getInventory("Mortar") > 0) && (%client.player.getInventory("MortarAmmo") > 0);
   if (%client.needEquipment && !%hasMortar)
   {
	   %task.setMonitorFreq(5);
		if (%task.equipment !$= "")
			%equipmentList = %task.equipment;
		else
			%equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
		if (%result $= "InProgress")
                {
                   //force a nervous reaction every 15 sec - Lagg...
                   if (getSimTime() - %task.buyInvTime > 15000)
                   {
                      %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
                      %task.buyInvTime = getSimTime();
                   }
                   return;
                }
		else if (%result $= "Finished")
		{
		   %task.setMonitorFreq(15);
			%client.needEquipment = false;
		}
		else if (%result $= "Failed")
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	      {
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
	      }
			return;
		}
   }
	//if we made it past the inventory buying, reset the inv time
	%task.buyInvTime = getSimTime();
   
	//chat
	if (%task.sendMsg)
	{
		if (%task.sendMsgTime == 0)
			%task.sendMsgTime = getSimTime();
		else if (getSimTime() - %task.sendMsgTime > 7000)
		{
			%task.sendMsg = false;
		   if (%client.isAIControlled())
			{
				if (%task.chat !$= "")
				{
					%chatMsg = getWord(%task.chat, 0);
					%chatTemplate = getWord(%task.chat, 1);
					if (%chatTemplate !$= "")
						AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
					else
						AIMessageThread(%task.chat, %client, -1);
				}
				else if (%task.targetObject > 0)
				{
					%type = %task.targetObject.getDataBlock().getName();
					if (%type $= "GeneratorLarge")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackGenerator", %client, -1);
					else if (%type $= "SensorLargePulse")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
					else if (%type $= "SensorMediumPulse")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
					else if (%type $= "TurretBaseLarge")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackTurrets", %client, -1);
					else if (%type $= "StationVehicle")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackVehicle", %client, -1);
				}
			}
		}
	}

   //--------------------------------------------------- monitor telporter - start -
   //are we using teleporter
   if (%task.useTeleport)
   {
      %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
      %closestMPB = getWord(%result, 0);
      %closestMPBDist = getWord(%result, 1);
      %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
      %closestTel = getWord(%result, 0);
      %closestTelDist = getWord(%result, 1);
      if (%closestMPB > 0 && %closestTel > 0)
      {
         //we are done teleporting
         if (%closestMPBDist < %closestTelDist)
         {
            //reset the clients inventory status
            if (%client.needEquipment)
            {
               %result = AIFindClosestInventory(%client, 0);
	       %closestInv = getWord(%result, 0);
               %client.invToUse = %closestInv;
            }
            %task.useTeleport = false;
            return;
         }

         if (%closestTelDist < 2)
            %client.pressJump();
         else
         {
            %client.stepMove(%closestTel.getWorldBoxCenter(), 0.25);
            return;
         }
      }
      else
         %task.useTeleport = false;
   }
   //--------------------------------------------------- monitor telporter - end -

   //set the target object
   %outOfStuff = (AIAttackOutofAmmo(%client));
   if (isObject(%task.targetObject) && %task.targetObject.getDamageState() !$= "Destroyed" && !%outOfStuff)
   {
      if (VectorDist(%task.targetObject.position, %client.player.position) < 15)
      {
         if (%task.targetObject.getDataBlock().getName() $= "StationVehicle")
            %client.setDangerLocation(%task.targetObject.position, 20);
         else if (%task.targetObject.getDataBlock().getName() $= "MPBTeleporter")
            %client.setDangerLocation(%task.targetObject.position, 20);
      }
      else
         %client.stepMove(%task.location);
      %targetLOS = "false";
      %mask = $TypeMasks::TerrainObjectType | $TypeMasks::InteriorObjectType;
      %targetLOS = !containerRayCast(%client.player.getWorldBoxCenter(), %task.targetObject.getWorldBoxCenter(), %mask, 0);
      if (%targetLOS)
	            %client.setTargetObject(%task.targetObject, 80, "Mortar");
      else
      {
          %client.setTargetObject(-1);
          %client.stepMove(%task.location);
      } 
   }
   else
   {
      %client.setTargetObject(-1);
      //%client.stop();
      
      //if this task is the objective task, choose a new objective
      if (%task == %client.objectiveTask)
      {
         AIUnassignClient(%client);
         Game.AIChooseGameObjective(%client);
      }
   }
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Missile Object +++
//                                                                            - Lagg... 4-12-2003

function AIOMissileObject::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   // if were playing CnH, check who owns this
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team == %client.team)
      return 0;      
   
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

   //lets check the range on this one
   if (vectorDist(%client.Player.getWorldBoxCenter(), %this.getWorldBoxCenter()) < 50)
      return 0;
    
   //no need to attack if the object is already destroyed
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamageState() $= "Destroyed")
      return 0;
   else
	{
		//if this bot is linked to a human who has issued this command, up the weight
		if (%this.issuedByClientId == %client.controlByHuman)
		{
			//make sure we have the potential to reach the minWeight
			if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
			{
				if ($AIWeightHumanIssuedCommand < %minWeight)
					return 0;
				else
					%weight = $AIWeightHumanIssuedCommand;
			}
			else
			{
				// calculate the default...
				%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
				if (%weight < $AIWeightHumanIssuedCommand)
					%weight = $AIWeightHumanIssuedCommand;
			}
		}
		else
		{
			//make sure we have the potential to reach the minWeight
			if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
				return 0;

			// calculate the default...
			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
		}

		return %weight;
	}
}

function AIOMissileObject::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIMissileObject);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIOMissileObject::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Missile Object ---
//                                                                            - Lagg... 4-12-2003

function AIMissileObject::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   %task.location = %objective.location;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;

	//initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;
        %task.useTeleport = false;
}

function AIMissileObject::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(5);
   %task.needToRangeTime = 0;
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);

	//even if we don't *need* equipemnt, see if we should buy some... 
	if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
	{
		//see if we could benefit from inventory
		%needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
		%result = AIFindClosestInventory(%client, %needArmor);
		%closestInv = getWord(%result, 0);
		%closestDist = getWord(%result, 1);
		if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
		{
			//find where we are
			%clientPos = %client.player.getWorldBoxCenter();
			%objPos = %task.targetObject.getWorldBoxCenter();
			%distToObject = %client.getPathDistance(%objPos);
			
			if (%distToObject < 0 || %closestDist < %distToObject)
				%client.needEquipment = true;
		}
	}

	//mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();

   //--------------------------------------------------- assume telporter - start -
   //if the MPB Teleporter is online - Lagg... 9-30-2003

   //first check for deployed MPB
   %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
   %closestMPB = getWord(%result, 0);
   %closestMPBDist = getWord(%result, 1);
      
   //next find the teleporter
   %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
   %closestTel = getWord(%result, 0);
   %closestTelDist = getWord(%result, 1);
      
   //now check for what would be closer - Lagg... 10-1-2003
   if (%closestMPB > 0 && %closestTel > 0)
   {
      %disToTarg = %client.getPathDistance(%task.location);
      %mpbDisToTarg = vectorDist(%closestMPB.getTransform(), %task.location);
         
      if (%closestTelDist < %closestMPBDist && %closestMPBDist < %disToTarg && %mpbDisToTarg < %disToTarg)
         %task.useTeleport = true;//new - Lagg... 10-1-2003
      else
         %task.useTeleport = false;            
   }
   //--------------------------------------------------- assume telporter - end -
}

function AIMissileObject::retire(%task, %client)
{
   %client.setTargetObject(-1);
}

function AIMissileObject::weight(%task, %client)
{
        if (VectorDist(%task.location, %client.Player.getWorldBoxCenter) < 41)
        {
           echo(" Too Close to missile object set baseweight (0)");
           %task.baseWeight = 0;
        }
	
	else if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   //let the monitor decide when to stop attacking
   %task.setWeight(%task.baseWeight);
}

function AIMissileObject::monitor(%task, %client)
{
   //first, buy the equipment
   if (%client.needEquipment)
   {
	   %task.setMonitorFreq(5);
		if (%task.equipment !$= "")
			%equipmentList = %task.equipment;
		else
			%equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
		if (%result $= "InProgress")
                {
                   //force a nervous reaction every 15 sec - Lagg...
                   if (getSimTime() - %task.buyInvTime > 15000)
                   {
                      %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
                      %task.buyInvTime = getSimTime();
                   }
                   return;
                }
		else if (%result $= "Finished")
		{
		   %task.setMonitorFreq(15);
			%client.needEquipment = false;
		}
		else if (%result $= "Failed")
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	      {
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
	      }
			return;
		}
   }
	//if we made it past the inventory buying, reset the inv time
	%task.buyInvTime = getSimTime();
   
	//chat
	if (%task.sendMsg)
	{
		if (%task.sendMsgTime == 0)
			%task.sendMsgTime = getSimTime();
		else if (getSimTime() - %task.sendMsgTime > 7000)
		{
			%task.sendMsg = false;
		   if (%client.isAIControlled())
			{
				if (%task.chat !$= "")
				{
					%chatMsg = getWord(%task.chat, 0);
					%chatTemplate = getWord(%task.chat, 1);
					if (%chatTemplate !$= "")
						AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
					else
						AIMessageThread(%task.chat, %client, -1);
				}
				else if (%task.targetObject > 0)
				{
					%type = %task.targetObject.getDataBlock().getName();
					if (%type $= "GeneratorLarge")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackGenerator", %client, -1);
					else if (%type $= "SensorLargePulse")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
					else if (%type $= "SensorMediumPulse")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
					else if (%type $= "TurretBaseLarge")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackTurrets", %client, -1);
					else if (%type $= "StationVehicle")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackVehicle", %client, -1);
				}
			}
		}
	}

   //--------------------------------------------------- monitor telporter - start -
   //are we using teleporter
   if (%task.useTeleport)
   {
      %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
      %closestMPB = getWord(%result, 0);
      %closestMPBDist = getWord(%result, 1);
      %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
      %closestTel = getWord(%result, 0);
      %closestTelDist = getWord(%result, 1);
      if (%closestMPB > 0 && %closestTel > 0)
      {
         //we are done teleporting
         if (%closestMPBDist < %closestTelDist)
         {
            //reset the clients inventory status
            if (%client.needEquipment)
            {
               %result = AIFindClosestInventory(%client, 0);
	       %closestInv = getWord(%result, 0);
               %client.invToUse = %closestInv;
            }
            %task.useTeleport = false;
            return;
         }

         if (%closestTelDist < 2)
            %client.pressJump();
         else
         {
            %client.stepMove(%closestTel.getWorldBoxCenter(), 0.25);
            return;
         }
      }
      else
         %task.useTeleport = false;
   }
   //--------------------------------------------------- monitor telporter - end -

   //set the target object
   if (isObject(%task.targetObject) && %task.targetObject.getDamageState() !$= "Destroyed")
   {
      //make sure we still have equipment
		%client.needEquipment = AINeedEquipment(%task.equipment, %client);
      if (%client.needEquipment)
      {
         //if this task is the objective task, choose a new objective
         if (%task == %client.objectiveTask)
			{
            AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
				return;
			}
      }

      %clientPos = %client.player.getWorldBoxCenter();
      %targetPos = %task.targetObject.getWorldBoxCenter();
      %distance = %client.getPathDistance(%targetPos);
		if (%distance < 0)
			%distance = 32767;

      //next move to within 300 
      if (%distance > 300)
      {
         %client.setTargetObject(-1);
         %client.stepMove(%task.targetObject.getWorldBoxCenter(), 15);
      }
      else
      {
         //move to LOS location to objective marker(not to target)
         //(that makes the LOS location adjustable!)
         %firePos = %client.getLOSLocation(%task.location, 50, 290);
         %client.stepMove(%firePos);
         //check for LOS
         %missileLOS = "false";
         %mask = $TypeMasks::TerrainObjectType | $TypeMasks::InteriorObjectType | $TypeMasks::TSStaticShapeObjectType;
         %missileLOS = !containerRayCast(%client.player.getWorldBoxCenter(), %task.location, %mask, 0);
         %inRange = %client.getPathDistance(%task.location);

         //modified here in case bot gets stuck trying to get LOS to target - Lagg... - 4-21-2003
	 %currentTime = getSimTime();
	 if (%currentTime > %task.needToRangeTime)
	 {
	    //force a rangeObject every 20 seconds...
            %task.needToRangeTime = %currentTime + 20000;
            %client.setDangerLocation(%firePos, 30);
            return;

         }
      
         if ((%inRange > 49) && (%inRange < 291) && %missileLOS)
         {
            %client.setTargetObject(%task.targetObject, 300, "Missile");
	    //dissolve the human control link
	    if (%task == %client.objectiveTask)
               {
	          aiReleaseHumanControl(%client.controlByHuman, %client);
                  %client.stop();
               }
            return;
         }
         else if ((%inRange > 49) && (%inRange < 291) && !%missileLOS && (%client.getPathDistance(%client.player.getWorldBoxCenter(), %firePos) < 10))
         {     
            //if this task is the objective task, choose a new objective
            if (%task == %client.objectiveTask)
            {
               %task.baseWeight = 0;
               %task.setWeight(%task.baseWeight);
               return;
            }
         }
         else if (%client.getStepStatus() !$= "Finished")
         {
            %client.stepMove(%firePos);
            return;
         }
      }     
   }
   else
   {     
      //if this task is the objective task, choose a new objective
      if (%task == %client.objectiveTask)
      {
         %client.setTargetObject(-1);
         %client.stop();
         AIUnassignClient(%client);
         Game.AIChooseGameObjective(%client);
      }
   }
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Mortar Object +++
//Modified so bot gets LOS to target before firing. Fixed a lot of stuff here.          - Lagg...

function AIOMortarObject::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   // if were playing CnH, check who owns this
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team == %client.team)
      return 0;
   
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;
      
   //no need to attack if the object is already destroyed
   if (%this.targetObjectId.getDamageState() $= "Destroyed")
      return 0;
   else
   {
      //if this bot is linked to a human who has issued this command, up the weight
      if (%this.issuedByClientId == %client.controlByHuman)
      {
         //make sure we have the potential to reach the minWeight
	 if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
	 {
	    if ($AIWeightHumanIssuedCommand < %minWeight)
	       return 0;
	    else
	       %weight = $AIWeightHumanIssuedCommand;
	 }
	 else
	 {
	    // calculate the default...
	    %weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
	    if (%weight < $AIWeightHumanIssuedCommand)
	       %weight = $AIWeightHumanIssuedCommand;
         }
      }
      else
      {
         //make sure we have the potential to reach the minWeight
         if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
	    return 0;

	 // calculate the default...
         %weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
      }

      return %weight;
   }
}

//modified client escorter - Lagg... - 4-12-2003
function AIOMortarObject::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIMortarObject);
   %client.objectiveTask.initFromObjective(%this, %client);
   
   //create the escort objective (require a targeting laser in this case...)
   %client.escort = new AIObjective(AIOEscortPlayer)
                     {
						      dataBlock = "AIObjectiveMarker";
                        weightLevel1 = $AIWeightEscortOffense[1];
                        weightLevel2 = $AIWeightEscortOffense[2];
                        description = "Escort " @ getTaggedString(%client.name);
                        targetClientId = %client;
                        offense = true;
                        equipment = "Plasma PlasmaAmmo TargetingLaser";
								buyEquipmentSet = "MediumMissileSet";
                     };
   MissionCleanup.add(%client.escort);

   //if is siege game we have to do this right - Lagg... 11-3-2003
   if (Game.class $= "SiegeGame")
   {
      //the objectives in $ObjectiveQ[1] are all offense objectives, $ObjectiveQ[2] has the defensive ones..
      if (%client.team == game.offenseTeam)
         $ObjectiveQ[1].add(%client.escort);
      else
         $ObjectiveQ[2].add(%client.escort);
   }
   else
      $ObjectiveQ[%client.team].add(%client.escort);
}

function AIOMortarObject::unassignClient(%this, %client)
{
   //kill the escort objective
   if (%client.escort)
   {
      AIClearObjective(%client.escort);
      %client.escort.delete();
      %client.escort = "";
   }   
 
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Mortar Object ---
function AIMortarObject::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
	%task.mode = %task.targetObject.getDataBlock().getName();

	%task.sendMsgTime = 0;
	%task.sendMsg = true;
        %task.useTeleport = false;
}

function AIMortarObject::assume(%task, %client)
{
   %task.setWeightFreq(30);
   %task.setMonitorFreq(30);
   %task.state = moveToRange;
   %task.waitForTargetter = true;
   %task.celebrate = false;
   %task.waitTimerMS = 0;
   %task.targetAcquired = false;
   %task.sayAcquired = true;
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);

   //even if we don't *need* equipemnt, see if we should buy some... 
   if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
   {
      //see if we could benefit from inventory
      %needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
      %result = AIFindClosestInventory(%client, %needArmor);
      %closestInv = getWord(%result, 0);
      %closestDist = getWord(%result, 1);
      if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
      {
         //find where we are
	 %clientPos = %client.player.getWorldBoxCenter();
	 %objPos = %task.targetObject.getWorldBoxCenter();
	 %distToObject = %client.getPathDistance(%objPos);
			
	 if (%distToObject < 0 || %closestDist < %distToObject)
	    %client.needEquipment = true;
      }
   }

   //mark the current time for the buy inventory state machine
   %task.buyInvTime = getSimTime();

   //--------------------------------------------------- assume telporter - start -
   //if the MPB Teleporter is online - Lagg... 9-30-2003

   //first check for deployed MPB
   %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
   %closestMPB = getWord(%result, 0);
   %closestMPBDist = getWord(%result, 1);
      
   //next find the teleporter
   %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
   %closestTel = getWord(%result, 0);
   %closestTelDist = getWord(%result, 1);
      
   //now check for what would be closer - Lagg... 10-1-2003
   if (%closestMPB > 0 && %closestTel > 0)
   {
      %disToTarg = %client.getPathDistance(%task.location);
      %mpbDisToTarg = vectorDist(%closestMPB.getTransform(), %task.location);
         
      if (%closestTelDist < %closestMPBDist && %closestMPBDist < %disToTarg && %mpbDisToTarg < %disToTarg)
         %task.useTeleport = true;//new - Lagg... 10-1-2003
      else
         %task.useTeleport = false;             
   }
   //--------------------------------------------------- assume telporter - end -
}

function AIMortarObject::retire(%task, %client)
{
   %client.setTargetObject(-1);
   
   //remove the associated lazeObjective
   if (%task.targetterObjective)
   {
      AIClearObjective(%task.targetterObjective);
      %task.targetterObjective.delete();
      %task.targetterObjective = "";
   }
}

function AIMortarObject::weight(%task, %client)
{
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   //let the monitor decide when to stop mortaring
   %task.setWeight(%task.baseWeight);
}

function AIMortarObject::monitor(%task, %client)
{
   //first, buy the equipment
   if (%client.needEquipment)
   {
      %task.setMonitorFreq(5);
      if (%task.equipment !$= "")
         %equipmentList = %task.equipment;
      else
         %equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
      if (%result $= "InProgress")
      {
         //force a nervous reaction every 15 sec - Lagg...
         if (getSimTime() - %task.buyInvTime > 15000)
         {
            %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
            %task.buyInvTime = getSimTime();
         }
         return;
      }
      else if (%result $= "Finished")
      {
         %task.setMonitorFreq(30);
	 %client.needEquipment = false;
      }
      else if (%result $= "Failed")
      {
         //if this task is the objective task, choose a new objective
	 if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
	 return;
      }
   }
   //if we made it past the inventory buying, reset the inv time
   %task.buyInvTime = getSimTime();

   //chat
   if (%task.sendMsg)
   {
      if (%task.sendMsgTime == 0)
         %task.sendMsgTime = getSimTime();
      else if (getSimTime() - %task.sendMsgTime > 7000)
      {
         %task.sendMsg = false;
	 if (%client.isAIControlled())
	 {
	    if (%task.chat !$= "")
	    {
	       %chatMsg = getWord(%task.chat, 0);
	       %chatTemplate = getWord(%task.chat, 1);
	       if (%chatTemplate !$= "")
	          AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
	       else
		  AIMessageThread(%task.chat, %client, -1);
	    }
	    else if (%task.targetObject > 0)
	    {
	       %type = %task.targetObject.getDataBlock().getName();
	       if (%type $= "GeneratorLarge")
	          AIMessageThreadTemplate("AttackBase", "ChatSelfAttackGenerator", %client, -1);
	       else if (%type $= "SensorLargePulse")
	          AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
	       else if (%type $= "SensorMediumPulse")
	          AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
	       else if (%type $= "TurretBaseLarge")
		  AIMessageThreadTemplate("AttackBase", "ChatSelfAttackTurrets", %client, -1);
	       else if (%type $= "StationVehicle")
		  AIMessageThreadTemplate("AttackBase", "ChatSelfAttackVehicle", %client, -1);
	    }
         }
      }
   }

   //--------------------------------------------------- monitor telporter - start -
   //are we using teleporter
   if (%task.useTeleport)
   {
      %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
      %closestMPB = getWord(%result, 0);
      %closestMPBDist = getWord(%result, 1);
      %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
      %closestTel = getWord(%result, 0);
      %closestTelDist = getWord(%result, 1);
      if (%closestMPB > 0 && %closestTel > 0)
      {
         //we are done teleporting
         if (%closestMPBDist < %closestTelDist)
         {
            //reset the clients inventory status
            if (%client.needEquipment)
            {
               %result = AIFindClosestInventory(%client, 0);
	       %closestInv = getWord(%result, 0);
               %client.invToUse = %closestInv;
            }
            %task.useTeleport = false;
            return;
         }

         if (%closestTelDist < 2)
            %client.pressJump();
         else
         {
            %client.stepMove(%closestTel.getWorldBoxCenter(), 0.25);
            return;
         }
      }
      else
         %task.useTeleport = false;
   }
   //--------------------------------------------------- monitor telporter - end -

   //make sure we still have something to destroy
   if (isObject(%task.targetObject) && %task.targetObject.getDamageState() !$= "Destroyed")
   {
      %clientPos = %client.player.getWorldBoxCenter();
      %targetPos = %task.targetObject.getWorldBoxCenter();
      %distance = %client.getPathDistance(%targetPos);
      if (%distance < 0)
         %distance = 32767;
      
      //make sure we still have equipment
      %client.needEquipment = AINeedEquipment(%task.equipment, %client);
      if (%client.needEquipment)
      {
         //if this task is the objective task, choose a new objective
         if (%task == %client.objectiveTask)
	 {
            AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	    return;
	 }
      }
      
      //next move to within 300 
      else if (%distance > 300)
      {
         %client.setTargetObject(-1);
         %client.stepMove(%task.targetObject.getWorldBoxCenter(), 15);
      }
      
      //now start ask for someone to laze the target, and start a 20 sec timer
      else if (%task.waitForTargetter)
      {
         //see if we've started the timer
         if (%task.waitTimerMS == 0)
         {
	    //range the object
	    %client.stepRangeObject(%task.targetObject, "BasicTargeter", 80, 300);

            //now ask for a targeter...
	    %targetType = %task.targetObject.getDataBlock().getName();
	    if (%targetType $= "TurretBaseLarge")
	       AIMessageThread("ChatCmdTargetTurret", %client, -1);
	    else if (%targetType $= "SensorLargePulse")
	       AIMessageThread("ChatCmdTargetSensors", %client, -1);
	    else if (%targetType $= "SensorMediumPulse")
	       AIMessageThread("ChatCmdTargetSensors", %client, -1);
	    else
	       AIMessageThread("ChatTargetNeed", %client, -1);

            %task.waitTimerMS = getSimTime();

            //create the objective
	    if (! %task.targetterObjective)
            {
	       %task.targetterObjective = new AIObjective(AIOLazeObject)
	               {
		               dataBlock = "AIObjectiveMarker";
	                       weightLevel1 = $AIWeightLazeObject[1];
	                       weightLevel2 = $AIWeightLazeObject[2];
	                       description = "Laze the " @ %task.targetObject.getName();
	                       targetObjectId = %task.targetObject;
			       issuedByClientId = %client;
	                       offense = true;
	                       equipment = "TargetingLaser";
	               };

               MissionCleanup.add(%task.targetterObjective);

               //if is siege game we have to do this right - Lagg... 11-3-2003
               if (Game.class $= "SiegeGame")
               {
                  //the objectives in $ObjectiveQ[1] are all offense objectives, $ObjectiveQ[2] defense
                  if (%client.team == game.offenseTeam)
                     $ObjectiveQ[1].add(%task.targetterObjective);
                  else
                     $ObjectiveQ[2].add(%task.targetterObjective);
               }
               else
                  $ObjectiveQ[%client.team].add(%task.targetterObjective);
            }
	    %task.targetterObjective.lastLazedTime = 0;

	    //remove the escort (want a targetter instead)
	    if (%client.escort)
	    {
	       AIClearObjective(%client.escort);
	       %client.escort.delete();
	       %client.escort = "";
	    }
         }									
         else
         {
            %elapsedTime = getSimTime() - %task.waitTimerMS;
	    if (%task.targetterObjective.group > 0)
	       %targetter = %task.targetterObjective.group.clientLevel[1];
	    else
	       %targetter = %task.targetterObjective.clientLevel[1];

	    //see if we can find a target near our objective
	    %task.targetAcquired = false;
	    %numTargets = ServerTargetSet.getCount();
	    for (%i = 0; %i < %numTargets; %i++)
	    {
	       %targ = ServerTargetSet.getObject(%i);
	       %targDist = VectorDist(%targ.getWorldBoxCenter(), %task.targetObject.getWorldBoxCenter());
	       if (%targDist < 300)//was 20 - Lagg...
	       {
	          %task.targetAcquired = true;
		  break;
	       }
	    }

	    if (%task.targetAcquired)
            {
               %task.waitForTargetter = false;
	       %task.waitTimerMS = 0;
	       %task.celebrate = true;
	       %task.sayAcquired = false;
	       AIMessageThread("ChatTargetAcquired", %client, -1);
            }

	    //else see if we've run out of time
	    else if (! %targetter || ! %targetter.isAIControlled() || %elapsedTime > 20000)
	    {
               %task.waitForTargetter = false;
	       %task.waitTimerMS = 0;
	       %task.celebrate = true;
	    }  
         }
      }
      
      //now we should finally be attacking with or without a targetter
      //eventually, the target will be destroyed, or we'll run out of ammo...
      else
      {
         //dissolve the human control link
	 if (%task == %client.objectiveTask)
	    aiReleaseHumanControl(%client.controlByHuman, %client);

	 //see if we didn't acquired a spotter along the way
	 if (%task.targetterObjective.group > 0)
	    %targetter = %task.targetterObjective.group.clientLevel[1];
	 else
	    %targetter = %task.targetterObjective.clientLevel[1];
	 if (! %task.targetAcquired && AIClientIsAlive(%targetter) && %targetter.isAIControlled())
	 {
	    %client.setTargetObject(-1);
            %task.waitForTargetter = true;
	 }
	 else
	 {
	    //see if we can find a target near our objective
	    if (! %task.targetAcquired)
	    {
	       %numTargets = ServerTargetSet.getCount();
	       for (%i = 0; %i < %numTargets; %i++)
	       {
		  %targ = ServerTargetSet.getObject(%i);
		  %targDist = VectorDist(%targ.getWorldBoxcenter(), %task.targetObject.getWorldBoxCenter());
		  if (%targDist < 300)//was 20 - Lagg...
		  {
		     %task.targetAcquired = true;
		     break;
		  }
	       }
	       //see if we found a target (must be by a human)
	       if (%task.targetAcquired && %task.sayAcquired)
	       {
	          %task.sayAcquired = false;
		  AIMessageThread("ChatTargetAcquired", %client, -1);
	       }
	    }
				
	    //set the target object, and keep attacking it
	    if (%client.getStepStatus() $= "Finished")
	       %client.setTargetObject(%task.targetObject, 300, "Mortar");
	    else
	       %client.setTargetObject(-1);
         }
      }
   }

   //the target must have been destroyed  :)
   else
   {
      //dissolve the human control link
      if (%task == %client.objectiveTask)
         aiReleaseHumanControl(%client.controlByHuman, %client);

      %client.setTargetObject(-1);
      %client.clearStep();
      %client.stop();

      if (%task.celebrate)
      {
         if (%task.waitTimerMS == 0)
	 {
	    //client animation "woohoo"!  :)
	    //choose the animation range
	    %minCel = 3;
	    %maxCel = 8;

	    //pick a random sound
	    if (getRandom() > 0.25)
	       %sound = "gbl.awesome";
	    else if (getRandom() > 0.5)
	       %sound = "gbl.thanks";
	    else if (getRandom() > 0.75)
	       %sound = "gbl.nice";
	    else
	       %sound = "gbl.rock";
	    %randTime = mFloor(getRandom() * 500) + 1;
	    schedule(%randTime, %client, "AIPlayAnimSound", %client, %task.targetObject.getWorldBoxCenter(), %sound, %minCel, %maxCel, 0);

	    //team message
	    AIMessageThread("ChatEnemyTurretsDestroyed", %client, -1);

	    //set the timer
            %task.waitTimerMS = getSimTime();
	 }

	 //else see if the celebration period is over
	 else if (getSimTime() - %task.waitTimerMS > 3000)
	    %task.celebrate = false;
      }
      else
      {
         //if this task is the objective task, choose a new objective
	 if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
         }
      }
   }
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Place Camera +++
// have to fix this so a repair object objective is created for the newly deployed thingy??
//rotate the objective marker, bot will place on the "Y" same as all other deploy objectives
//                                                                            - Lagg... 1-14-2003

function AIOPlaceCamera::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

	//make sure the deploy objective is valid
	//if (%this.isInvalid)
		//return 0;

	//first, make sure we haven't deployed too many...
 	if (%this.equipment $= "CameraGrenade")
        %maxAllowed = $TeamDeployableMax[DeployedCamera];
        else
                return 0;
   
	if ($TeamDeployedCount[%client.team, %this.equipment] >= %maxAllowed)
		return 0;

	//now make sure there are no other items in the way...
  	  InitContainerRadiusSearch(%this.location, 1, $TypeMasks::VehicleObjectType |
  	                                               $TypeMasks::MoveableObjectType |
  	                                               $TypeMasks::StaticShapeObjectType |
  	                                               $TypeMasks::TSStaticShapeObjectType |
  	                                               $TypeMasks::ForceFieldObjectType |
  	                                               $TypeMasks::ItemObjectType |
  	                                               $TypeMasks::PlayerObjectType | $TypeMasks::TurretObjectType);                   
	%objSearch = containerSearchNext();

	//make sure we're not invalidating the deploy location with the client's own player object
	if (%objSearch == %client.player)
		%objSearch = containerSearchNext();

	//did we find an object which would block deploying the equipment?
	if (isObject(%objSearch))
		return 0;

 	

	//check equipment requirement
	%needEquipment = AINeedEquipment(%this.equipment, %client);
	
        //if don't need equipment, see if we've past the "point of no return", and should continue regardless
 	if (! %needEquipment)
 	{
 		%needArmor = AIMustUseRegularInvStation(%this.equipment, %client);
 		%result = AIFindClosestInventory(%client, %needArmor);
 		%closestInv = getWord(%result, 0);
 		%closestDist = getWord(%result, 1);
 
 		//if we're too far from the inv to go back, or we're too close to the deploy location, force continue
 		if (%closestDist > 50 && VectorDist(%client.player.getWorldBoxCenter(), %task.location) < 150)
 		{
 			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
 			if (%weight < $AIWeightContinueDeploying)
 				%weight = $AIWeightContinueDeploying;
 			return %weight;
 		}
 	}

	//if this bot is linked to a human who has issued this command, up the weight
	if (%this.issuedByClientId == %client.controlByHuman)
	{
		//make sure we have the potential to reach the minWeight
		if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
		{
			if ($AIWeightHumanIssuedCommand < %minWeight)
				return 0;
			else
				%weight = $AIWeightHumanIssuedCommand;
		}
		else
		{
			// calculate the default...
			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
			if (%weight < $AIWeightHumanIssuedCommand)
				%weight = $AIWeightHumanIssuedCommand;
		}
	}
	else
	{
		//make sure we have the potential to reach the minWeight
		if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
			return 0;

		// calculate the default...
		%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
	}

	return %weight;
}

function AIOPlaceCamera::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIPlaceCamera);
   %task = %client.objectiveTask;
   %task.initFromObjective(%this, %client);
}

function AIOPlaceCamera::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Place Camera ---

function AIPlaceCamera::initFromObjective(%task, %objective, %client)
{
	//initialize the task vars from the objective
   %task.baseWeight = %client.objectiveWeight;
   %task.location = %objective.location;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
	%task.chat = %objective.chat;

	//initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;

	//use the Y-axis of the rotation as the desired direction of deployement,
	//and calculate a walk to point 3 m behind the deploy point. 
	%task.deployDirection = MatrixMulVector("0 0 0 " @ getWords(%objective.getTransform(), 3, 6), "0 1 0");
	%task.deployDirection = VectorNormalize(%task.deployDirection);
}

function AIPlaceCamera::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(15);
	
	%client.needEquipment = AINeedEquipment(%task.equipment, %client);
   
   //mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();

	%task.passes = 0;
	%task.deployAttempts = 0;
	%task.checkObstructed = false;
	%task.waitMove = 0;
}

function AIPlaceCamera::retire(%task, %client)
{
}

function AIPlaceCamera::weight(%task, %client)
{
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   %task.setWeight(%task.baseWeight);
}

function AIPlaceCamera::monitor(%task, %client)
{
   //first, buy the equipment
   if (%client.needEquipment)
   {
	   %task.setMonitorFreq(5);
		if (%task.equipment !$= "")
			%equipmentList = %task.equipment;
		else
			%equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
		if (%result $= "InProgress")
                {
                   //force a nervous reaction every 15 sec - Lagg...
                   if (getSimTime() - %task.buyInvTime > 15000)
                   {
                      %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
                      %task.buyInvTime = getSimTime();
                   }
                   return;
                }
		else if (%result $= "Finished")
		{	
		   %task.setMonitorFreq(30);
         %client.needEquipment = false;
         //if we made it past the inventory buying, reset the inv time
	      %task.buyInvTime = getSimTime();
      }
      else if (%result $= "Failed")
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	      {
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
	      }
			return;
		}
   }

	//chat
	if (%task.sendMsg)
	{
		if (%task.sendMsgTime == 0)
			%task.sendMsgTime = getSimTime();
		else if (getSimTime() - %task.sendMsgTime > 7000)
		{
			%task.sendMsg = false;
		   if (%client.isAIControlled())
			{
				if (%task.chat !$= "")
				{
					%chatMsg = getWord(%task.chat, 0);
					%chatTemplate = getWord(%task.chat, 1);
					if (%chatTemplate !$= "")
						AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
					else
						AIMessageThread(%task.chat, %client, -1);
				}
			}
		}
	}

   //see if we're supposed to be engaging anyone...
   if (AIClientIsAlive(%client.shouldEngage))
   {
	   %hasLOS = %client.hasLOSToClient(%client.shouldEngage);
	   %losTime = %client.getClientLOSTime(%client.shouldEngage);
	   if (%hasLOS || %losTime < 1000)
         %client.setEngageTarget(%client.shouldEngage);
      else
         %client.setEngageTarget(-1);
   }
   else
      %client.setEngageTarget(-1);

	//calculate the deployFromLocation
	%factor = -1 * (3 - (%task.passes * 0.5));
   %task.deployFromLocation = VectorAdd(%task.location,VectorScale(%task.deployDirection, %factor));

	//see if we're within range of the deploy location
   %clLoc = %client.player.position;
   %distance = VectorDist(%clLoc, %task.deployFromLocation);
	%dist2D = VectorDist(%client.player.position, getWords(%task.deployFromLocation, 0, 1) SPC getWord(%client.player.position, 2));

	//set the aim when we get near the target...  this will be overwritten when we're actually trying to deploy
	if (%distance < 10 && %dist2D < 10)
      %client.aimAt(%task.location, 1000);

   if ((%client.pathDistRemaining(20) > %distance + 0.25) || %dist2D > 0.5)
	{
		%task.deployAttempts = 0;
		%task.checkObstructed = false;
		%task.waitMove = 0;
      %client.stepMove(%task.deployFromLocation, 0.25);
	   %task.setMonitorFreq(15);
		return;
	}
   
	if (%task.deployAttempts < 1 && %task.passes < 1 && !AIClientIsAlive(%client.getEngageTarget()))
	{
		//dissolve the human control link
		if (%task == %client.objectiveTask)
			aiReleaseHumanControl(%client.controlByHuman, %client);

	   %task.setMonitorFreq(3);
      %client.stop();
		if (%task.deployAttempts == 0)
			%deployPoint = %task.location;
		else
	      %deployPoint = findTurretDeployPoint(%client, %task.location, %task.deployAttempts);
      if(%deployPoint !$= "")
      {
         // we have possible point
         %task.deployAttempts++;
         %client.aimAt(%deployPoint, 2000);

			//try to place the camera
			//%client.deployPack = true;
         %client.lastThrownObject = -1;
         %client.player.throwStrength = 2;
         %client.player.use(CameraGrenade);
         
         // check if camera deployed
         if (isObject(%client.lastDeployedObject))
			{
				//see if there's a "repairObject" objective for the newly deployed thingy...
				if (%task == %client.objectiveTask)
				{
					%deployedObject = %client.lastDeployedObject;

					//search the current objective group and search for a "repair Object" task...
					%objective = %client.objective;

					//delete any previously associated "AIORepairObject" objective
					if (isObject(%objective.repairObjective))
					{
						AIClearObjective(%objective.repairObjective);
						%objective.repairObjective.delete();
						%objective.repairObjective = "";
					}

					//add the repair objective
	            %objective.repairObjective = new AIObjective(AIORepairObject)
		                              {
											      dataBlock = "AIObjectiveMarker";
		                                 weightLevel1 = %objective.weightLevel1 - 100;
		                                 weightLevel2 = 0;
		                                 description = "Repair the Deployed Camera";
													targetObjectId = %deployedObject;
													issuedByClientId = %client;
		                                 offense = false;
													defense = true;
		                                 equipment = "RepairPack";
                                                 buyEquipmentSet = "LightRepairSet";
		                              };
					%objective.repairObjective.deployed = true;
					%objective.repairObjective.setTransform(%objective.getTransform());
					%objective.repairObjective.group = %objective.group;
			      MissionCleanup.add(%objective.repairObjective);
	            $ObjectiveQ[%client.team].add(%objective.repairObjective);

					//finally, unassign the client so he'll go do something else...
			      AIUnassignClient(%client);
					Game.AIChooseGameObjective(%client);
				}

				//finished
				return;
			}
      }
	}
	else if (!%task.checkObstructed)
	{
		%task.checkObstructed = true;

	   //see if anything is in our way
	   InitContainerRadiusSearch(%task.location, 4, $TypeMasks::MoveableObjectType | $TypeMasks::VehicleObjectType |
																					                      $TypeMasks::PlayerObjectType);
	   %objSrch = containerSearchNext();
		if (%objSrch == %client.player)
		   %objSrch = containerSearchNext();
	   if (%objSrch)
			AIMessageThread("ChatMove", %client, -1);
	}
	else if (%task.waitMove < 5 && %task.passes < 1)
	{
		%task.waitMove++;

		//try another pass at deploying 
		if (%task.waitMove == 5)
		{
			%task.waitMove = 0;
			%task.passes++;
			%task.deployAttempts = 0;

			//see if we're *right* underneath the deploy point
			%deployDist2D = VectorDist(getWords(%client.player.position, 0, 1) @ "0", getWords(%task.location, 0, 1) @ "0");
			if (%deployDist2D < 0.25)
			{
				%client.pressjump();
				//%client.deployPack = true;
                                %client.player.throwStrength = 2;
	                        %client.player.use(CameraGrenade);

	         // check if pack deployed
	         //if(%client.player.getMountedImage($BackpackSlot) == 0)
				   // {
					//don't add a "repairObject" objective for ceiling turrets
					if (%task == %client.objectiveTask)
					{
						AIUnassignClient(%client);
						Game.AIChooseGameObjective(%client);
					}
				//}
			}
		}
	}
	else
	{
		//find a new assignment - and remove this one from the Queue
      if (%task == %client.objectiveTask)
		{
			//error(%client SPC "from team" SPC %client.team SPC "is invalidating objective:" SPC %client.objective SPC "UNABLE TO DEPLOY EQUIPMENT");
			%client.objective.isInvalid = false;
	      AIUnassignClient(%client);
			Game.AIChooseGameObjective(%client);
		}
	}
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Repair Object +++
//if you have a problem with bot getting stuck navigating to repair any object,
//place objective marker in spot you want bot to stand for repair at about bots waist level.
//if there is no problem with bot getting stuck repairing this object set the AIORepairObject
//markers transform to the same exact transform as the Object (x, y, z) updated - 10-18-2003

//fixed spam error when trying to repair a deployed object in case it gets destroyed while
//in loop. also fixed bots finding repair pack if base is down :) ----------- Lagg... 3-26-2003

function AIORepairObject::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   // if were playing CnH, check who owns this
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team != %client.team)
      return 0;      
   
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;
      
   //no need to repair if the object isn't in need
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamagePercent() <= 0)
      return 0;
   else
	{
		//if this bot is linked to a human who has issued this command, up the weight
		if (%this.issuedByClientId == %client.controlByHuman)
		{
			//make sure we have the potential to reach the minWeight
			if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
			{
				if ($AIWeightHumanIssuedCommand < %minWeight)
					return 0;
				else
					%weight = $AIWeightHumanIssuedCommand;
			}
			else
			{
				// calculate the default...
				%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
				if (%weight < $AIWeightHumanIssuedCommand)
					%weight = $AIWeightHumanIssuedCommand;
			}
		}
		else
		{
			//make sure we have the potential to reach the minWeight
			if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
				return 0;

			// calculate the default...
			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
		}

                //lets give him some personallity on this one :) - Lagg...
                if ((findTargetInView(%client, 100)) == %this.targetObjectId)
                   %weight += 200;

		return %weight;
	}
}

function AIORepairObject::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIRepairObject);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIORepairObject::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Repair Object ---

function AIRepairObject::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
	//need to force this objective to only require a repair pack
   //%task.equipment = %objective.equipment;
   %task.equipment = "RepairPack";
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;
        %task.location = %objective.location;
        
	%task.deployed = %objective.deployed;
	if (%task.deployed)
	{
                if (!isObject(%task.targetObject) && isObject(%objective.repairObjective))
		{
                    //if this task is the objective task, choose a new objective
                    if (%task == %client.objectiveTask)
		    {
                        AIUnassignClient(%client);
	                Game.AIChooseGameObjective(%client);			
		    }
                    return;                    
	        }
		%task.location = %objective.position;
		%task.deployDirection = MatrixMulVector("0 0 0 " @ getWords(%objective.getTransform(), 3, 6), "0 1 0");
		%task.deployDirection = VectorNormalize(%task.deployDirection);
	}
}

function AIRepairObject::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(15);
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);
      
   //clear the target object, and range it
   %client.setTargetObject(-1);
	if (! %client.needEquipment)
	{
	    if (%task.deployed)
	    {
                if (!isObject(%task.targetObject) && isObject(%objective.repairObjective))
		{
                    //if this task is the objective task, choose a new objective
                    if (%task == %client.objectiveTask)
		    {
                        AIUnassignClient(%client);
	                Game.AIChooseGameObjective(%client);			
		    }
		    return;                    
	        }
		   %task.repairLocation = VectorAdd(%task.location,VectorScale(%task.deployDirection, -4.0));//was -4
			%client.stepMove(%task.repairLocation, 0.25);
	    }

            //if the objective marker was moved than we have a problemed target
            //and we move to the objective marker to fix bot getting stuck trying
            //to repair object - Lagg... 10-10-2003            
            else if (%task.targetObject.getWorldBoxCenter() == %task.location)
                %client.stepRangeObject(%task.targetObject, "DefaultRepairBeam", 2, 4);                    
            else
	        %client.stepMove(%task.location);
	}

	//mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();
	%task.needToRangeTime = 0;
	%task.pickupRepairPack = -1;
	%task.usingInv = false;

	//set a tag to help the repairPack.cs script fudge acquiring a target
	%client.repairObject = %task.targetObject;
}

function AIRepairObject::retire(%task, %client)
{
   %client.setTargetObject(-1);
	%client.repairObject = -1;
}

function AIRepairObject::weight(%task, %client)
{
        //update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   //let the monitor decide when to stop repairing
   %task.setWeight(%task.baseWeight);
}

function AIRepairObject::monitor(%task, %client)
{
   //echo("AIRepairObject --- monitor");
   //first, buy the equipment
   if (%client.needEquipment)
   {
           %task.setMonitorFreq(5);

		//first, see if we still need a repair pack
		if (%client.player.getInventory(RepairPack) > 0)
		{
			%client.needEquipment = false;
		   %task.setMonitorFreq(15);

			//if this is to repair a deployed object, walk to the deploy point...
			if (%task.deployed)
			{
                           if (!isObject(%task.targetObject) && isObject(%objective.repairObjective))
		           {
                               %client.setTargetObject(-1);
                               //if this task is the objective task, choose a new objective
                               if (%task == %client.objectiveTask)
		               {
                                  //AIUnassignClient(%client);
	                          //Game.AIChooseGameObjective(%client);			
		               }
		               AIClearObjective(%objective.repairObjective);
		               %objective.repairObjective.delete();
		               %objective.repairObjective = "";
                               //echo("AIRepairObject - init - is not an object so delete repairobjective");
                               return;                    
	                   }
			   %task.repairLocation = VectorAdd(%task.location,VectorScale(%task.deployDirection, -4.0));//was -4
				%client.stepMove(%task.repairLocation, 0.25);
			}
                        //if the objective marker was moved than we have a problemed target
                        //and we move to the objective marker to fix bot getting stuck trying
                        //to repair object - Lagg... 10-10-2003            
                        else if (%task.targetObject.getWorldBoxCenter() == %task.location)
                           %client.stepRangeObject(%task.targetObject, "DefaultRepairBeam", 2, 4);
                        else
	                   %client.stepMove(%task.location);
		}
		else
		{
			// check to see if there's a repair pack nearby
			%closestRepairPack = -1;
			%closestRepairDist = 32767;

			//search the AIItemSet for a repair pack (someone might have dropped one...)
			%itemCount = $AIItemSet.getCount();
			for (%i = 0; %i < %itemCount; %i++)
			{
				%item = $AIItemSet.getObject(%i);
				if (%item.getDataBlock().getName() $= "RepairPack" && !%item.isHidden())
				{
                                        %dist = %client.getPathDistance(%item.getWorldBoxCenter());
					if (%dist > 0 && %dist < %closestRepairDist)
					{
                                                %closestRepairPack = %item;
						%closestRepairDist = %dist;
					}
				}
			}

			//choose whether we're picking up the closest pack, or buying from an inv station...
                        //with all these errors by Dynamix it is a wonder the bots do anything - Lagg... 3-25-2003
			if ((isObject(%closestRepairPack) && %closestRepairPack != %task.pickupRepairPack) || (%task.buyInvTime != %client.buyInvTime))
                        {
                                %task.pickupRepairPack = %closestRepairPack;

				//initialize the inv buying
				%task.buyInvTime = getSimTime();
				AIBuyInventory(%client, "RepairPack", %task.buyEquipmentSet, %task.buyInvTime);

				//now decide which is closer
				if (isObject(%closestRepairPack))
				{
                                        //added a little here to check for power - Lagg... - 3-25-2003
					if (isObject(%client.invToUse) && (%client.invToUse.isEnabled()) && (%client.invToUse.isPowered()))
					{
                                                %dist = %client.getPathDistance(%client.invToUse.getWorldBoxCenter());
						if (%dist < %closestRepairDist)
							%task.usingInv = true;
						else
							%task.usingInv = false;
					}
					else
                                           %task.usingInv = false;
				}
				else
					%task.usingInv = true;
			}

			//now see if we found a closer repair pack
			if (!%task.usingInv)
			{
				%client.stepMove(%task.pickupRepairPack.position, 0.25);
				%distToPack = %client.getPathDistance(%task.pickupRepairPack.position);
				if (%distToPack < 10 && %client.player.getMountedImage($BackpackSlot) > 0)
					%client.player.throwPack();

				//and we're finished until we actually have a repair pack... should now! - Lagg...
				return;
			}
			else
			{
		                %result = AIBuyInventory(%client, "RepairPack", %task.buyEquipmentSet, %task.buyInvTime);
				if (%result $= "InProgress")
                                {
                                   //force a nervous reaction every 15 sec - Lagg...
                                   if (getSimTime() - %task.buyInvTime > 15000)
                                   {
                                      %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
                                      %task.buyInvTime = getSimTime();
                                   }
                                   return;
                                }
				else if (%result $= "Finished")
				{
					%client.needEquipment = false;
				        %task.setMonitorFreq(15);

					//if this is to repair a deployed object, walk to the deploy point...
					if (%task.deployed)
					{ 	
					   %task.repairLocation = VectorAdd(%task.location,VectorScale(%task.deployDirection, -6.0));//was -4
						%client.stepMove(%task.repairLocation, 0.25);
					}
                                        //if the objective marker was moved than we have a problemed target
                                        //and we move to the objective marker to fix bot getting stuck trying
                                        //to repair object - Lagg... 10-10-2003            
                                        else if (%task.targetObject.getWorldBoxCenter() == %task.location)
                                           %client.stepRangeObject(%task.targetObject, "DefaultRepairBeam", 2, 4);
                                        else
	                                   %client.stepMove(%task.location);
				}
				else if (%result $= "Failed")
				{
			      //if this task is the objective task, choose a new objective
			      if (%task == %client.objectiveTask)
			      {
			         AIUnassignClient(%client);
			         Game.AIChooseGameObjective(%client);
			      }
					return;
				}
			}
		}
   }
	//if we made it past the inventory buying, reset the inv time
	%task.buyInvTime = getSimTime();
   
	//chat
	if (%task.sendMsg)
	{
		if (%task.sendMsgTime == 0)
			%task.sendMsgTime = getSimTime();
		else if (getSimTime() - %task.sendMsgTime > 7000)
		{
			%task.sendMsg = false;
		   if (%client.isAIControlled())
			{
				if (%task.chat !$= "")
				{
					%chatMsg = getWord(%task.chat, 0);
					%chatTemplate = getWord(%task.chat, 1);
					if (%chatTemplate !$= "")
						AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
					else
						AIMessageThread(%task.chat, %client, -1);
				}
				else if (%task.targetObject > 0)
				{
					%type = %task.targetObject.getDataBlock().getName();
					if (%type $= "GeneratorLarge")
						AIMessageThreadTemplate("RepairBase", "ChatSelfRepairGenerator", %client, -1);
					else if (%type $= "StationVehicle")
						AIMessageThreadTemplate("RepairBase", "ChatSelfRepairVehicle", %client, -1);
					else if (%type $= "SensorLargePulse")
						AIMessageThreadTemplate("RepairBase", "ChatSelfRepairSensors", %client, -1);
					else if (%type $= "SensorMediumPulse")
						AIMessageThreadTemplate("RepairBase", "ChatSelfRepairSensors", %client, -1);
					else if (%type $= "TurretBaseLarge")
						AIMessageThreadTemplate("RepairBase", "ChatSelfRepairTurrets", %client, -1);
				}
			}
		}
	}

   //if deployable got killed before we get to it - Lagg...
   if (!isObject(%task.targetObject))
   {
       %client.setTargetObject(-1);

      //if this task is the objective task, choose a new objective
      if (%task == %client.objectiveTask)
         {
            AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
            return;
	 }
    }
      if (%task.targetObject.getDamagePercent() > 0)
      {
         //make sure we still have equipment
		%client.needEquipment = AINeedEquipment(%task.equipment, %client);
         if (%client.needEquipment)
         {
         //if this task is the objective task, choose a new objective
         if (%task == %client.objectiveTask)
			{
            AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
				return;
			}
         }
      
		if (%task.deployed)
		{
			//see if we're within range of the deploy location
		   %clLoc = %client.player.position;
		   %distance = VectorDist(%clLoc, %task.repairLocation);
			%dist2D = VectorDist(%client.player.position, getWords(%task.repairLocation, 0, 1) SPC getWord(%client.player.position, 2));

			//set the aim when we get near the target...  this will be overwritten when we're actually trying to repair deployed
 			if (%distance < 10 && %dist2D < 10)
 		      %client.aimAt(%task.location, 1000);

			//see if we're at the deploy location
		   if ((%client.pathDistRemaining(20) > %distance + 0.25) || %dist2D > 0.3)
			{
	         %client.setTargetObject(-1);
		      %client.stepMove(%task.repairLocation, 0.25);
			}
			else
			{
				%client.stop();
                                %client.setTargetObject(%task.targetObject, 12, "Repair");//increased range - Lagg...
			}
		}
		else
		{
                        //modified here in case bot gets stuck trying to get to repair spot - Lagg... - 4-21-2003
			%currentTime = getSimTime();
			if (%currentTime > %task.needToRangeTime)
			{
				//force a rangeObject every 45 seconds...
                                %task.needToRangeTime = %currentTime + 45000;
				%client.setTargetObject(-1);
                                %client.setDangerLocation(%task.targetObject.position, 15);
                                //%client.player.cycleWeapon();
                                //if ( !%client.player.getImageTrigger( $BackpackSlot ) )
                                   //%client.player.setImageTrigger( $BackpackSlot, true );
                                
                                //if the objective marker was moved than we have a problemed target
                                //and we move to the objective marker to fix bot getting stuck trying
                                //to repair object - Lagg... 10-10-2003            
                                if (%task.targetObject.getWorldBoxCenter() == %task.location)
                                   %client.stepRangeObject(%task.targetObject, "DefaultRepairBeam", 2, 4);                                                  else
	                           %client.stepMove(%task.location);
			}

	      //if we've ranged the object, start repairing, else unset the object
	      else if (%client.getStepStatus() $= "Finished")
			{
				//dissolve the human control link
				if (%task == %client.objectiveTask)
					aiReleaseHumanControl(%client.controlByHuman, %client);

	         %client.setTargetObject(%task.targetObject, 12, "Repair");
			}
	      else
	         %client.setTargetObject(-1);
		}
   }
   else
   {
      %client.setTargetObject(-1);
      
      //if this task is the objective task, choose a new objective
      if (%task == %client.objectiveTask)
		{
         AIUnassignClient(%client);
			Game.AIChooseGameObjective(%client);
		}
   }
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Tank Patrol  +++

function AIOTankPatrol::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   // if were playing CnH, check who owns this
   if (%this.targetObjectId > 0)
   {
      if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team != %client.team)
         return 0;
   }
   
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

   //do a quick check to disqualify this objective if it can't meet the minimum weight
   if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
   {
      if (%this.targetObjectId > 0 && %this.issuedByClientId == %client.controlByHuman)
      {
         if ($AIWeightHumanIssuedCommand < %minWeight)
	    return 0;
      }
      else
         return 0;
   }

   //if the enemy turrets are down no need to contuinue
   %tur1 = nameToId("Team2TurretBaseLarge1");
   %tur2 = nameToId("Team2TurretBaseLarge2");
   if (%tur1.isDisabled() && %tur2.isDisabled())
   {
      //error("tur1 and tur2 destroyed");
      return 0;
   }

   //check for Vehicle station near buy of forget it - Lagg...
   %clVs = AIFindClosestVStation(%client);
   if (%clVs > 0)
   {
      %closestVs = getWord(%clVs, 0);
      %closestVsDist = getWord(%clVs, 1);
      if (%closestVsDist > 250)
         return 0;
   }
   else 
      return 0;

   //check how many vehicles of this type are in the field - Lagg..
   %blockName = "AssaultVehicle";
   if (!vehicleCheck(%blockName, %client.team))
   {
      error("AIOTankSpam::weight 2 - To many Tanks in the field return 0");
      return 0;
   }

   %weight = AIODefault::weight(%this, %client, %level, %inventoryStr);

   //if the object has been destroyed, reduce the weight
   if (%this.targetObjectId > 0)
   {
      //see if we were forced on the objective
      if (%this.issuedByClientId == %client.controlByHuman && %weight < $AIWeightHumanIssuedCommand)
         %weight = $AIWeightHumanIssuedCommand;

      //else see if the object has been destroyed
      else if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamageState() $= "Destroyed")
         %weight -= 320;
   }

   return %weight;
}

function AIOTankPatrol::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AITankPatrol);
   %client.objectiveTask.initFromObjective(%this, %client);
   
   //create the escort objective (require a gunner in this case...)
   %client.escort = new AIObjective(AIOEscortPlayer)
                     {
						      dataBlock = "AIObjectiveMarker";
                        weightLevel1 = $AIWeightVehicleMountedEscort;
                        weightLevel2 = 0;
                        description = "Escort " @ getTaggedString(%client.name);
                        targetClientId = %client;
                        offense = true;
                        chat = "ChatNeedHold";
                        equipment = "FlareGrenade";
								buyEquipmentSet = "MediumRepairSet";
                     };
   MissionCleanup.add(%client.escort);

   //the objectives on team1 are all offense objectives, team2 has the defensive ones..
   if (%client.team == game.offenseTeam)
      $ObjectiveQ[1].add(%client.escort);
   else
      $ObjectiveQ[2].add(%client.escort);
}

function AIOTankPatrol::unassignClient(%this, %client)
{
   //kill the escort objective
   if (%client.escort)
   {
      AIClearObjective(%client.escort);
      %client.escort.delete();
      %client.escort = "";
   }   
   if(%client.pilotVehicle)
      {
         AIDisembarkVehicle(%client);
      }  
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Tank Patrol ---

function AITankPatrol::initFromObjective(%task, %objective, %client)
{
   //initialize the task vars from the objective
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   if (%objective.Location !$= "")
      %task.location = %objective.location;
   else
      %task.location = %objective.targetObjectId.getWorldBoxCenter();

   %task.equipment = %objective.equipment;
   %task.buyEquipmentSet = %objective.buyEquipmentSet;
   %task.desiredEquipment = %objective.desiredEquipment;
   %task.issuedByClient = %objective.issuedByClientId;
   %task.chat = %objective.chat;

   //initialize other task vars
   %task.sendMsg = true;
   %task.sendMsgTime = 0;
   %task.path = "";
}

function AITankPatrol::assume(%task, %client)
{
   %task.setWeightFreq(30);
   %task.setMonitorFreq(40);
   
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);

   //even if we don't *need* equipemnt, see if we should buy some... 
   if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
   {
      //see if we could benefit from inventory
      %needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
      %result = AIFindClosestInventory(%client, %needArmor);
      %closestInv = getWord(%result, 0);
      %closestDist = getWord(%result, 1);
      if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
      {
         %result = AIFindClosestEnemy(%client, 100, $AIClientLOSTimeout);
	 %closestEnemy = getWord(%result, 0);
	 %closestEnemydist = getWord(%result, 1);

	 if (%closestEnemy <= 0 || (%closestEnemyDist > %closestDist * 1.5))
	    %client.needEquipment = true;
      }
   }

   //mark the current time for the buy inventory state machine
   %task.buyInvTime = getSimTime();

   //reset the vehicle station wait time
   %client.vsWaitTime = "";

   //set the destination paths for each team and game type

   %team = %client.team;
   %random = mFloor(getRandom(1, 2));
   if (Game.class $= "SiegeGame")
   {
      if (%team == Game.offenseTeam)
      {         
         if (%random == 1)
            %task.group = nameToId(T1TankPath1);
         //if we have an alternate route random path
         else if (isObject(nameToId(T1TankPath2)))
            %task.group = nameToId(T1TankPath2);
         else
            %task.group = nameToId(T1TankPath1);
      }      
      else
      {
         if (%random == 1)
            %task.group = nameToId(T2TankPath1);
         else if (isObject(nameToId(T2TankPath2)))
            %task.group = nameToId(T2TankPath2);
         else
            %task.group = nameToId(T2TankPath1);
      }
   }
   else
   {
      if (%team == 1)
      {         
         if (%random == 1)
            %task.group = nameToId(T1TankPath1);
         else if (isObject(nameToId(T1TankPath2)))
            %task.group = nameToId(T1TankPath2);
         else
            %task.group = nameToId(T1TankPath1);
      }      
      else
      {
         if (%random == 1)
            %task.group = nameToId(T2TankPath1);
         else if (isObject(nameToId(T2TankPath2)))
            %task.group = nameToId(T2TankPath2);
         else
            %task.group = nameToId(T2TankPath1);
      }      
   }      
   
   %task.count = %task.group.getCount();  
   %task.locationIndex = 0;
   %client.needVehicle = true;
}


function AITankPatrol::retire(%task, %client)
{
   if (aiClientIsAlive(%client))
   {
      %client.needVehicle = false;
      %client.clearStep();
      if(%client.player.isMounted())
         AIDisembarkVehicle(%client);
   }
}

function AITankPatrol::weight(%task, %client)
{
   //let the monitor decide when to quit :)
   %task.setWeight(%task.baseWeight);
}

function AITankPatrol::monitor(%task, %client)
{   
   //first, buy equipment
   if (%client.needEquipment)
   {
      %task.setMonitorFreq(5);
      if (%task.equipment !$= "")
         %equipmentList = %task.equipment;
      else
         %equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
      if (%result $= "InProgress")
      {
         //force a nervous reaction every 30 sec - Lagg...
         if (getSimTime() - %task.buyInvTime > 30000)
         {
            %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
            %task.buyInvTime = getSimTime();
         }
         return;
      }
      else if (%result $= "Finished")
      {
         %task.setMonitorFreq(50);
	 %client.needEquipment = false;
      }
      else if (%result $= "Failed")
      {
         //if this task is the objective task, choose a new objective
	 if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
	 return;
      }
   }
   //if we made it past the inventory buying, reset the inv time
   %task.buyInvTime = getSimTime();

   //chat - send the message
   if (%task.sendMsg)
   {
      if (%task.sendMsgTime == 0)
         %task.sendMsgTime = getSimTime();
      else if (getSimTime() - %task.sendMsgTime > 7000)
      {
         %task.sendMsg = false;
         if (%client.isAIControlled())
	 {
	    if (%task.chat !$= "")
	    {
	       %chatMsg = getWord(%task.chat, 0);
	       %chatTemplate = getWord(%task.chat, 1);
	       if (%chatTemplate !$= "")
		  AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
	       else
		  AIMessageThread(%task.chat, %client, -1);
	    }
         }
      }
   }

   if (%client.needVehicle)
   {
      %clVs = AIFindClosestVStation(%client);
      if (%clVs > 0)
      {
         %closestVs = getWord(%clVs, 0);
         %closestVsDist = getWord(%clVs, 1);
      }
      if (%closestVs > 0 && %closestVsDist < 250 && !isObject(%client.player.mVehicle))
      {
         //If we're in light or medium armor, buy the vehicle - Lagg...
         if (%client.player.getArmorSize() !$= "Heavy")
         {        
            %task.baseWeight = 5500;//set high - lagg...
            %task.setMonitorFreq(9);
            %buyResult = aiBuyVehicle(AssaultVehicle, %client);
         }
         else
         {
            //if ai in heavy armor buy equipment
            if (%task == %client.objectiveTask)
	    {
               %task.baseWeight = %client.objectiveWeight;
               %task.equipment = "Medium";
	       %task.buyEquipmentSet = "MediumMissileSet";
               %client.needEquipment = true;
               return;
	    }
         }
           
         if (%buyResult $= "InProgress")
         {
            //clear offensive tags
            %client.lastDamageClient = -1;
            %client.lastDamageTurret = -1;
            %client.shouldEngage = -1;
            %client.setEngageTarget(-1);
            %client.setTargetObject(-1);
            %client.engageRemeq = -1;
            %client.pickUpItem = -1;
	    return;
         }

         else if (%buyResult $= "Finished")
         {
            %client.needVehicle = false;//needed duh!
            //mount the vehicle and go - Lagg...
	    %task.setMonitorFreq(40);
            %client.stop();
            %client.pilotVehicle = true;//needed to allow ai to get in pilot seat
                  
            //throw away any packs that won't fit
	    if (%client.player.getInventory(InventoryDeployable) > 0)
	       %client.player.throwPack();
	    else if (%client.player.getInventory(TurretIndoorDeployable) > 0)
	       %client.player.throwPack();
	    else if (%client.player.getInventory(TurretOutdoorDeployable) > 0)
	       %client.player.throwPack();
         }
         else if (%result $= "Failed")
         {
            //if this task is the objective task, choose a new objective
	    if (%task == %client.objectiveTask)
	    {
	       AIUnassignClient(%client);
	       Game.AIChooseGameObjective(%client);
               return;
	    }
         }
      }
      else if (%closestVs <= 0 && !isObject(%client.player.mVehicle))
      {
         //error("waiting for vehicle to materialize");
         if (%task == %client.objectiveTask)
         {
            //AIUnassignClient(%client);
	    //Game.AIChooseGameObjective(%client);
            //return;
         }
      }
   }

   //let set some variables

   //if we managed to get in vehicle then go
   if (%client.player.isMounted() && isObject(%client.player.mVehicle))
   { 
      //get the vehicle
      %vehicle = %Client.vehicleMounted;

      //get the gunner seat: 0 = empty 1 = full
      %nodeGun = %vehicle.getMountNodeObject(1);

      //should we wait for a gunner?
      if (%nodeGun <= 0)
      {
         %pos = %client.vehicleMounted.position;
	 %pos2D = getWord(%pos, 0) SPC getWord(%pos, 1) SPC "0";
         %dest = %task.location;
	 %dest2D = getWord(%dest, 0) SPC getWord(%dest, 1) SPC "0";
         if (VectorDist(%dest2D, %pos2D) < 20)
            %client.stop();//doen't seem to work if ai is pilot
         else
         {      
            %client.setPilotPitchRange(-0.2, 0.05, 0.05);
	    %client.setPilotDestination(%task.location, 10); //move to wait spot
         }         
      }
      else 
      {
         //little check to see if anybody around

         //first check turret potential targets
         %vehicle = %Client.vehicleMounted;
         %turret = %vehicle.getMountNodeObject(10);
         %target = %turret.getTargetObject();

         //driver see if anybody close to run down (cheat ignor LOS) :) - Lagg...
         %losTimeout = $AIClientMinLOSTime + ($AIClientLOSTimeout * %client.getSkillLevel());
         %result = AIFindClosestEnemyToLoc(%client, %client.player.getWorldBoxCenter(), 70, %losTimeout, true, false);
         %closestEnemy = getWord(%result, 0);
         %closestdist = getWord(%result, 1);

         //check for obstacles
         %vLoc = %vehicle.getWorldBoxCenter();
         //%mask = $TypeMasks::InteriorObjectType | $TypeMasks::TSStaticShapeObjectType;
         InitContainerRadiusSearch(%vLoc, 30, $TypeMasks::InteriorObjectType | $TypeMasks::TSStaticShapeObjectType |
           $TypeMasks::VehicleObjectType);
         %obs = containerSearchNext();
         if (%obs)
         {
            //echo("we got an interior close by");
            //if (getRandom() > 0.95)
            //{
               //if (%task.locationIndex > 1)
               //{
                  //echo("Random change to last dest index :)");
                  //%task.locationIndex--;
               //}
            //}
                  
         }

         if (%target > 0)
            %dist = vectorDist(%vehicle.getWorldBoxCenter(), %target.getWorldBoxCenter());

         //if driver spotted a target
         if (%closestEnemy > 0 && %closestdist < 70 && !%obs)//run em dowm even if gunner has target
         {
            %client.setPilotDestination(%closestEnemy.position, 60);//run em down!
            %client.aimAt(%closestEnemy.position, 1000); 
         }
         else if (%closestEnemy > 0 && %target <= 0 && %closestdist < 200 && !%obs)//only move if gunner has no target
         {
            %client.setPilotDestination(%closestEnemy.position, 10);//shoot em
            %client.aimAt(%closestEnemy.position, 5000);
         }
            
         //if gunner has target - move to target
         else if (%target > 0 && %dist > 250 && !%obs)
         {
            %client.setPilotDestination(%target.position, 20);//if gunner has target move slow
            %client.aimAt(%target.position, 5000); 
         }
              
         //slow down so gunner can hit something
         //else if (%target > 0 && %dist <= 250 && !%obs)
         else if (%target > 0 && %dist <= 250)//don't check for obstacles, just stop
         {
            %client.setPilotDestination(%client.vehicleMounted.position, 0); //this stops him
            %client.aimAt(%target.position, 10000);
         }

         //stop so gunner can chaingun target
         //else if (%target > 0 && %dist < 25 && !%obs)
         else if (%target > 0 && %dist < 35)//since we are stopped no check for %obs
         {
            %client.setPilotDestination(%client.vehicleMounted.position, 0);  //this stops him
            %client.aimAt(%target.position, 10000);
         }
         //if there is no enemy, continue on path
         else
         {
            //set the locations
            %location = %task.group.getObject(%task.locationIndex);

            %pos = %client.vehicleMounted.position;
	    %pos2D = getWord(%pos, 0) SPC getWord(%pos, 1) SPC "0";
	    %dest = %location.position;
	    %dest2D = getWord(%dest, 0) SPC getWord(%dest, 1) SPC "0";

            //are we close to location index marker?
	    if (VectorDist(%dest2D, %pos2D) < 25)//25 meters from marker
	    {
	       //if we have another location index
               if ((%task.count - 1) > %task.locationIndex)//has to be -1 on the groups count
                  %task.locationIndex++;
               //we are at end of trail
	       else
               {
                  if (%task == %client.objectiveTask)
	          {                  
                     if (%client.vehicleMounted )
                     {
                         AIDisembarkVehicle(%client); //Hop off...
                         %client.stepMove(%location.position, 0.25);
                         return;
                     }
	          }
               }
            }
            %client.setPilotDestination(%location.position, 20);
         }
      }
   }
   else if (!%client.player.isMounted())
   {
      //if we at end of path and we hopped out
      if ((%task.count - 1) == %task.locationIndex)//has to be -1 on the groups count
      {
         if (%task == %client.objectiveTask)
	 {
            AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
      }
            
      //did we fall off our bike? if so get back on!
      if (isObject(%client.player.mVehicle) && %client.player.mVehicle.getDamageState() !$= "Destroyed" && %client.pilotVehicle)
      {
         //if ai in heavy armor buy equipment
         if (%task == %client.objectiveTask)
	 {
            %task.baseWeight = %client.objectiveWeight;
            %task.equipment = "Medium";
	    %task.buyEquipmentSet = "MediumMissileSet";
            %client.needEquipment = true;
            return;
	 }

         //check if someone stole our bike
         if (%client.player.mVehicle.getMountNodeObject(0) > 0)
         {
            if (%task == %client.objectiveTask)
	    {
               error("Tank Stolen !");
               AIUnassignClient(%client);
	       Game.AIChooseGameObjective(%client);
               return;
            }
         }

         //throw away any packs that won't fit
	 if (%client.player.getInventory(InventoryDeployable) > 0)
	    %client.player.throwPack();
	 else if (%client.player.getInventory(TurretIndoorDeployable) > 0)
	    %client.player.throwPack();
	 else if (%client.player.getInventory(TurretOutdoorDeployable) > 0)
	    %client.player.throwPack();

         %client.pilotVehicle = true;//needed to let ai mount pilot seat
         %client.stepMove(%client.player.mVehicle.position, 0.25, $AIModeMountVehicle);
      }

      //did someone shoot our legs out? if so we are done!
      else if (isObject(%client.player.mVehicle) && %client.player.mVehicle.getDamageState() $= "Destroyed")
      {
         if (%task == %client.objectiveTask)
	 {
            AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }				
      }
   }
}

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ AIO Touch Object +++

function AIOTouchObject::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

	if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
		return 0;

   switch$ (%this.mode)
   {
      case "TouchFlipFlop":
         if(%this.targetObjectId.team == %client.team || %this.targetObjectId.isHidden())
	    return 0;

         //added a check for siege games to enhance the ai, fix navGraph bug with forcefileds - Lagg...
         else if ($CurrentMissionType $= "Siege")
         {
            InitContainerRadiusSearch(%this.location, 12, $TypeMasks::ForceFieldObjectType);
            %objSearch = containerSearchNext();
            if (%objSearch > 0 && %objSearch.isPowered() && %objSearch.team != %client.team)
               return 0;
            else
	       return AIODefault::weight(%this, %client, %level, %inventoryStr);
         }
	 else
	    return AIODefault::weight(%this, %client, %level, %inventoryStr);
      case "FlagGrab":
			if (! %this.targetObjectId.isHome)
				return 0;
			else
	         return AIODefault::weight(%this, %client, %level, %inventoryStr);
      case "FlagDropped":
			if ((%this.targetObjectId.isHome) || (%this.targetObjectId.carrier !$= ""))
				return 0;
			else
	         return AIODefault::weight(%this, %client, %level, %inventoryStr);
      case "FlagCapture":
			if (%this.targetObjectId.carrier != %client.player)
            return 0;
         else
			{
				//find our home flag location
				%homeTeam = %client.team;
				%homeFlag = $AITeamFlag[%homeTeam];
				%this.location = %homeFlag.originalPosition;
				return AIODefault::weight(%this, %client, %level, %inventoryStr);
			}
   }
   return 0;
}

function AIOTouchObject::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AITouchObject);
   %client.objectiveTask.initFromObjective(%this, %client);
   
   //create an AIOEscortPlayer objective to help out, if required
   if (%this.mode $= "FlagGrab")
   {
      //%client.escort = new AIObjective(AIOEscortPlayer)
                        //{
							      //dataBlock = "AIObjectiveMarker";
                           //weightLevel1 = $AIWeightEscortOffense[1];
                           //weightLevel2 = $AIWeightEscortOffense[2];
                           //description = "Escort " @ getTaggedString(%client.name);
                           //targetClientId = %client;
                           //offense = true;
									//desiredEquipment = "EnergyPack";
									//buyEquipmentSet = "LightEnergyELF";
                        //};
      //MissionCleanup.add(%client.escort);
      //$ObjectiveQ[%client.team].add(%client.escort);

      %client.escort = new AIObjective(AIOAttackLocation) {
					position = %this.targetObjectId.position;
					dataBlock = "AIObjectiveMarker";
					lockCount = "0";
					homingCount = "0";
					targetClientId = "-1";
					targetObjectId = "-1";
					location = %this.targetObjectId.position;
					weightLevel1 = $AIWeightEscortOffense[1];
					weightLevel2 = "0";
					weightLevel3 = "0";
					weightLevel4 = "0";
					offense = "1";
					defense = "0";
                                        desiredEquipment = "SniperRifle EnergyPack";
					buyEquipmentSet = "LightEnergySniper";
					chat = "ChatCmdAttackFlag";
					issuedByHuman = "0";
					issuedByClientId = "-1";
					forceClientId = "-1";
				};
      MissionCleanup.add(%client.escort);
      $ObjectiveQ[%client.team].add(%client.escort);
      
      %client.escort1 = new AIObjective(AIOMAttackLocation) {
					position = %this.targetObjectId.position;
					dataBlock = "AIObjectiveMarker";
					lockCount = "0";
					homingCount = "0";
					targetClientId = "-1";
					targetObjectId = "-1";
					location = %this.targetObjectId.position;
					weightLevel1 = "3600";
					weightLevel2 = "0";
					weightLevel3 = "0";
					weightLevel4 = "0";
					offense = "1";
					defense = "0";
                    equipment = "Mortar MortarAmmo";
                    buyEquipmentSet = "HeavyAmmoSet";
					chat = "ChatCmdTargetFlag";
					issuedByHuman = "0";
					issuedByClientId = "-1";
					forceClientId = "-1";
				};
      MissionCleanup.add(%client.escort1);
      $ObjectiveQ[%client.team].add(%client.escort1);
   }   
   else if (%this.mode $= "FlagCapture")
   {
      %client.escort = new AIObjective(AIOEscortPlayer)
                        {
							      dataBlock = "AIObjectiveMarker";
                           weightLevel1 = $AIWeightEscortCapper[1];
                           weightLevel2 = $AIWeightEscortCapper[2];
                           description = "Escort " @ getTaggedString(%client.name);
                           targetClientId = %client;
                           offense = true;
									desiredEquipment = "EnergyPack";
									buyEquipmentSet = "LightEnergyDefault";
                           chat = "ChatCmdDefendCarrier";
                        };
      MissionCleanup.add(%client.escort);
      $ObjectiveQ[%client.team].add(%client.escort);
   }
}

function AIOTouchObject::unassignClient(%this, %client)
{
   //kill the escort objective
   if (%client.escort)
   {
      AIClearObjective(%client.escort);
      %client.escort.delete();
      %client.escort = "";
   }
   if (%client.escort1)
   {
      AIClearObjective(%client.escort1);
      %client.escort1.delete();
      %client.escort1 = "";
   }
   
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

//----------------------------------------------------------------------------------------------- AI Touch Object ---
//ramdom set to go for flag/flipflop -                                      - Lagg... - 4-14-2003

function AITouchObject::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   %task.mode = %objective.mode;
   %task.equipment = %objective.equipment;
   %task.buyEquipmentSet = %objective.buyEquipmentSet;
   %task.desiredEquipment = %objective.desiredEquipment;
   %task.issuedByClient = %objective.issuedByClientId;
   %task.chat = %objective.chat;
   %task.useTeleport = false;

   %task.sendMsgTime = 0;
   if (%task.mode $= "FlagGrab" || %task.mode $= "FlagCapture")
      %task.sendMsg = true;
   else
      %task.sendMsg = false;
   if (%task.mode $= "FlagCapture")
      %task.location = %objective.location;
   else if(%task.mode $= "TouchFlipFlop" || %task.mode $= "FlagGrab")
   {
      %task.location = %objective.location;
      //pick a random set based on armor...
      %randNum = getRandom();
      if (%randNum < 0.2)
      {
         %task.desiredEquipment = "SensorJammerPack";
         %task.buyEquipmentSet = "HeavyEnergySet";
      }
      else if (%randNum < 0.4)
      {
         %task.desiredEquipment = "SensorJammerPack";
         %task.buyEquipmentSet = "LightSensorJammer";
      } 
      else if (%randNum < 0.6)
      {
         %task.desiredEquipment = "CloakingPack";
         %task.buyEquipmentSet = "LightCloakSet";
      }
      else if (%randNum < 0.8)
      {
         %task.desiredEquipment = "ShieldPack";
         %task.buyEquipmentSet = "HeavyShieldOff";
      }
      else
      {
         %task.desiredEquipment = "EnergyPack";
         %task.buyEquipmentSet = "LightEnergySniper";
      }
   }
   else
      %task.location = "";
}

function AITouchObject::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(15);
   %task.engageTarget = 0;
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);

   //even if we don't *need* equipemnt, see if we should buy some... 
   if (! %client.needEquipment && (%task.mode $= "FlagGrab" || %task.mode $= "TouchFlipFlop") && %task.buyEquipmentSet !$= "")
   {
      //see if we could benefit from inventory
      %needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
      %result = AIFindClosestInventory(%client, %needArmor);
      %closestInv = getWord(%result, 0);
      %closestDist = getWord(%result, 1);
      if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
      {
         //find where we are
	 %clientPos = %client.player.getWorldBoxCenter();
	 %distToObject = %client.getPathDistance(%task.location);
	 if (%distToObject < 0 || %closestDist < %distToObject)
	    %client.needEquipment = true;
      }
   }

   //mark the current time for the buy inventory state machine
   %task.buyInvTime = getSimTime();

   //--------------------------------------------------- assume telporter - start -
   //if the MPB Teleporter is online - Lagg... 9-30-2003

   //first check for deployed MPB
   %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
   %closestMPB = getWord(%result, 0);
   %closestMPBDist = getWord(%result, 1);
      
   //next find the teleporter
   %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
   %closestTel = getWord(%result, 0);
   %closestTelDist = getWord(%result, 1);
      
   //now check for what would be closer - Lagg... 10-1-2003
   if (%closestMPB > 0 && %closestTel > 0)
   {
      %disToTarg = %client.getPathDistance(%task.location);
      %mpbDisToTarg = vectorDist(%closestMPB.getTransform(), %task.location);
         
      if (%closestTelDist < %closestMPBDist && %closestMPBDist < %disToTarg && %mpbDisToTarg < %disToTarg)
         %task.useTeleport = true;//new - Lagg... 10-1-2003
      else
         %task.useTeleport = false;             
   }
   //--------------------------------------------------- assume telporter - end -
}

function AITouchObject::retire(%task, %client)
{
}

function AITouchObject::weight(%task, %client)
{
   //update the task weight
   if (%task == %client.objectiveTask)
      %task.baseWeight = %client.objectiveWeight;

   //see if we can find someone to shoot at...
   if (%client.getEngageTarget() <= 0)
   {
      %losTimeout = $AIClientMinLOSTime + ($AIClientLOSTimeout * %client.getSkillLevel());
      %myLocation = %client.player.getWorldBoxCenter();
      %result = AIFindClosestEnemy(%client, 40, %losTimeout);
      %task.engageTarget = getWord(%result, 0);
   }
   
   %task.setWeight(%task.baseWeight);
}

function AITouchObject::monitor(%task, %client)
{
   //--------------------------------------------------- monitor telporter - start -
   //are we using teleporter
   if (%task.useTeleport)
   {
      %result = AIFindDeployedMPB(%client);//new function in aiVehicle.cs
      %closestMPB = getWord(%result, 0);
      %closestMPBDist = getWord(%result, 1);
      %result = SweepForTeleporters(%client);//new function in aiVehicle.cs
      %closestTel = getWord(%result, 0);
      %closestTelDist = getWord(%result, 1);
      if (%closestMPB > 0 && %closestTel > 0)
      {
         //we are done teleporting
         if (%closestMPBDist < %closestTelDist)
         {
            //reset the clients inventory status
            if (%client.needEquipment)
            {
               %result = AIFindClosestInventory(%client, 0);
	       %closestInv = getWord(%result, 0);
               %client.invToUse = %closestInv;
               error("resetting client's inventory to use");
            }
            %task.useTeleport = false;
            return;
         }

         if (%closestTelDist < 2)
            %client.pressJump();
         else
         {
            %client.stepMove(%closestTel.getWorldBoxCenter(), 0.25);
            return;
         }
      }
      else
         %task.useTeleport = false;
   }
   //--------------------------------------------------- monitor telporter - end -

   //%client.needEquipment = AINeedEquipment(%task.equipment, %client);

   //even if we do *need* equipemnt, see if we are too far to go back - Lagg... 
   if (%client.needEquipment && (%task.mode $= "FlagGrab" || %task.mode $= "TouchFlipFlop") && %task.buyEquipmentSet !$= "")
   {
      //see if we could benefit from inventory
      %needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
      %result = AIFindClosestInventory(%client, %needArmor);
      %closestInv = getWord(%result, 0);
      %closestDist = getWord(%result, 1) + 400;
      if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
      {
         //find where we are
         %clientPos = %client.player.getWorldBoxCenter();
         %distToObject = vectorDist(%clientPos, %task.location);
         if (%distToObject < 0 || %closestDist > %distToObject)
            %client.needEquipment = false;
      }
   }

   //first, buy the equipment
   if (%client.needEquipment)
   {
      %task.setMonitorFreq(5);
      if (%task.equipment !$= "")
         %equipmentList = %task.equipment;
      else
	 %equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
      if (%result $= "InProgress")
      {
         //force a nervous reaction every 10 sec - Lagg...
         if (getSimTime() - %task.buyInvTime > 10000)
         {
            %client.setDangerLocation(%client.player.getWorldBoxCenter(), 15);
            %task.buyInvTime = getSimTime();
         }
         return;
      }
      else if (%result $= "Finished")
      {
         %task.setMonitorFreq(15);
	 %client.needEquipment = false;
      }
      else if (%result $= "Failed")
      {
         //if this task is the objective task, choose a new objective
	 if (%task == %client.objectiveTask)
	 {
	    AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	 }
	 return;
      }
   }

   //if we made it past the inventory buying, reset the inv time
   %task.buyInvTime = getSimTime();

   //chat
   if (%task.sendMsg)
   {
      if (%task.sendMsgTime == 0)
         %task.sendMsgTime = getSimTime();
      else if (getSimTime() - %task.sendMsgTime > 7000)
      {
         %task.sendMsg = false;
	 if (%client.isAIControlled())
	 {
	    if (%task.chat !$= "")
	    {
	       %chatMsg = getWord(%task.chat, 0);
	       %chatTemplate = getWord(%task.chat, 1);
	       if (%chatTemplate !$= "")
	          AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
	       else
		  AIMessageThread(%task.chat, %client, -1);
            }
         }
      }
   }

   //keep updating the position, in case the flag is flying through the air...
   if (%task.location !$= "")
      %touchPos = %task.location;
   else
      %touchPos = %task.targetObject.getWorldBoxCenter();
      
   //see if we need to engage a new target
   %engageTarget = %client.getEngageTarget();
   if (!AIClientIsAlive(%engageTarget) && %task.engageTarget > 0)
      %client.setEngageTarget(%task.engageTarget);
   
   //else see if we should abandon the engagement
   else if (AIClientIsAlive(%engageTarget))
   {
      %myPos = %client.player.getWorldBoxCenter();
      %testPos = %engageTarget.player.getWorldBoxCenter();
      %distance = %client.getPathDistance(%testPos);
      if (%distance < 0 || %distance > 70)
         %client.setEngageTarget(-1);
   }

   //see if we have completed our objective
   if (%task == %client.objectiveTask)
   {
      %completed = false;
      switch$ (%task.mode)
      {
         case "TouchFlipFlop":
	    if (%task.targetObject.team == %client.team)
	       %completed = true;
	 case "FlagGrab":
	    if (!%task.targetObject.isHome)
               %completed = true;
	 case "FlagDropped":
	    if ((%task.targetObject.isHome) || (%task.targetObject.carrier !$= ""))
	       %completed = true;
	 case "FlagCapture":
	    if (%task.targetObject.carrier != %client.player)
	       %completed = true;
      }
      if (%completed)
      {
         AIUnassignClient(%client);
	 Game.AIChooseGameObjective(%client);
	 return;
      }
   }

   if (%task.mode $= "FlagCapture")
   {
      %homeFlag = $AITeamFlag[%client.team];

      //if we're within range of the flag's home position, and the flag isn't home, start idling...
      if (VectorDist(%client.player.position, %touchPos) < 40 && !%homeFlag.isHome)
      {
         if (%client.getStepName() !$= "AIStepIdlePatrol")
	    %client.stepIdle(%touchPos);
      }
      else
         %client.stepMove(%touchPos, 0.25);
   }

   //if siege game we want a special way of capturing the flip flop - Lagg... 9-11-2003
   else if ((%task.mode $= "TouchFlipFlop") && ($CurrentMissionType $= "Siege"))
   {

      //if there is a force field blocking the way - Lagg... 9-11-2003
      InitContainerRadiusSearch(%touchPos, 12, $TypeMasks::ForceFieldObjectType);
      %objSearch = containerSearchNext();
      if (%objSearch > 0 && %objSearch.isPowered())//should we check for all pass force fields? - Lagg ... (nah)
      {
         if (%task == %client.objectiveTask)
         {
            AIUnassignClient(%client);
	    Game.AIChooseGameObjective(%client);
	    return;
         }
      }
      else
         %client.stepMove(%touchPos, 0.25);
   }
   else
      %client.stepMove(%touchPos, 0.25);

   if (VectorDist(%client.player.position, %touchPos) < 10)
   {
      //dissolve the human control link
      if (%task == %client.objectiveTask)
      {
         if (aiHumanHasControl(%task.issuedByClient, %client))
	 {
	    aiReleaseHumanControl(%client.controlByHuman, %client);

	    //should re-evaluate the current objective weight
	    %inventoryStr = AIFindClosestInventories(%client);
	    %client.objectiveWeight = %client.objective.weight(%client, %client.objectiveLevel, 0, %inventoryStr);
	 }
      }
   }

   //see if we're supposed to be engaging anyone...
   if (!AIClientIsAlive(%client.getEngageTarget()) && AIClientIsAlive(%client.shouldEngage))
      %client.setEngageTarget(%client.shouldEngage);
}


//--------------------------------------------------------------------------------------------------------------------------
//AI Objective functions

function ClientHasAffinity(%objective, %client)
{
   if (%objective.offense && %client.offense)
      return true;
   else if (%objective.defense && !%client.offense)
      return true;
   else
      return false;
}

function ClientHasRequiredEquipment(%objective, %client)
{
   return true;
}

function AIODefault::weight(%objective, %client, %level, %inventoryStr)
{
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

   //set the base weight
   switch (%level)
   {
      case 1:
         %weight = %objective.weightLevel1;
      case 2:
         %weight = %objective.weightLevel2;
      case 3:
         %weight = %objective.weightLevel3;
      default:
         %weight = %objective.weightLevel4;
   }
   
   //check Affinity
   if (ClientHasAffinity(%objective, %client))
      %weight += 40;

	//if the objective doesn't require any equipment, it automatically get's the +100...
	if (%objective.equipment $= "" && %objective.desiredEquipment $= "")
		%weight += 100;
	else
	{
		//check equipment requirement
		%needEquipment = AINeedEquipment(%objective.equipment, %client);
	      
	   //check Required equipment
	   if (%objective.equipment !$= "" && !%needEquipment)
	      %weight += 100;

		//figure out the percentage of desired equipment the bot has
		else if (%objective.desiredEquipment !$= "")
		{
			%count = getWordCount(%objective.desiredEquipment);
			%itemCount = 0;
			for (%i = 0; %i < %count; %i++)
			{
				%item = getWord(%objective.desiredEquipment, %i);
				if (!AINeedEquipment(%item, %client))
					%itemCount++;
			}

			//add to the weight
			%weight += mFloor((%itemCount / %count) * 75);
		}
	}
      
   //find the distance to target
   if (%objective.targetClientId !$= "" || %objective.targetObjectId !$= "")
   {
      if (AIClientIsAlive(%objective.targetClientId))
      {   
         %targetPos = %objective.targetClientId.player.getWorldBoxCenter();
      }
      else if (VectorDist(%objective.location, "0 0 0") > 1)
         %targetPos = %objective.location;
      else
      {   
         if(%objective.targetObjectId > 0)
            %targetPos = %objective.targetObjectId.getWorldBoxCenter();
      }
   }
        //make sure the destination is accessible
        %distance = %client.getPathDistance(%targetPos);
	if (%distance < 0)
           return 0;

	%closestInvIsRemote = (getWordCount(%inventoryStr) == 4);
	%closestInv = getWord(%inventoryStr, 0);
	%closestDist = getWord(%inventoryStr, 1);
	%closestRemoteInv = getWord(%inventoryStr, 2);
	%closestRemoteDist = getWord(%inventoryStr, 3);
	
   //if we need equipment, the distance is from the client, to an inv, then to the target
 	if (%needEquipment)
 	{
		//if we need a regular inventory station, and one doesn't exist, exit
		if (!isObject(%closestInv) && %needArmor)
			return 0;

		//find the closest inv based on whether we require armor (from a regular inv station)
		if (!%closestInvIsRemote)
		{
			%needArmor = false;
			%weightDist = %closestDist;
			%weightInv = %closestInv;
		}
		else
		{
	 		%needArmor = AIMustUseRegularInvStation(%objective.equipment, %client);
			if (%needArmor)
			{
				%weightDist = %closestDist;
				%weightInv = %closestInv;
			}
			else
			{
				%weightDist = %closestRemoteDist;
				%weightInv = %closestRemoteInv;
			}
		}

		//if we don't need armor, and there's no inventory station, see if the equipment we need
		//is something we can pick up off the ground (likely this would be a repair pack...)
		if (%weightDist >= 32767)
		{
  			%itemType = getWord(%objective.equipment, 0);
  			%found = false;
  			%itemCount = $AIItemSet.getCount();
  			for (%i = 0; %i < %itemCount; %i++)
  			{
  				%item = $AIItemSet.getObject(%i);
  				if (%item.getDataBlock().getName() $= %itemType && !%item.isHidden())
  				{
					%weightDist = %client.getPathDistance(%item.getWorldBoxCenter());
					if (%weightDist > 0)
					{
						%weightInv = %item;  //set the var so the distance function will work...
	  					%found = true;
	  					break;
					}
  				}
  			}
  			if (! %found)
  				return 0;
  		}
 
		//now find the distance used for weighting the objective
		%tempDist = AIGetPathDistance(%targetPos, %weightInv.getWorldBoxCenter());
		if (%tempDist < 0)
			%tempDist = 32767;
		%distance = %weightDist + %tempDist;
 	}
   
   //see if we're within 200 m
   if (%distance < 200)
      %weight += 30;
      
   //see if we're within 90 m
   if (%distance < 90)
      %weight += 30;

   //see if we're within 45 m
   if (%distance < 45)
      %weight += 30;
      
   //see if we're within 20 m
   if (%distance < 20)
      %weight += 30;

   //lets give him some personallity on this one :) - Lagg...
   if (%objective.targetObjectId > 0)
   {
      if ((findTargetInView(%client, 150)) == %objective.targetObjectId)
         %weight += 200;
   }
   
   //final return, since we've made it through all the rest
   return %weight;
}

function AIODefault::QuickWeight(%objective, %client, %level, %minWeight)
{
	//can't do a quick weight when re-evaluating a client's current objective
	if (%client.objective == %objective)
		return true;

	//do a quick check to disqualify this objective if it can't meet the minimum weight
	switch (%level)
	{
	   case 1:
	      %testWeight = %objective.weightLevel1;
	   case 2:
	      %testWeight = %objective.weightLevel2;
	   case 3:
	      %testWeight = %objective.weightLevel3;
	   default:
	      %testWeight = %objective.weightLevel4;
	}
	if (%testWeight + 260 < %minWeight)
		return false;
	else
		return true;
}

//--------------------------------------------------------------
//AI Objective Q functions...

$ObjectiveClientsSet = 0;
function AIObjectiveFindClients(%objective)
{
   //create and clear the set
   if (! $ObjectiveClientsSet)
   {
      $ObjectiveClientsSet = new SimSet();
      MissionCleanup.add($ObjectiveClientSet);
   }
   $ObjectiveClientsSet.clear();
   
   %clientCount = 0;
   %count = ClientGroup.getCount();
   for(%i = 0; %i < %count; %i++)
   {
		%cl = ClientGroup.getObject(%i);
      if (%cl.objective == %objective)
         $ObjectiveClientsSet.add(%cl);
   }
   return $ObjectiveClientsSet.getCount();
}

function AIObjectiveGetClosestClient(%location, %team)
{
   if (%location $= "")
      return -1;
      
   if (%team $= "")
      %team = 0;
      
   %closestClient = -1;
   %closestDistance = 32767;
   %count = ClientGroup.getCount();
   for(%i = 0; %i < %count; %i++)
   {
		%cl = ClientGroup.getObject(%i);
      if (%cl.isAIControlled() && (%cl.team == %team || %team == 0) && AIClientIsAlive(%cl))
      {
         %testPos = %cl.player.getWorldBoxCenter();
         %distance = VectorDist(%location, %testPos);
         if (%distance < %closestDistance)
         {
            %closestDistance = %distance;
            %closestClient = %cl;
         }
      }
	}
   
   return %closestClient;
}

function AICountObjectives(%team)
{
	%objCount = 0;
	%count = $ObjectiveQ[%team].getCount();
	for (%i = 0; %i < %count; %i++)
	{
		%grp = $ObjectiveQ[%team].getObject(%i);
		if (%grp.getClassName() !$= "AIObjective")
			%objCount += %grp.getCount();
		else
			%objCount++;
	}
	error("DEBUG" SPC %team SPC "has" SPC %objCount SPC "objectives.");
}

function AIAddTableObjective(%objective, %weight, %level, %bump, %position)
{
	$objTable[%position, objective] = %objective;
	$objTable[%position, weight] = %weight;
	$objTable[%position, level] = %level;
	$objTable[%position, bump] = %bump;
	$objTableCount = %position + 1;
}

function AIChooseObjective(%client, %useThisObjectiveQ)
{
        //if(%client.player.ismounted() || %client.pilotVehicle)
           //return;

	//pick which objectiveQ to use, or use the default
	if (%useThisObjectiveQ <= 0 && %client.team < 0)
		return;

	if (%useThisObjectiveQ <= 0)
		%useThisObjectiveQ = $ObjectiveQ[%client.team];

	if (!isObject(%useThisObjectiveQ) || %useThisObjectiveQ.getCount() <= 0)
		return;

	//since most objectives check for inventory, find the closest inventory stations first
	%inventoryStr = AIFindClosestInventories(%client);

   //find the most appropriate objective
   if (!%client.objective)
	{
		//note, the table is never empty, during the course of this function
		AIAddTableObjective(0, 0, 0, 0, 0);
	}
   else
	{
		//should re-evaluate the current objective weight - but never decrease the weight!!!

                //Capto Lamia and ZOD have attempted to fix this function in the past.
                //This function works fine! It is the AIO Objective weights that are causing spam errors.
                //This function works on the object weights for each objective.
                //Objectives that create another objective (ie. AIOMortarObject, AIOTouchObject)
                //have very touchy weights.
                //I have tested this and found that the weights I set
                //in ai.cs should be left alone. - Lagg... 9-28-2003

                //a little change here or bots can't use vehicles :( - Lagg... *TEST FURTHER*
                //this next line I don't get, how could you ask for so many varibles and only use 1?
                //AI spends more time bumping each other than they do acually playing tribes 2. 
		//%testWeight = %client.objective.weight(%client, %client.objectiveLevel, 0, %inventoryStr);
                %testWeight = %client.objectiveTask.baseWeight;
                
		if (%testWeight <= 0 || %testWeight > %client.objectiveWeight)
			%client.objectiveWeight = %testWeight;

		if (%client.objectiveWeight > 0)
			AIAddTableObjective(%client.objective, %client.objectiveWeight, %client.objectiveLevel, 0, 0);
		else
			AIAddTableObjective(0, 0, 0, 0, 0);
	}

   %objCount = %useThisObjectiveQ.getCount();
 	for (%i = 0; %i < %objCount; %i++)
 	{
	   %objective = %useThisObjectiveQ.getObject(%i);

		//don't re-evaluate the client's own
		if (%objective == %client.objective)
			continue;

		//try this objective at each of the 4 weight levels to see if it is weighted higher
		for (%level = 1; %level <= 4; %level++)
		{
			%minWeight = 0;
			%bumpWeight = 0;
			%bumpClient = "";

			//we can bump clients off the objective for the first three levels
			if (%level <= 3)
			{
				//if the objective is part of a group, check the whole group
				if (%objective.group > 0)
				{
					%bumpClient = %objective.group.clientLevel[%level];
					%bumpWeight = %bumpClient.objectiveWeight;
				}
				else
				{
					%bumpClient = %objective.clientLevel[%level];
					%bumpWeight = %bumpClient.objectiveWeight;
				}
			}

			//find the minimum weight the objective must have to be considered
			%minWeight = (%bumpWeight > $objTable[0, weight] ? %bumpWeight : $objTable[0, weight]);

			//evaluate the weight
	                %weight = %objective.weight(%client, %level, %minWeight, %inventoryStr);

			//make sure we got a valid weight
			if (%weight <= 0)
				break;

			//if it's the highest so far, it now replaces anything else in the table
			if (%weight > $objTable[0, weight])
			{
				//never bump someone unless you out- weight them
				if (%weight > %bumpWeight)
				{
					AIAddTableObjective(%objective, %weight, %level, %bumpClient, 0);

					//no need to keep checking the other levels
					break;
				}
			}

			//else if it's equal to the highest objective we've seen so far, and higher from our current objective
			else if (%weight == $objTable[0, weight] && %weight > %client.objectiveWeight)
			{
				//never bump someone unless you outweigh them
				if (%weight > %bumpWeight)
				{
					//if this wouldn't require us to bump someone, or the table is empty
					if (%bumpWeight <= 0 || $objTable[0, weight] <= 0)
					{
						//if the table currently contains objectives which would require bumping someone, clear it
						if ($objTable[0, bump] > 0)
							%position = 0;
						else
							%position = $objTableCount;

						//add it to the table
						AIAddTableObjective(%objective, %weight, %level, %bumpClient, %position);

						//no need to keep checking the other levels
						break;
					}

					//otherwise, the table is not empty, and this would require us to bump someone
					//only add it if everything else in the table would also require us to bump someone
					else if ($objTable[0, bump] > 0)
					{
						AIAddTableObjective(%objective, %weight, %level, %bumpClient, $objTableCount);

						//no need to keep checking the other levels
						break;
					}
				}
			}

			//else it must have been less than our highest objective so far- again, no need to keep checking other levels...
			else
				break;
		}
	}

	//if we have a table of possible objectives which are higher than our current- choose one at random
	if ($objTableCount > 0 && $objTable[0, objective] != %client.objective)
	{
		//choose the new one
		%index = mFloor(getRandom() * ($objTableCount - 0.01));

		//clear the old objective
      if (%client.objective)
      {
         if (%client.objectiveLevel <= 3)
			{
				if (%client.objective.group > 0)
				{
					if (%client.objective.group.clientLevel[%client.objectiveLevel] == %client)
						%client.objective.group.clientLevel[%client.objectiveLevel] = "";
				}
				else
				{
					if (%client.objective.clientLevel[%client.objectiveLevel] == %client)
		                                %client.objective.clientLevel[%client.objectiveLevel] = "";
				}
			}
         %client.objective.unassignClient(%client);
      }
		
		//assign the new
      %chooseObjective = $objTable[%index, objective];
      %client.objective = %chooseObjective;
      %client.objectiveWeight = $objTable[%index, weight];
      %client.objectiveLevel = $objTable[%index, level];
		if (%client.objectiveLevel <= 3)
		{
			if (%chooseObjective.group > 0)
		      %chooseObjective.group.clientLevel[%client.objectiveLevel] = %client;
			else
		      %chooseObjective.clientLevel[%client.objectiveLevel] = %client;
		}
      %chooseObjective.assignClient(%client);//this spams but this works unless my AIobjectives are wrong - lagg...

      //see if this objective needs to be acknowledged
      if (%chooseObjective.shouldAcknowledge && %chooseObjective.issuedByHuman && isObject(%chooseObjective.issuedByClientId))
      {
         //cancel any pending acknowledgements - a bot probably just got bumped off this objective
         cancel(%chooseObjective.ackSchedule);
         %chooseObjective.ackSchedule = schedule(5500, %chooseObjective, "AIAcknowledgeObjective", %client, %chooseObjective);
      }

      //if we had to bump someone off this objective, 
		%bumpClient = $objTable[%index, bump];
      if (%bumpClient > 0)
      {
         //unassign the bumped client and choose a new objective
			AIUnassignClient(%bumpClient);
         Game.AIChooseGameObjective(%bumpClient);
      }
	}

   //debuging - refresh aidebugq() if required
   //if ($AIDebugTeam >= 0)
      //aiDebugQ($AIDebugTeam);
}

function AIAcknowledgeObjective(%client, %objective)
{
   %objective.shouldAcknowledge = false;
   //make sure the client is still assigned to this objective
   if (%client.objective == %objective)
	   serverCmdAcceptTask(%client, %objective.issuedByClientId, -1, %objective.ackDescription);
}

function AIForceObjective(%client, %newObjective, %useWeight)
{
   //if we found a new objective, release the old, and assign the new
   if (%newObjective && %newObjective != %client.objective)
   {
      //see if someone was already assigned to this objective
		if (%newObjective.group > 0)
	      %prevClient = newObjective.group.clientLevel[1];
		else
	      %prevClient = newObjective.clientLevel[1];
      if (%prevClient > 0)
         AIUnassignClient(%prevClient);

		//see if we should override the weight
		if (%useWeight < %newObjective.weightLevel1)
			%useWeight = %newObjective.weightLevel1;
      
      //release the client, and force the assignment
      AIUnassignClient(%client);
      %client.objective = %newObjective;
      %client.objectiveWeight = %useWeight;
      %client.objectiveLevel = 1;
		if (%newObjective.group > 0)
	      %newObjective.group.clientLevel[1] = %client;
		else
	      %newObjective.clientLevel[1] = %client;
		%newObjective.forceClientId = %client;
      %newObjective.assignClient(%client);

      //don't acknowledge anything that's been forced...
      %newObjective.shouldAcknowledge = false;
      
      //now reassign the prev client
      if (%prevClient)
         Game.AIChooseGameObjective(%prevClient);
   }
   
   //debuging - refresh aidebugq() if required
   //if ($AIDebugTeam >= 0)
    // aiDebugQ($AIDebugTeam);
}

function AIUnassignClient(%client)
{
	//first, dissolve any link with a human
	aiReleaseHumanControl(%client.controlByHuman, %client);

   if (%client.objective)
   {
      if (%client.objectiveLevel <= 3)
		{
			if (%client.objective.group > 0)
			{
				//make sure the clientLevel was actually this client
				if (%client.objective.group.clientLevel[%client.objectiveLevel] == %client)
					%client.objective.group.clientLevel[%client.objectiveLevel] = "";
			}
			else
			{
				if (%client.objective.clientLevel[%client.objectiveLevel] == %client)
		         %client.objective.clientLevel[%client.objectiveLevel] = "";
			}
		}
      %client.objective.unassignClient(%client);
      %client.objective = "";
		%client.objectiveWeight = 0;
   }
   
   //debuging - refresh aidebugq() if required
   //if ($AIDebugTeam >= 0)
      //aiDebugQ($AIDebugTeam);
}
  
function AIClearObjective(%objective)
{
   %count = ClientGroup.getCount();
   for(%i = 0; %i < %count; %i++)
   {
		%cl = ClientGroup.getObject(%i);
      if (%cl.objective == %objective)
         AIUnassignClient(%cl);
   }
   
   //debuging - refresh aidebugq() if required
   //if ($AIDebugTeam >= 0)
      //aiDebugQ($AIDebugTeam);
}
